@@ -27,6 +27,10 @@ extern "C"
 #include <string.h>
 #endif
 
+#if HAVE_STRINGS_H
+#include <strings.h>
+#endif
+
 #if HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -61,16 +65,15 @@ extern "C"
 #include "tools.hpp"
 #include "thread_cancellation.hpp"
 #include "archive.hpp"
-#include "string_file.hpp"
 #include "cygwin_adapt.hpp"
 #include "no_comment.hpp"
 #include "line_tools.hpp"
-#include "fichier.hpp"
+#include "fichier_local.hpp"
 #include "deci.hpp"
 
 using namespace libdar;
 
-#define DAR_MANAGER_VERSION "1.7.8"
+#define DAR_MANAGER_VERSION "1.7.10"
 
 
 #define ONLY_ONCE "Only one -%c is allowed, ignoring this extra option"
@@ -80,8 +83,8 @@ using namespace libdar;
 
 enum operation { none_op, create, add, listing, del, chbase, where, options, dar, restore, used, files, stats, moving, interactive, check, batch };
 
-static S_I little_main(user_interaction & dialog, S_I argc, char *const argv[], const char **env);
-static bool command_line(user_interaction & dialog,
+static S_I little_main(shell_interaction & dialog, S_I argc, char *const argv[], const char **env);
+static bool command_line(shell_interaction & dialog,
 			 S_I argc, char * const argv[],
                          operation & op,
                          string & base,
@@ -95,21 +98,21 @@ static bool command_line(user_interaction & dialog,
 			 bool & even_when_removed,
 			 bool & check_order,
 			 bool recursive); // true if called from op_batch
-static void show_usage(user_interaction & dialog, const char *command);
-static void show_version(user_interaction & dialog, const char *command);
+static void show_usage(shell_interaction & dialog, const char *command);
+static void show_version(shell_interaction & dialog, const char *command);
 
 #if HAVE_GETOPT_LONG
 static const struct option *get_long_opt();
 #endif
-static void op_create(user_interaction & dialog, const string & base, bool info_details);
-static void op_add(user_interaction & dialog, database *dat, const string &arg, string fake, const infinint & min_digits, bool info_details);
-static void op_listing(user_interaction & dialog, const database *dat, bool info_details);
-static void op_del(user_interaction & dialog, database *dat, S_I min, archive_num max, bool info_details);
-static void op_chbase(user_interaction & dialog, database *dat, S_I num, const string & arg, bool info_details);
-static void op_where(user_interaction & dialog, database *dat, S_I num, const string & arg, bool info_details);
-static void op_options(user_interaction & dialog, database *dat, const vector<string> & rest, bool info_details);
-static void op_dar(user_interaction & dialog, database *dat, const string & arg, bool info_details);
-static void op_restore(user_interaction & dialog,
+static void op_create(shell_interaction & dialog, const string & base, bool info_details);
+static void op_add(shell_interaction & dialog, database *dat, const string &arg, string fake, const infinint & min_digits, bool info_details);
+static void op_listing(shell_interaction & dialog, const database *dat, bool info_details);
+static void op_del(shell_interaction & dialog, database *dat, S_I min, archive_num max, bool info_details);
+static void op_chbase(shell_interaction & dialog, database *dat, S_I num, const string & arg, bool info_details);
+static void op_where(shell_interaction & dialog, database *dat, S_I num, const string & arg, bool info_details);
+static void op_options(shell_interaction & dialog, database *dat, const vector<string> & rest, bool info_details);
+static void op_dar(shell_interaction & dialog, database *dat, const string & arg, bool info_details);
+static void op_restore(shell_interaction & dialog,
 		       database *dat,
 		       const vector<string> & rest,
 		       const infinint & date,
@@ -118,23 +121,23 @@ static void op_restore(user_interaction & dialog,
 		       bool early_release,
 		       bool ignore_dar_options_in_base,
 		       bool even_when_removed);
-static void op_used(user_interaction & dialog, const database *dat, S_I num, bool info_details);
-static void op_files(user_interaction & dialog, const database *dat, const string & arg, bool info_details);
-static void op_stats(user_interaction & dialog, const database *dat, bool info_details);
-static void op_move(user_interaction & dialog, database *dat, S_I src, archive_num dst, bool info_details);
-static void op_interactive(user_interaction & dialog, database *dat, string base);
-static void op_check(user_interaction & dialog, const database *dat, bool info_details);
-static void op_batch(user_interaction & dialog, database *dat, const string & filename, bool info_details);
+static void op_used(shell_interaction & dialog, const database *dat, S_I num, bool info_details);
+static void op_files(shell_interaction & dialog, const database *dat, const string & arg, bool info_details);
+static void op_stats(shell_interaction & dialog, const database *dat, bool info_details);
+static void op_move(shell_interaction & dialog, database *dat, S_I src, archive_num dst, bool info_details);
+static void op_interactive(shell_interaction & dialog, database *dat, string base);
+static void op_check(shell_interaction & dialog, const database *dat, bool info_details);
+static void op_batch(shell_interaction & dialog, database *dat, const string & filename, bool info_details);
 
-static database *read_base(user_interaction & dialog,
+static database *read_base(shell_interaction & dialog,
 			   const string & base,
 			   bool partial,
 			   bool partial_read_only,
 			   bool check_order);
-static void write_base(user_interaction & dialog, const string & filename, const database *base, bool overwrite);
-static vector<string> read_vector(user_interaction & dialog);
-static void finalize(user_interaction & dialog, operation op, database *dat, const string & base, bool info_details);
-static void action(user_interaction & dialog,
+static void write_base(shell_interaction & dialog, const string & filename, const database *base, bool overwrite);
+static vector<string> read_vector(shell_interaction & dialog);
+static void finalize(shell_interaction & dialog, operation op, database *dat, const string & base, bool info_details);
+static void action(shell_interaction & dialog,
 		   operation op,
 		   database *dat,
 		   const string & arg,
@@ -159,10 +162,11 @@ int main(S_I argc, char *const argv[], const char **env)
 #if HAVE_GETOPT_LONG
 			    get_long_opt(),
 #endif
+			    'o',  // stop looking for -j and -Q once -o option is met on command-line
 			    &little_main);
 }
 
-S_I little_main(user_interaction & dialog, S_I argc, char * const argv[], const char **env)
+S_I little_main(shell_interaction & dialog, S_I argc, char * const argv[], const char **env)
 {
     operation op;
     string base;
@@ -172,14 +176,14 @@ S_I little_main(user_interaction & dialog, S_I argc, char * const argv[], const
     vector<string> rest;
     bool info_details;
     infinint date;
-    database *dat = NULL;
+    database *dat = nullptr;
     bool partial_read = false;
     bool partial_read_only = false;
     bool ignore_dat_options;
     bool even_when_removed;
     bool check_order;
 
-    shell_interaction_change_non_interactive_output(&cout);
+    dialog.change_non_interactive_output(&cout);
 
     if(!command_line(dialog, argc, argv, op, base, arg, num, rest, num2, date, info_details, ignore_dat_options, even_when_removed, check_order, false))
 	return EXIT_SYNTAX;
@@ -244,18 +248,18 @@ S_I little_main(user_interaction & dialog, S_I argc, char * const argv[], const
 	}
 	catch(...)
 	{
-	    if(dat != NULL)
+	    if(dat != nullptr)
 		delete dat;
 	    throw;
 	}
-	if(dat != NULL)
+	if(dat != nullptr)
 	    delete dat;
     }
 
     return EXIT_OK;
 }
 
-static bool command_line(user_interaction & dialog,
+static bool command_line(shell_interaction & dialog,
 			 S_I argc, char *const argv[],
                          operation & op,
                          string & base,
@@ -290,7 +294,7 @@ static bool command_line(user_interaction & dialog,
 
 	(void)line_tools_reset_getopt();
 #if HAVE_GETOPT_LONG
-	while((lu = getopt_long(argc, argv, OPT_STRING, get_long_opt(), NULL)) != EOF)
+	while((lu = getopt_long(argc, argv, OPT_STRING, get_long_opt(), nullptr)) != EOF)
 #else
 	    while((lu = getopt(argc, argv, OPT_STRING)) != EOF)
 #endif
@@ -301,7 +305,7 @@ static bool command_line(user_interaction & dialog,
 		    if(op != none_op)
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
 		    op = create;
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    base = optarg;
 		    break;
@@ -310,7 +314,7 @@ static bool command_line(user_interaction & dialog,
 			throw Erange("command_line", tools_printf(gettext("-B option cannot be given inside a batch file")));
 		    if(base != "")
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    base = optarg;
 		    break;
@@ -318,7 +322,7 @@ static bool command_line(user_interaction & dialog,
 		    if(op != none_op)
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
 		    op = add;
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    tools_split_path_basename(optarg, chem, filename);
 		    tools_check_basename(dialog, chem, filename, EXTENSION);
@@ -333,7 +337,7 @@ static bool command_line(user_interaction & dialog,
 		    if(op != none_op)
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
 		    op = del;
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    try
 		    {
@@ -350,7 +354,7 @@ static bool command_line(user_interaction & dialog,
 		    if(op != none_op)
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
 		    op = chbase;
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    num = tools_str2signed_int(optarg);
 		    break;
@@ -358,7 +362,7 @@ static bool command_line(user_interaction & dialog,
 		    if(op != none_op)
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
 		    op = where;
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    num = tools_str2signed_int(optarg);
 		    break;
@@ -371,7 +375,7 @@ static bool command_line(user_interaction & dialog,
 		    if(op != none_op)
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
 		    op = dar;
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    arg = optarg;
 		    break;
@@ -384,7 +388,7 @@ static bool command_line(user_interaction & dialog,
 		    if(op != none_op)
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
 		    op = used;
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    num = tools_str2signed_int(optarg);
 		    break;
@@ -392,7 +396,7 @@ static bool command_line(user_interaction & dialog,
 		    if(op != none_op)
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
 		    op = files;
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    arg = optarg;
 		    break;
@@ -405,7 +409,7 @@ static bool command_line(user_interaction & dialog,
 		    if(op != none_op)
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
 		    op = moving;
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    num = tools_str2int(optarg);
 		    break;
@@ -419,10 +423,9 @@ static bool command_line(user_interaction & dialog,
 		    verbose = true;
 		    break;
 		case 'Q':
-		case 'j':
 		    break;  // ignore this option already parsed during initialization (dar_suite.cpp)
 		case 'w':
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    date = tools_convert_date(optarg);
 		    break;
@@ -439,7 +442,7 @@ static bool command_line(user_interaction & dialog,
 		case 'e':
 		    if(extra != "")
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    extra = optarg;
 		    break;
@@ -449,7 +452,7 @@ static bool command_line(user_interaction & dialog,
 		    if(op != none_op)
 			throw Erange("command_line", tools_printf(gettext(ONLY_ONCE), char(lu)));
 		    op = batch;
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    arg = optarg;
 		    break;
@@ -479,7 +482,7 @@ static bool command_line(user_interaction & dialog,
 		    }
 		    break;
 		case 'a':
-		    if(optarg == NULL)
+		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    if(strcasecmp("i", optarg) == 0 || strcasecmp("ignore-order", optarg) == 0)
 			check_order = false;
@@ -590,7 +593,7 @@ static bool command_line(user_interaction & dialog,
     return true;
 }
 
-static void op_create(user_interaction & dialog, const string & base, bool info_details)
+static void op_create(shell_interaction & dialog, const string & base, bool info_details)
 {
     database dat; // created empty;
 
@@ -604,14 +607,14 @@ static void op_create(user_interaction & dialog, const string & base, bool info_
         dialog.warning(gettext("Database has been successfully created empty."));
 }
 
-static void op_add(user_interaction & dialog, database *dat, const string &arg, string fake, const infinint & min_digits, bool info_details)
+static void op_add(shell_interaction & dialog, database *dat, const string &arg, string fake, const infinint & min_digits, bool info_details)
 {
     thread_cancellation thr;
     string arch_path, arch_base;
     bool date_order_problem = false;
     archive_options_read read_options;
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
@@ -621,7 +624,7 @@ static void op_add(user_interaction & dialog, database *dat, const string &arg,
     read_options.set_info_details(info_details);
     read_options.set_slice_min_digits(min_digits);
     archive *arch = new (nothrow) archive(dialog, path(arch_path), arch_base, EXTENSION, read_options);
-    if(arch == NULL)
+    if(arch == nullptr)
 	throw Ememory("dar_manager.cpp:op_add");
 
     try
@@ -637,14 +640,14 @@ static void op_add(user_interaction & dialog, database *dat, const string &arg,
 	dat->add_archive(*arch, chemin, b, database_add_options());
 	thr.check_self_cancellation();
 	if(info_details)
-	    dialog.warning(gettext("Checking date ordering of files between archive..."));
+	    dialog.warning(gettext("Checking date ordering of files between archives..."));
 	date_order_problem = dat->check_order(dialog);
 	thr.check_self_cancellation();
 
     }
     catch(...)
     {
-	if(arch != NULL)
+	if(arch != nullptr)
 	    delete arch;
 	throw;
     }
@@ -654,15 +657,15 @@ static void op_add(user_interaction & dialog, database *dat, const string &arg,
 	throw Edata(gettext("Some files do not follow chronological order when archive index increases withing the database, this can lead dar_manager to restored a wrong version of these files"));
 }
 
-static void op_listing(user_interaction & dialog, const database *dat, bool info_details)
+static void op_listing(shell_interaction & dialog, const database *dat, bool info_details)
 {
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     dat->show_contents(dialog);
 }
 
-static void op_del(user_interaction & dialog, database *dat, S_I min, archive_num max, bool info_details)
+static void op_del(shell_interaction & dialog, database *dat, S_I min, archive_num max, bool info_details)
 {
     thread_cancellation thr;
     database_remove_options opt;
@@ -673,7 +676,7 @@ static void op_del(user_interaction & dialog, database *dat, S_I min, archive_nu
     opt.set_revert_archive_numbering(!sign_plus);
     if(!sign_plus)
 	max = rmin;
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
@@ -683,7 +686,7 @@ static void op_del(user_interaction & dialog, database *dat, S_I min, archive_nu
     thr.check_self_cancellation();
 }
 
-static void op_chbase(user_interaction & dialog, database *dat, S_I num, const string & arg, bool info_details)
+static void op_chbase(shell_interaction & dialog, database *dat, S_I num, const string & arg, bool info_details)
 {
     thread_cancellation thr;
     database_change_basename_options opt;
@@ -693,7 +696,7 @@ static void op_chbase(user_interaction & dialog, database *dat, S_I num, const s
     signed_int_to_archive_num(num, rnum, sign_plus);
     opt.set_revert_archive_numbering(!sign_plus);
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
@@ -703,7 +706,7 @@ static void op_chbase(user_interaction & dialog, database *dat, S_I num, const s
     thr.check_self_cancellation();
 }
 
-static void op_where(user_interaction & dialog, database *dat, S_I num, const string & arg, bool info_details)
+static void op_where(shell_interaction & dialog, database *dat, S_I num, const string & arg, bool info_details)
 {
     thread_cancellation thr;
     database_change_path_options opt;
@@ -713,7 +716,7 @@ static void op_where(user_interaction & dialog, database *dat, S_I num, const st
     signed_int_to_archive_num(num, rnum, sign_plus);
     opt.set_revert_archive_numbering(!sign_plus);
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
@@ -723,11 +726,11 @@ static void op_where(user_interaction & dialog, database *dat, S_I num, const st
     thr.check_self_cancellation();
 }
 
-static void op_options(user_interaction & dialog, database *dat, const vector<string> & rest, bool info_details)
+static void op_options(shell_interaction & dialog, database *dat, const vector<string> & rest, bool info_details)
 {
     thread_cancellation thr;
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
@@ -737,11 +740,11 @@ static void op_options(user_interaction & dialog, database *dat, const vector<st
     thr.check_self_cancellation();
 }
 
-static void op_dar(user_interaction & dialog, database *dat, const string & arg, bool info_details)
+static void op_dar(shell_interaction & dialog, database *dat, const string & arg, bool info_details)
 {
     thread_cancellation thr;
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
@@ -751,15 +754,14 @@ static void op_dar(user_interaction & dialog, database *dat, const string & arg,
     thr.check_self_cancellation();
 }
 
-static void op_restore(user_interaction & dialog, database *dat, const vector<string> & rest, const infinint & date, const string & options_for_dar, bool info_details, bool early_release, bool ignore_dar_options_in_base, bool even_when_removed)
+static void op_restore(shell_interaction & dialog, database *dat, const vector<string> & rest, const infinint & date, const string & options_for_dar, bool info_details, bool early_release, bool ignore_dar_options_in_base, bool even_when_removed)
 {
     thread_cancellation thr;
-    string_file strfile = string_file(options_for_dar);
-    vector <string> options = tools_split_in_words(strfile);
+    vector <string> options = tools_split_in_words(options_for_dar);
 
     database_restore_options dat_opt;
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
@@ -774,7 +776,7 @@ static void op_restore(user_interaction & dialog, database *dat, const vector<st
     dat->restore(dialog, rest, dat_opt);
 }
 
-static void op_used(user_interaction & dialog, const database *dat, S_I num, bool info_details)
+static void op_used(shell_interaction & dialog, const database *dat, S_I num, bool info_details)
 {
     thread_cancellation thr;
     database_used_options opt;
@@ -784,29 +786,29 @@ static void op_used(user_interaction & dialog, const database *dat, S_I num, boo
     signed_int_to_archive_num(num, rnum, sign_plus);
     opt.set_revert_archive_numbering(!sign_plus);
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
     dat->show_files(dialog, rnum, opt);
 }
 
-static void op_files(user_interaction & dialog, const database *dat, const string & arg, bool info_details)
+static void op_files(shell_interaction & dialog, const database *dat, const string & arg, bool info_details)
 {
     thread_cancellation thr;
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
     dat->show_version(dialog, arg);
 }
 
-static void op_stats(user_interaction & dialog, const database *dat, bool info_details)
+static void op_stats(shell_interaction & dialog, const database *dat, bool info_details)
 {
     thread_cancellation thr;
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
@@ -815,7 +817,7 @@ static void op_stats(user_interaction & dialog, const database *dat, bool info_d
     dat->show_most_recent_stats(dialog);
 }
 
-static void op_move(user_interaction & dialog, database *dat, S_I src, archive_num dst, bool info_details)
+static void op_move(shell_interaction & dialog, database *dat, S_I src, archive_num dst, bool info_details)
 {
     thread_cancellation thr;
     bool date_order_problem = false;
@@ -823,7 +825,7 @@ static void op_move(user_interaction & dialog, database *dat, S_I src, archive_n
     if(src <= 0)
 	throw Erange("op_move", gettext("Negative number or zero not allowed when moving an archive inside a database"));
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
@@ -832,14 +834,14 @@ static void op_move(user_interaction & dialog, database *dat, S_I src, archive_n
     dat->set_permutation(src, dst);
     thr.check_self_cancellation();
     if(info_details)
-	dialog.warning(gettext("Checking date ordering of files between archive..."));
+	dialog.warning(gettext("Checking date ordering of files between archives..."));
     date_order_problem = dat->check_order(dialog);
     thr.check_self_cancellation();
     if(date_order_problem)
 	throw Edata(gettext("Some files do not follow chronological order when archive index increases withing the database, this can lead dar_manager to restored a wrong version of these files"));
 }
 
-static void show_usage(user_interaction & dialog, const char *command)
+static void show_usage(shell_interaction & dialog, const char *command)
 {
     dialog.printf("usage :\n\n");
     dialog.printf("\tdar_manager [options] -C [<path>/]<database>\n");
@@ -861,17 +863,44 @@ static void show_usage(user_interaction & dialog, const char *command)
     dialog.printf("\tdar_manager -h\n");
     dialog.printf("\tdar_manager -V\n");
     dialog.printf("\n");
-#include "dar_manager.usage"
+    dialog.printf(gettext("\n"));
+    dialog.printf(gettext("Commands:\n"));
+    dialog.printf(gettext("   -C <database>   creates an empty database\n"));
+    dialog.printf(gettext("   -B <database>   specify the database to use (read or modify)\n"));
+    dialog.printf(gettext("   -A <archive>    add an archive to the database\n"));
+    dialog.printf(gettext("   -l\t\t   gives information about the archive compiled in the database\n"));
+    dialog.printf(gettext("   -D <number[-number]> delete an archive from the database\n"));
+    dialog.printf(gettext("   -b <number>\t   change the basename to use for the give archive number\n"));
+    dialog.printf(gettext("   -p <number>\t   change the path to use for the given archive number\n"));
+    dialog.printf(gettext("   -o <options>    specify a list of option to always pass to dar\n"));
+    dialog.printf(gettext("   -d <dar's path> specify the path to dar\n"));
+    dialog.printf(gettext("   -r <files>\t   restores the given files\n"));
+    dialog.printf(gettext("   -w <date>\t   only with -r, restores in state just before the given date\n"));
+    dialog.printf(gettext("   -u <number>\t   list the most recent files contained in the given archive\n"));
+    dialog.printf(gettext("   -f <file>\t   list the archives where the given file is present\n"));
+    dialog.printf(gettext("   -s\t\t   shows the number of most recent file by archive\n"));
+    dialog.printf(gettext("   -m <number>\t   move an archive within a given database.\n"));
+    dialog.printf(gettext("   -i\t\t   user interactive mode\n"));
+    dialog.printf(gettext("   -c\t\t   check database for dates order\n"));
+    dialog.printf(gettext("   -L <filename>   execute on a given database a batch of action as defined by\n"));
+    dialog.printf(gettext("\t\t   the provided file.\n"));
+    dialog.printf(gettext("   -h\t\t   displays this help information\n"));
+    dialog.printf(gettext("   -V\t\t   displays software version\n"));
+    dialog.printf(gettext("\n"));
+    dialog.printf(gettext("Options:\n"));
+    dialog.printf(gettext("   -v\t\t   display more information about what is going on\n"));
+    dialog.printf(gettext("\n"));
+    dialog.printf(gettext("See man page for more options.\n"));
 }
 
-static void show_version(user_interaction & dialog, const char *command_name)
+static void show_version(shell_interaction & dialog, const char *command_name)
 {
     string name;
     tools_extract_basename(command_name, name);
     U_I maj, med, min;
 
     get_version(maj, med, min);
-    shell_interaction_change_non_interactive_output(&cout);
+    dialog.change_non_interactive_output(&cout);
     dialog.printf("\n %s version %s, Copyright (C) 2002-2052 Denis Corbin\n", name.c_str(), DAR_MANAGER_VERSION);
     dialog.warning(string("   ") + dar_suite_command_line_features() + "\n");
     if(maj > 2)
@@ -892,42 +921,42 @@ static void show_version(user_interaction & dialog, const char *command_name)
 static const struct option *get_long_opt()
 {
     static const struct option ret[] = {
-        {"create", required_argument, NULL, 'C'},
-        {"base", required_argument, NULL, 'B'},
-        {"add", required_argument, NULL, 'A'},
-        {"list", no_argument, NULL, 'l'},
-        {"delete", required_argument, NULL, 'D'},
-        {"basename", required_argument, NULL, 'b'},
-        {"path", required_argument, NULL, 'p'},
-        {"options", no_argument, NULL, 'o'},
-        {"dar", no_argument, NULL, 'd'},
-        {"restore", no_argument, NULL, 'r'},
-        {"used", required_argument, NULL, 'u'},
-        {"file", required_argument, NULL, 'f'},
-        {"stats", no_argument, NULL, 's'},
-        {"help", no_argument, NULL, 'h'},
-        {"version", no_argument, NULL, 'V'},
-        {"verbose", no_argument, NULL, 'v'},
-	{"jog", no_argument, NULL, 'j'},
-	{"when", required_argument, NULL, 'w'},
-	{"interactive", no_argument, NULL, 'i'},
-	{"extra", required_argument, NULL, 'e'},
-	{"check", no_argument, NULL, 'c'},
- 	{"batch", required_argument, NULL, '@'},
-	{"ignore-options-in-base", no_argument, NULL, 'N'},
-	{"min-digits", required_argument, NULL, '9'},
-	{"ignore-when-removed", no_argument, NULL, 'k'},
-	{"alter", required_argument, NULL, 'a'},
-        { NULL, 0, NULL, 0 }
+        {"create", required_argument, nullptr, 'C'},
+        {"base", required_argument, nullptr, 'B'},
+        {"add", required_argument, nullptr, 'A'},
+        {"list", no_argument, nullptr, 'l'},
+        {"delete", required_argument, nullptr, 'D'},
+        {"basename", required_argument, nullptr, 'b'},
+        {"path", required_argument, nullptr, 'p'},
+        {"options", no_argument, nullptr, 'o'},
+        {"dar", no_argument, nullptr, 'd'},
+        {"restore", no_argument, nullptr, 'r'},
+        {"used", required_argument, nullptr, 'u'},
+        {"file", required_argument, nullptr, 'f'},
+        {"stats", no_argument, nullptr, 's'},
+        {"help", no_argument, nullptr, 'h'},
+        {"version", no_argument, nullptr, 'V'},
+        {"verbose", no_argument, nullptr, 'v'},
+	{"jog", no_argument, nullptr, 'j'},
+	{"when", required_argument, nullptr, 'w'},
+	{"interactive", no_argument, nullptr, 'i'},
+	{"extra", required_argument, nullptr, 'e'},
+	{"check", no_argument, nullptr, 'c'},
+ 	{"batch", required_argument, nullptr, '@'},
+	{"ignore-options-in-base", no_argument, nullptr, 'N'},
+	{"min-digits", required_argument, nullptr, '9'},
+	{"ignore-when-removed", no_argument, nullptr, 'k'},
+	{"alter", required_argument, nullptr, 'a'},
+        { nullptr, 0, nullptr, 0 }
     };
 
     return ret;
 }
 #endif
 
-static database *read_base(user_interaction & dialog, const string & base, bool partial, bool partial_read_only, bool check_order)
+static database *read_base(shell_interaction & dialog, const string & base, bool partial, bool partial_read_only, bool check_order)
 {
-    database *ret = NULL;
+    database *ret = nullptr;
 
     try
     {
@@ -936,7 +965,7 @@ static database *read_base(user_interaction & dialog, const string & base, bool
 	dat_opt.set_partial(partial);
 	dat_opt.set_partial_read_only(partial_read_only);
         ret = new (nothrow) database(dialog, base, dat_opt);
-        if(ret == NULL)
+        if(ret == nullptr)
             throw Ememory("read_base");
     }
     catch(Erange & e)
@@ -949,7 +978,7 @@ static database *read_base(user_interaction & dialog, const string & base, bool
     return ret;
 }
 
-static void write_base(user_interaction & dialog, const string & filename, const database *base, bool overwrite)
+static void write_base(shell_interaction & dialog, const string & filename, const database *base, bool overwrite)
 {
     thread_cancellation thr;
     database_dump_options dat_opt;
@@ -960,7 +989,7 @@ static void write_base(user_interaction & dialog, const string & filename, const
     thr.block_delayed_cancellation(false);
 }
 
-static void op_interactive(user_interaction & dialog, database *dat, string base)
+static void op_interactive(shell_interaction & dialog, database *dat, string base)
 {
     char choice;
     bool saved = true;
@@ -969,7 +998,7 @@ static void op_interactive(user_interaction & dialog, database *dat, string base
     S_I tmp_si;
     bool tmp_sign;
     string input, input2;
-    archive *arch = NULL;
+    archive *arch = nullptr;
     vector <string> vectinput;
     U_I more = 25;
     database_change_basename_options opt_change_name;
@@ -977,7 +1006,7 @@ static void op_interactive(user_interaction & dialog, database *dat, string base
     database_remove_options opt_remove;
     database_used_options opt_used;
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     thr.check_self_cancellation();
@@ -1008,7 +1037,7 @@ static void op_interactive(user_interaction & dialog, database *dat, string base
 
 		// user's choice selection
 
-	    shell_interaction_read_char(choice);
+	    dialog.read_char(choice);
 	    thr.check_self_cancellation();
 	    dialog.printf("\n\n");
 
@@ -1064,24 +1093,24 @@ static void op_interactive(user_interaction & dialog, database *dat, string base
 		read_options.clear();
 		read_options.set_info_details(true);
 		arch = new (nothrow) archive(dialog, path(input), input2, EXTENSION, read_options);
-		if(arch == NULL)
+		if(arch == nullptr)
 		    throw Ememory("dar_manager.cpp:op_interactive");
 		try
 		{
 		    dialog.warning(gettext("Updating database with catalogue..."));
 		    dat->add_archive(*arch, input, input2, database_add_options());
 		    thr.check_self_cancellation();
-		    dialog.warning(gettext("Checking date ordering of files between archive..."));
+		    dialog.warning(gettext("Checking date ordering of files between archives..."));
 		    (void)dat->check_order(dialog);
 		}
 		catch(...)
 		{
 		    delete arch;
-		    arch = NULL;
+		    arch = nullptr;
 		    throw;
 		}
 		delete arch;
-		arch = NULL;
+		arch = nullptr;
 		saved = false;
 		break;
 	    case 'D':
@@ -1101,7 +1130,7 @@ static void op_interactive(user_interaction & dialog, database *dat, string base
 		num2 = tools_str2int(input);
 		dat->set_permutation(num, num2);
 		thr.check_self_cancellation();
-		dialog.warning(gettext("Checking date ordering of files between archive..."));
+		dialog.warning(gettext("Checking date ordering of files between archives..."));
 		dat->check_order(dialog);
 		saved = false;
 		break;
@@ -1183,19 +1212,19 @@ static void op_interactive(user_interaction & dialog, database *dat, string base
 	}
     }
     while(choice != 'q');
-    if(arch != NULL)
+    if(arch != nullptr)
 	throw SRC_BUG;
 }
 
-static void op_check(user_interaction & dialog, const database *dat, bool info_details)
+static void op_check(shell_interaction & dialog, const database *dat, bool info_details)
 {
     thread_cancellation thr;
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
     if(info_details)
-	dialog.warning(gettext("Checking date ordering of files between archive..."));
+	dialog.warning(gettext("Checking date ordering of files between archives..."));
     if(!dat->check_order(dialog))
 	throw Edata(gettext("Some files do not follow chronological order when archive index increases withing the database, this can lead dar_manager to restored a wrong version of these files"));
     else
@@ -1203,7 +1232,7 @@ static void op_check(user_interaction & dialog, const database *dat, bool info_d
     thr.check_self_cancellation();
 }
 
-static void op_batch(user_interaction & dialog, database *dat, const string & filename, bool info_details)
+static void op_batch(shell_interaction & dialog, database *dat, const string & filename, bool info_details)
 {
     const string pseudo_cmd = "dar_manager"; // to take the place of the command on the simulated command-line
     string line;
@@ -1222,21 +1251,15 @@ static void op_batch(user_interaction & dialog, database *dat, const string & fi
     bool even_when_removed;
     bool check_order; // not used here
 
-    if(dat == NULL)
+    if(dat == nullptr)
 	throw SRC_BUG;
 
 	// openning the batch file
 
     if(info_details)
 	dialog.warning(gettext("Opening and reading the batch file..."));
-    int fd = -1;
-    fd = open(filename.c_str(), O_RDONLY|O_BINARY);
-
-    if(fd < 0)
-	throw Erange("op_batch", tools_printf(gettext("Cannot open file %S : %s"), &filename, strerror(errno)));
-
-    fichier batch_file = fichier(dialog, fd); // the object batch_file will close fd upon destructor call.
 
+    fichier_local batch_file = fichier_local(filename, false);
     no_comment proper = no_comment(batch_file); // removing the comments from file
 
 	// reading it line by line and executing corresponding action
@@ -1252,8 +1275,7 @@ static void op_batch(user_interaction & dialog, database *dat, const string & fi
 	    while(proper.read(&tmp,  1) == 1 && tmp != '\n')
 		line += tmp;
 
-	    string_file line_file = string_file(line);
-	    mots = tools_split_in_words(line_file);
+	    mots = tools_split_in_words(line);
 
 	    if(mots.size() == 0)
 		continue;
@@ -1287,7 +1309,7 @@ static void op_batch(user_interaction & dialog, database *dat, const string & fi
     }
 }
 
-static vector<string> read_vector(user_interaction & dialog)
+static vector<string> read_vector(shell_interaction & dialog)
 {
     vector<string> ret;
     string tmp;
@@ -1307,7 +1329,7 @@ static vector<string> read_vector(user_interaction & dialog)
     return ret;
 }
 
-static void finalize(user_interaction & dialog, operation op, database *dat, const string & base, bool info_details)
+static void finalize(shell_interaction & dialog, operation op, database *dat, const string & base, bool info_details)
 {
     switch(op)
     {
@@ -1337,7 +1359,7 @@ static void finalize(user_interaction & dialog, operation op, database *dat, con
     }
 }
 
-static void action(user_interaction & dialog,
+static void action(shell_interaction & dialog,
 		   operation op,
 		   database *dat,
 		   const string & arg,
