@@ -38,7 +38,7 @@ extern "C"
 #  define strchr index
 #  define strrchr rindex
 # endif
-char *strchr (), *strrchr ();
+    char *strchr (), *strrchr ();
 # if !HAVE_MEMCPY
 #  define memcpy(d, s, n) bcopy ((s), (d), (n))
 #  define memmove(d, s, n) bcopy ((s), (d), (n))
@@ -64,6 +64,7 @@ char *strchr (), *strrchr ();
 #include "libdar.hpp"
 #include "shell_interaction.hpp"
 #include "line_tools.hpp"
+#include "entrepot_local.hpp"
 
 #define ONLY_ONCE "Only one -%c is allowed, ignoring this extra option"
 #define OPT_STRING "i:o:hVE:Qj9:"
@@ -71,31 +72,32 @@ char *strchr (), *strrchr ();
 using namespace libdar;
 using namespace std;
 
-#define DAR_SLAVE_VERSION "1.4.6"
+#define DAR_SLAVE_VERSION "1.4.8"
 
-static bool command_line(user_interaction & dialog,
+static bool command_line(shell_interaction & dialog,
 			 S_I argc, char * const argv[], path * &chemin, string & filename,
                          string &input_pipe, string &output_pipe, string & execute,
 			 infinint & min_digits);
-static void show_usage(user_interaction & dialog, const char *command);
-static void show_version(user_interaction & dialog, const char *command);
-static S_I little_main(user_interaction & dialog, S_I argc, char * const argv[], const char **env);
+static void show_usage(shell_interaction & dialog, const char *command);
+static void show_version(shell_interaction & dialog, const char *command);
+static S_I little_main(shell_interaction & dialog, S_I argc, char * const argv[], const char **env);
 
 int main(S_I argc, char * const argv[], const char **env)
 {
-     return dar_suite_global(argc,
-			     argv,
-			     env,
-			     OPT_STRING,
+    return dar_suite_global(argc,
+			    argv,
+			    env,
+			    OPT_STRING,
 #if HAVE_GETOPT_LONG
-			     NULL,
+			    nullptr,
 #endif
-			     &little_main);
+			    '\0', // should never be met as option, thus early read the whole command-line for -j and -Q options
+			    &little_main);
 }
 
-static S_I little_main(user_interaction & dialog, S_I argc, char * const argv[], const char **env)
+static S_I little_main(shell_interaction & dialog, S_I argc, char * const argv[], const char **env)
 {
-    path *chemin = NULL;
+    path *chemin = nullptr;
     string filename;
     string input_pipe;
     string output_pipe;
@@ -104,23 +106,26 @@ static S_I little_main(user_interaction & dialog, S_I argc, char * const argv[],
 
     if(command_line(dialog, argc, argv, chemin, filename, input_pipe, output_pipe, execute, min_digits))
     {
-        tuyau *input = NULL;
-        tuyau *output = NULL;
-        sar *source = NULL;
+        tuyau *input = nullptr;
+        tuyau *output = nullptr;
+        sar *source = nullptr;
+	entrepot_local entrep = entrepot_local("", "", false);
 
-	if(chemin == NULL)
+	if(chemin == nullptr)
 	    throw SRC_BUG;
+
+	entrep.set_location(*chemin);
         try
         {
-            source = new (nothrow) sar(dialog, filename, EXTENSION, *chemin, true, min_digits, false, execute);
-            if(source == NULL)
+	    source = new (nothrow) sar(dialog, filename, EXTENSION, entrep, true, min_digits, false, execute);
+            if(source == nullptr)
                 throw Ememory("little_main");
 
             tools_open_pipes(dialog, input_pipe, output_pipe, input, output);
 
             slave_zapette zap = slave_zapette(input, output, source);
-            input = output = NULL; // now managed by zap;
-            source = NULL;  // now managed by zap;
+            input = output = nullptr; // now managed by zap;
+            source = nullptr;  // now managed by zap;
 
             try
             {
@@ -135,20 +140,20 @@ static S_I little_main(user_interaction & dialog, S_I argc, char * const argv[],
         catch(...)
         {
             delete chemin;
-            if(input != NULL)
+            if(input != nullptr)
                 delete input;
-            if(output != NULL)
+            if(output != nullptr)
                 delete output;
-            if(source != NULL)
+            if(source != nullptr)
                 delete source;
             throw;
         }
         delete chemin;
-        if(input != NULL)
+        if(input != nullptr)
             delete input;
-        if(output != NULL)
+        if(output != nullptr)
             delete output;
-        if(source != NULL)
+        if(source != nullptr)
             delete source;
 
         return EXIT_OK;
@@ -157,7 +162,7 @@ static S_I little_main(user_interaction & dialog, S_I argc, char * const argv[],
         return EXIT_SYNTAX;
 }
 
-static bool command_line(user_interaction & dialog,
+static bool command_line(shell_interaction & dialog,
 			 S_I argc,char * const argv[], path * &chemin, string & filename,
                          string &input_pipe, string &output_pipe, string & execute,
     			 infinint & min_digits)
@@ -176,7 +181,7 @@ static bool command_line(user_interaction & dialog,
         switch(lu)
         {
         case 'i':
-            if(optarg == NULL)
+            if(optarg == nullptr)
                 throw Erange("command_line", gettext("Missing argument to -i option"));
             if(input_pipe == "")
                 input_pipe = optarg;
@@ -184,7 +189,7 @@ static bool command_line(user_interaction & dialog,
                 dialog.warning(tools_printf(gettext(ONLY_ONCE), char(lu)));
             break;
         case 'o':
-            if(optarg == NULL)
+            if(optarg == nullptr)
                 throw Erange("command_line", gettext("Missing argument to -o option"));
             if(output_pipe == "")
                 output_pipe = optarg;
@@ -198,7 +203,7 @@ static bool command_line(user_interaction & dialog,
             show_version(dialog, argv[0]);
             return false;
         case 'E':
-            if(optarg == NULL)
+            if(optarg == nullptr)
                 throw Erange("command_line", gettext("Missing argument to -E option"));
             if(execute == "")
                 execute = optarg;
@@ -206,10 +211,9 @@ static bool command_line(user_interaction & dialog,
 		execute += string(" ; ") + optarg;
             break;
 	case 'Q':
-	case 'j':
 	    break;  // ignore this option already parsed during initialization (dar_suite.cpp)
 	case '9':
-	    if(optarg == NULL)
+	    if(optarg == nullptr)
 		throw Erange("command_line", tools_printf(gettext("Missing argument to --min-digits"), char(lu)));
 	    else
 	    {
@@ -244,28 +248,34 @@ static bool command_line(user_interaction & dialog,
     return true;
 }
 
-static void show_usage(user_interaction & dialog, const char *command)
+static void show_usage(shell_interaction & dialog, const char *command)
 {
     string cmd;
     tools_extract_basename(command, cmd);
-    shell_interaction_change_non_interactive_output(&cout);
+    dialog.change_non_interactive_output(&cout);
 
     dialog.printf("\nusage : \n");
     dialog.printf("  command1 | %s [options] [<path>/]basename | command2\n", cmd.c_str());
     dialog.printf("  %s [options] [-i input_pipe] [-o output_pipe] [<path>/]basename\n", cmd.c_str());
     dialog.printf("  %s -h\n", cmd.c_str());
     dialog.printf("  %s -V\n\n", cmd.c_str());
-#include "dar_slave.usage"
+    dialog.printf(gettext("\n"));
+    dialog.printf(gettext("Common options:\n"));
+    dialog.printf(gettext("   -i <named pipe> pipe to use instead of std input to read orders from dar\n"));
+    dialog.printf(gettext("   -o <named pipe> pipe to use instead of std output to write data to dar\n"));
+    dialog.printf(gettext("   -E <string>\t   command line to execute between slices of the archive\n"));
+    dialog.printf(gettext("\n"));
+    dialog.printf(gettext("See man page for more options.\n"));
 }
 
-static void show_version(user_interaction & dialog, const char *command)
+static void show_version(shell_interaction & dialog, const char *command)
 {
     string cmd;
     tools_extract_basename(command, cmd);
     U_I maj, med, min;
 
     get_version(maj, med, min);
-    shell_interaction_change_non_interactive_output(&cout);
+    dialog.change_non_interactive_output(&cout);
     dialog.printf("\n %s version %s Copyright (C) 2002-2052 Denis Corbin\n\n", cmd.c_str(), DAR_SLAVE_VERSION);
     if(maj > 2)
 	dialog.printf(gettext(" Using libdar %u.%u.%u built with compilation time options:\n"), maj, med, min);
