@@ -31,6 +31,10 @@ extern "C"
 #include <string.h>
 #endif
 
+#if HAVE_STRINGS_H
+#include <strings.h>
+#endif
+
 #include "getopt_decision.h"
 } // end extern "C"
 
@@ -38,7 +42,7 @@ extern "C"
 #include <new>
 
 #include "sar.hpp"
-#include "sar_tools.hpp"
+#include "trivial_sar.hpp"
 #include "user_interaction.hpp"
 #include "tools.hpp"
 #include "tuyau.hpp"
@@ -49,14 +53,16 @@ extern "C"
 #include "thread_cancellation.hpp"
 #include "header.hpp"
 #include "line_tools.hpp"
+#include "entrepot_local.hpp"
+#include "macro_tools.hpp"
 
 using namespace libdar;
 
-#define DAR_XFORM_VERSION "1.5.6"
+#define DAR_XFORM_VERSION "1.5.8"
 
 #define OPT_STRING  "s:S:p::wnhbVE:F:a::Qj^:3:9:"
 
-static bool command_line(user_interaction & dialog,
+static bool command_line(shell_interaction & dialog,
 			 S_I argc, char * const argv[],
                          path * & src_dir, string & src,
                          path * & dst_dir, string & dst,
@@ -75,9 +81,9 @@ static bool command_line(user_interaction & dialog,
 			 infinint & src_min_digits,
 			 infinint & dst_min_digits);
 
-static void show_usage(user_interaction & dialog, const char *command_name);
-static void show_version(user_interaction & dialog, const char *command_name);
-static S_I sub_main(user_interaction & dialog, S_I argc, char *const argv[], const char **env);
+static void show_usage(shell_interaction & dialog, const char *command_name);
+static void show_version(shell_interaction & dialog, const char *command_name);
+static S_I sub_main(shell_interaction & dialog, S_I argc, char *const argv[], const char **env);
 
 int main(S_I argc, char *const argv[], const char **env)
 {
@@ -86,15 +92,16 @@ int main(S_I argc, char *const argv[], const char **env)
 			    env,
 			    OPT_STRING,
 #if HAVE_GETOPT_LONG
-			    NULL,
+			    nullptr,
 #endif
+			    '\0', // should never be met as option, thus early read the whole command-line for -j and -Q options
 			    &sub_main);
 }
 
-static S_I sub_main(user_interaction & dialog, S_I argc, char * const argv[], const char **env)
+static S_I sub_main(shell_interaction & dialog, S_I argc, char * const argv[], const char **env)
 {
-    path *src_dir = NULL;
-    path *dst_dir = NULL;
+    path *src_dir = nullptr;
+    path *dst_dir = nullptr;
     string src, dst;
     infinint first, size;
     bool warn, allow, beep;
@@ -115,77 +122,124 @@ static S_I sub_main(user_interaction & dialog, S_I argc, char * const argv[], co
 			warn, allow, pause, beep, execute_src, execute_dst, slice_perm, slice_user, slice_group, hash,
 			src_min_digits, dst_min_digits))
 	{
-	    generic_file *dst_sar = NULL;
-	    generic_file *src_sar = NULL;
+	    generic_file *dst_sar = nullptr;
+	    generic_file *src_sar = nullptr;
 	    label data_name;
+	    label internal_name;
+	    entrepot_local entrep = entrepot_local(slice_user, slice_group, false);
 	    bool format_07_compatible = false;
+	    bool force_perm = slice_perm != "";
+	    U_I perm = force_perm ? tools_octal2int(slice_perm) : 0;
 
 	    data_name.clear();
+	    internal_name.generate_internal_filename();
 	    try
 	    {
 		if(dst != "-")
 		{
-		    shell_interaction_change_non_interactive_output(&cout);
-		    tools_avoid_slice_overwriting_regex(dialog,  dst_dir->display(), string("^")+dst+"\\.[0-9]+\\."+EXTENSION+"(\\.(md5|sha1))?$", false, allow, warn, false);
+		    dialog.change_non_interactive_output(&cout);
+		    tools_avoid_slice_overwriting_regex(dialog,
+							dst_dir->display(), string("^")+dst+"\\.[0-9]+\\."+EXTENSION+"(\\.(md5|sha1))?$",
+							false,
+							allow,
+							warn,
+							false);
 		}
 
 		thr.check_self_cancellation();
 
-		shell_interaction_set_beep(beep);
+		dialog.set_beep(beep);
 		if(src == "-")
 		{
 		    trivial_sar *tmp_sar = new (nothrow) trivial_sar(dialog, src, false);
-		    if(tmp_sar == NULL)
+		    if(tmp_sar == nullptr)
 			throw Ememory("sub_main");
 		    format_07_compatible = tmp_sar->is_an_old_start_end_archive();
 
 		    src_sar = tmp_sar;
-		    if(src_sar != NULL)
+		    if(src_sar != nullptr)
 			data_name = tmp_sar->get_data_name();
 		    else
 			throw SRC_BUG;
 		}
 		else 	// source not from a pipe
 		{
-		    sar *tmp_sar = new (nothrow) sar(dialog, src, EXTENSION, *src_dir, false, src_min_digits, false, execute_src);
-		    if(tmp_sar == NULL)
+		    if(src_dir != nullptr)
+			entrep.set_location(*src_dir);
+		    else
+			throw SRC_BUG;
+
+		    sar *tmp_sar = new (nothrow) sar(dialog, src, EXTENSION, entrep, false, src_min_digits, false, execute_src);
+		    if(tmp_sar == nullptr)
 			throw Ememory("main");
 		    else
 			tmp_sar->set_info_status(CONTEXT_OP);
 		    format_07_compatible = tmp_sar->is_an_old_start_end_archive();
 		    src_sar = tmp_sar;
-		    if(src_sar != NULL)
+		    if(src_sar != nullptr)
 			data_name = tmp_sar->get_data_name();
 		    else
 			throw SRC_BUG;
 		}
 
-		if(size == 0)
+		if(size.is_zero())
 		    if(dst == "-")
-			dst_sar = sar_tools_open_archive_tuyau(dialog, 1, gf_write_only, data_name,
-							       format_07_compatible, execute_dst);
+			dst_sar = macro_tools_open_archive_tuyau(dialog,
+								 nullptr,
+								 1,
+								 gf_write_only,
+								 internal_name,
+								 data_name,
+								 format_07_compatible,
+								 execute_dst);
 		    else
+		    {
+			if(dst_dir != nullptr)
+			    entrep.set_location(*dst_dir);
+			else
+			    throw SRC_BUG;
 			dst_sar = new (nothrow) trivial_sar(dialog,
+							    gf_write_only,
 							    dst,
 							    EXTENSION,
-							    *dst_dir,
+							    entrep,
+							    internal_name,
 							    data_name,
 							    execute_dst,
 							    allow,
 							    warn,
-							    slice_perm,
-							    slice_user,
-							    slice_group,
+							    force_perm,
+							    perm,
 							    hash,
 							    dst_min_digits,
 							    format_07_compatible);
+		    }
 		else
-		    dst_sar = new (nothrow) sar(dialog, dst, EXTENSION, size, first, warn, allow, pause,
-						*dst_dir, data_name, slice_perm, slice_user, slice_group,
-						hash, dst_min_digits,
+		{
+		    if(dst_dir != nullptr)
+			entrep.set_location(*dst_dir);
+		    else
+			throw SRC_BUG;
+		    dst_sar = new (nothrow) sar(dialog,
+						gf_write_only,
+						dst,
+						EXTENSION,
+						size,
+						first,
+						warn,
+						allow,
+						pause,
+						entrep,
+						internal_name,
+						data_name,
+						force_perm,
+						perm,
+						hash,
+						dst_min_digits,
 						format_07_compatible,
 						execute_dst);
-		if(dst_sar == NULL)
+		}
+		if(dst_sar == nullptr)
 		    throw Ememory("main");
 
 		thr.check_self_cancellation();
@@ -218,15 +272,15 @@ static S_I sub_main(user_interaction & dialog, S_I argc, char * const argv[], co
 	    }
 	    catch(...)
 	    {
-		if(dst_sar != NULL)
+		if(dst_sar != nullptr)
 		    delete dst_sar;
-		if(src_sar != NULL)
+		if(src_sar != nullptr)
 		    delete src_sar;
 		throw;
 	    }
-	    if(src_sar != NULL)
+	    if(src_sar != nullptr)
 		delete src_sar;
-	    if(dst_sar != NULL)
+	    if(dst_sar != nullptr)
 		delete dst_sar;
 
 	    ret = EXIT_OK;
@@ -236,20 +290,20 @@ static S_I sub_main(user_interaction & dialog, S_I argc, char * const argv[], co
     }
     catch(...)
     {
-	if(src_dir != NULL)
+	if(src_dir != nullptr)
 	    delete src_dir;
-	if(dst_dir != NULL)
+	if(dst_dir != nullptr)
 	    delete dst_dir;
 	throw;
     }
-    if(src_dir != NULL)
+    if(src_dir != nullptr)
 	delete src_dir;
-    if(dst_dir != NULL)
+    if(dst_dir != nullptr)
 	delete dst_dir;
     return ret;
 }
 
-static bool command_line(user_interaction & dialog, S_I argc, char * const argv[],
+static bool command_line(shell_interaction & dialog, S_I argc, char * const argv[],
                          path * & src_dir, string & src,
                          path * & dst_dir, string & dst,
                          infinint & first_file_size,
@@ -268,8 +322,8 @@ static bool command_line(user_interaction & dialog, S_I argc, char * const argv[
 			 infinint & dst_min_digits)
 {
     S_I lu;
-    src_dir = NULL;
-    dst_dir = NULL;
+    src_dir = nullptr;
+    dst_dir = nullptr;
     warn = true;
     allow = true;
     pause = 0;
@@ -293,16 +347,16 @@ static bool command_line(user_interaction & dialog, S_I argc, char * const argv[
             switch(lu)
             {
             case 's':
-                if(file_size != 0)
+                if(!file_size.is_zero())
                     throw Erange("command_line", gettext("Only one -s option is allowed"));
-                if(optarg == NULL)
+                if(optarg == nullptr)
                     throw Erange("command_line", gettext("Missing argument to -s"));
                 else
                 {
                     try
                     {
                         file_size = tools_get_extended_size(optarg, suffix_base);
-                        if(first_file_size == 0)
+                        if(first_file_size.is_zero())
                             first_file_size = file_size;
                     }
                     catch(Edeci &e)
@@ -313,12 +367,12 @@ static bool command_line(user_interaction & dialog, S_I argc, char * const argv[
                 }
                 break;
             case 'S':
-                if(optarg == NULL)
+                if(optarg == nullptr)
                     throw Erange("command_line", gettext("Missing argument to -S"));
-                if(first_file_size == 0)
+                if(first_file_size.is_zero())
                     first_file_size = tools_get_extended_size(optarg, suffix_base);
                 else
-                    if(file_size == 0)
+                    if(file_size.is_zero())
                         throw Erange("command_line", gettext("Only one -S option is allowed"));
                     else
                         if(file_size == first_file_size)
@@ -340,7 +394,7 @@ static bool command_line(user_interaction & dialog, S_I argc, char * const argv[
                             throw Erange("command_line", gettext("Only one -S option is allowed"));
                 break;
             case 'p':
-		if(optarg != NULL)
+		if(optarg != nullptr)
 		{
 			// note that the namespace specification is necessary
 			// due to similar existing name in std namespace under
@@ -367,7 +421,7 @@ static bool command_line(user_interaction & dialog, S_I argc, char * const argv[
                 show_version(dialog, argv[0]);
                 return false;
             case 'E':
-                if(optarg == NULL)
+                if(optarg == nullptr)
                     throw Erange("command_line", gettext("Missing argument to -E"));
                 if(execute_dst == "")
                     execute_dst = optarg;
@@ -375,7 +429,7 @@ static bool command_line(user_interaction & dialog, S_I argc, char * const argv[
 		    execute_dst += string(" ; ") + optarg;
                 break;
             case 'F':
-                if(optarg == NULL)
+                if(optarg == nullptr)
                     throw Erange("command_line", gettext("Missing argument to -F"));
                 if(execute_src == "")
                     execute_src = optarg;
@@ -383,7 +437,7 @@ static bool command_line(user_interaction & dialog, S_I argc, char * const argv[
 		    execute_src += string(" ; ") + optarg;
                 break;
 	    case 'a':
-		if(optarg == NULL)
+		if(optarg == nullptr)
 		    throw Erange("command_line", gettext("-a option requires an argument"));
 		if(strcasecmp("SI-unit", optarg) == 0 || strcasecmp("SI", optarg) == 0 || strcasecmp("SI-units", optarg) == 0)
 		    suffix_base = TOOLS_SI_SUFFIX;
@@ -394,15 +448,14 @@ static bool command_line(user_interaction & dialog, S_I argc, char * const argv[
 			throw Erange("command_line", string(gettext("Unknown parameter given to -a option: ")) + optarg);
 		break;
 	    case 'Q':
-	    case 'j':
 		break;  // ignore this option already parsed during initialization (dar_suite.cpp)
 	    case '^':
-		if(optarg == NULL)
+		if(optarg == nullptr)
 		    throw Erange("command_line", tools_printf(gettext("Missing argument to -^"), char(lu)));
 		line_tools_slice_ownership(string(optarg), slice_perm, slice_user, slice_group);
 		break;
 	    case '3':
-		if(optarg == NULL)
+		if(optarg == nullptr)
 		    throw Erange("command_line", tools_printf(gettext("Missing argument to --hash"), char(lu)));
 		if(strcasecmp(optarg, "md5") == 0)
 		    hash = hash_md5;
@@ -413,7 +466,7 @@ static bool command_line(user_interaction & dialog, S_I argc, char * const argv[
 			throw Erange("command_line", string(gettext("Unknown parameter given to --hash option: ")) + optarg);
 		break;
 	    case '9':
-		if(optarg == NULL)
+		if(optarg == nullptr)
 		    throw Erange("command_line", tools_printf(gettext("Missing argument to --min-digits"), char(lu)));
 		else
 		{
@@ -461,42 +514,62 @@ static bool command_line(user_interaction & dialog, S_I argc, char * const argv[
         }
 
             // sanity checks
-        if(dst == "-" && file_size != 0)
+        if(dst == "-" && !file_size.is_zero())
             throw Erange("dar_xform::command_line", gettext("Archive on stdout is not compatible with slicing (-s option)"));
     }
     catch(...)
     {
-        if(src_dir != NULL)
+        if(src_dir != nullptr)
             delete src_dir;
-	src_dir = NULL;
-        if(dst_dir != NULL)
+	src_dir = nullptr;
+        if(dst_dir != nullptr)
             delete dst_dir;
-	dst_dir = NULL;
+	dst_dir = nullptr;
         throw;
     }
     return true;
 }
 
-static void show_usage(user_interaction & dialog, const char *command_name)
+static void show_usage(shell_interaction & dialog, const char *command_name)
 {
     string name;
     tools_extract_basename(command_name, name);
-    shell_interaction_change_non_interactive_output(&cout);
+    dialog.change_non_interactive_output(&cout);
 
     dialog.printf("usage :\t %s [options] [<path>/]<basename> [<path>/]<basename>\n", name.c_str());
     dialog.printf("       \t %s -h\n",name.c_str());
     dialog.printf("       \t %s -V\n",name.c_str());
-#include "dar_xform.usage"
+    dialog.printf(gettext("\n"));
+    dialog.printf(gettext("\t\t   the first non options argument is the archive to read\n"));
+    dialog.printf(gettext("\n"));
+    dialog.printf(gettext("\t\t   the second non option argument is the archive to create\n"));
+    dialog.printf(gettext("\n"));
+    dialog.printf(gettext("Common options:\n"));
+    dialog.printf(gettext("   -h\t\t   displays this help information\n"));
+    dialog.printf(gettext("   -V\t\t   displays version information\n"));
+    dialog.printf(gettext("   -s <integer>    split the archive in several files of size <integer>\n"));
+    dialog.printf(gettext("   -S <integer>    first file size\n"));
+    dialog.printf(gettext("   -p\t\t   pauses before writing to a new file\n"));
+    dialog.printf(gettext("   -n\t\t   don't overwrite files\n"));
+    dialog.printf(gettext("   -w\t\t   don't warn before overwriting files\n"));
+    dialog.printf(gettext("   -b\t\t   ring the terminal bell when user action is required\n"));
+    dialog.printf(gettext("   -E <string>\t   command to execute between slices of destination archive\n"));
+    dialog.printf(gettext("   -F <string>\t   command to execute between slice of source archive\n"));
+    dialog.printf(gettext("   -aSI \t   slice size suffixes k, M, T, G, etc. are power of 10\n"));
+    dialog.printf(gettext("   -abinary\t   slice size suffixes k, M, T, G, etc. are power of 2\n"));
+    dialog.printf(gettext("   -^ <string>\t   permission[:user[:group]] of created slices\n"));
+    dialog.printf(gettext("\n"));
+    dialog.printf(gettext("See man page for more options.\n"));
 }
 
-static void show_version(user_interaction & dialog, const char *command_name)
+static void show_version(shell_interaction & dialog, const char *command_name)
 {
     string name;
     tools_extract_basename(command_name, name);
     U_I maj, med, min;
 
     get_version(maj, med, min);
-    shell_interaction_change_non_interactive_output(&cout);
+    dialog.change_non_interactive_output(&cout);
 
     dialog.printf("\n %s version %s, Copyright (C) 2002-2052 Denis Corbin\n\n", name.c_str(), DAR_XFORM_VERSION);
     if(maj > 2)
