@@ -37,12 +37,14 @@ extern "C"
 
 #include <new>
 #include <algorithm>
+#include <vector>
+#include <string>
 
 #include "line_tools.hpp"
 #include "deci.hpp"
 #include "erreurs.hpp"
 #include "tools.hpp"
-#include "fichier.hpp"
+#include "fichier_local.hpp"
 
 using namespace std;
 using namespace libdar;
@@ -56,26 +58,26 @@ argc_argv::argc_argv(S_I size)
     if(x_argc > 0)
     {
 	x_argv = new (nothrow) char *[size];
-	if(x_argv == NULL)
+	if(x_argv == nullptr)
 	    throw Ememory("argc_argv::argc_argv");
 
 	for(S_I i = 0; i < x_argc; i++)
-	    x_argv[i] = NULL;
+	    x_argv[i] = nullptr;
     }
     else
-	x_argv = NULL;
+	x_argv = nullptr;
 }
 
 argc_argv::~argc_argv()
 {
-    if(x_argv == NULL && x_argc > 0)
+    if(x_argv == nullptr && x_argc > 0)
 	throw SRC_BUG;
 
     for(S_I i = 0; i < x_argc; i++)
-	if(x_argv[i] != NULL)
+	if(x_argv[i] != nullptr)
 	{
 	    delete [] x_argv[i];
-	    x_argv[i] = NULL;
+	    x_argv[i] = nullptr;
 	}
 
     if(x_argc > 0)
@@ -87,14 +89,14 @@ void argc_argv::set_arg(const string & arg, S_I index)
     if(index >= x_argc)
 	throw Erange("argc_argv::set_arg", gettext("Index out of range"));
 
-    if(x_argv[index] != NULL)
+    if(x_argv[index] != nullptr)
     {
 	delete [] x_argv[index];
-	x_argv[index] = NULL;
+	x_argv[index] = nullptr;
     }
 
     x_argv[index] = new (nothrow) char[arg.size() + 1];
-    if(x_argv[index] == NULL)
+    if(x_argv[index] == nullptr)
 	throw Ememory("argc_argv::set_arg");
     strncpy(x_argv[index], arg.c_str(), arg.size());
     x_argv[index][arg.size()] = '\0';
@@ -105,14 +107,14 @@ void argc_argv::set_arg(generic_file & f, U_I size, S_I index)
     if(index >= x_argc)
 	throw Erange("argc_argv::set_arg", gettext("Index out of range"));
 
-    if(x_argv[index] != NULL)
+    if(x_argv[index] != nullptr)
     {
 	delete [] x_argv[index];
-	x_argv[index] = NULL;
+	x_argv[index] = nullptr;
     }
 
     x_argv[index] = new (nothrow) char [size+1];
-    if(x_argv[index] == NULL)
+    if(x_argv[index] == nullptr)
 	throw Ememory("argc_argv::set_arg");
 
     x_argv[index][f.read(x_argv[index], size)] = '\0';
@@ -120,21 +122,21 @@ void argc_argv::set_arg(generic_file & f, U_I size, S_I index)
 
 void argc_argv::resize(S_I size)
 {
-    char **tmp = NULL;
+    char **tmp = nullptr;
 
     if(size == x_argc)
 	return;
 
     if(size < x_argc)
 	for(S_I i = size; i < x_argc; i++)
-	    if(x_argv[i] != NULL)
+	    if(x_argv[i] != nullptr)
 	    {
 		delete [] x_argv[i];
-		x_argv[i] = NULL;
+		x_argv[i] = nullptr;
 	    }
 
     tmp = new (nothrow) char*[size];
-    if(tmp == NULL)
+    if(tmp == nullptr)
 	throw Ememory("argc_argv::resize");
 
     try
@@ -145,17 +147,17 @@ void argc_argv::resize(S_I size)
 	    tmp[i] = x_argv[i];
 
 	for(S_I i = min; i < size; i++)
-	    tmp[i] = NULL;
+	    tmp[i] = nullptr;
 
 	if(x_argc > 0)
 	    delete [] x_argv;
 	x_argv = tmp;
-	tmp = NULL;
+	tmp = nullptr;
 	x_argc = size;
     }
     catch(...)
     {
-	if(tmp != NULL)
+	if(tmp != nullptr)
 	    delete [] tmp;
 	throw;
     }
@@ -236,9 +238,9 @@ void line_tools_repeat_param(const string & cmd, infinint & repeat_count, infini
     }
 }
 
-void line_tools_tlv_list2argv(user_interaction & dialog, const tlv_list & list, argc_argv & arg)
+void line_tools_tlv_list2argv(user_interaction & dialog, tlv_list & list, argc_argv & arg)
 {
-    memory_file mem = memory_file(gf_read_write);
+    memory_file mem = memory_file();
     U_I transfert = 0;
     infinint size;
 
@@ -246,14 +248,15 @@ void line_tools_tlv_list2argv(user_interaction & dialog, const tlv_list & list,
     for(S_I i = 0; i < arg.argc() ; i++)
     {
 	if(list[i].get_type() != 0)
+		// we only use type 0 here
 	    throw Erange("line_tools_tlv_list2argv", gettext("Unknown TLV record type"));
-	list[i].get_contents(mem);
+	size = list[i].size();
 	transfert = 0;
-	size = mem.get_data_size();
 	size.unstack(transfert);
-	if(size != 0)
+	if(!size.is_zero())
 	    throw Erange("line_tools_tlv_list2argv", "Too long argument found in TLV to be handled by standard library routine");
-	arg.set_arg(mem, transfert, i);
+	list[i].skip(0);
+	arg.set_arg(list[i], transfert, i);
     }
 }
 
@@ -407,7 +410,7 @@ vector<string> line_tools_explode_PATH(const char *the_path)
     const char *last = it;
 
     ret.clear();
-    if(it == NULL)
+    if(it == nullptr)
 	return ret;
 
     while(*it != '\0')
@@ -431,9 +434,8 @@ string line_tools_get_full_path_from_PATH(const vector<string> & the_path, const
 {
     string ret;
     bool no_path = false;
-    user_interaction_blind aveugle;
 
-    if(filename == NULL)
+    if(filename == nullptr)
 	throw SRC_BUG;
     else
     {
@@ -471,7 +473,7 @@ string line_tools_get_full_path_from_PATH(const vector<string> & the_path, const
 	    {
 		string where = (path(*it) + filename).display();
 
-		fichier tmp = fichier(aveugle, where, gf_read_only, tools_octal2int("0777"), false);
+		fichier_local tmp = fichier_local(where, false);
 		found = true;
 		ret = where;
 	    }
@@ -492,7 +494,7 @@ void line_tools_split_at_first_space(const char *field, string & before_space, s
 {
     const char *ptr = field;
 
-    if(field == NULL)
+    if(field == nullptr)
 	throw SRC_BUG;
     while(*ptr != ' ' && *ptr != '\0')
 	++ptr;
@@ -589,6 +591,7 @@ void line_tools_look_for(const vector<char> & arguments,
 #if HAVE_GETOPT_LONG
 			 const struct option *long_options,
 #endif
+			 char stop_scan,
 			 vector<char> & presence)
 {
     S_I lu;
@@ -597,13 +600,13 @@ void line_tools_look_for(const vector<char> & arguments,
     (void)line_tools_reset_getopt();
 #if HAVE_GETOPT_LONG
     const struct option *ptr_long_opt = long_options;
-    const struct option voided = { NULL, 0, NULL, 0 };
-    if(long_options == NULL)
+    const struct option voided = { nullptr, 0, nullptr, 0 };
+    if(long_options == nullptr)
 	ptr_long_opt = &voided;
 
-    while((lu = getopt_long(argc, argv, getopt_string, ptr_long_opt, NULL)) != EOF)
+    while((lu = getopt_long(argc, argv, getopt_string, ptr_long_opt, nullptr)) != EOF && stop_scan != lu)
 #else
-	while((lu = getopt(argc, argv, getopt_string)) != EOF)
+	while((lu = getopt(argc, argv, getopt_string)) != EOF && stop_scan != lu)
 #endif
 	{
 	    vector<char>::const_iterator it = find(arguments.begin(), arguments.end(), (char)lu);
@@ -614,20 +617,19 @@ void line_tools_look_for(const vector<char> & arguments,
     (void)line_tools_reset_getopt();
 }
 
-void line_tools_look_for_jQ(S_I argc,
-			    char *const argv[],
-			    const char *getopt_string,
+void line_tools_look_for_Q(S_I argc,
+			   char *const argv[],
+			   const char *getopt_string,
 #if HAVE_GETOPT_LONG
-			    const struct option *long_options,
+			   const struct option *long_options,
 #endif
-			    bool & j_is_present,
+			    char stop_scan,
 			    bool & Q_is_present)
 {
     vector<char> arguments;
     vector<char> presence;
     vector<char>::const_iterator it;
 
-    j_is_present = false;
     Q_is_present = false;
 
     arguments.push_back('j');
@@ -639,17 +641,256 @@ void line_tools_look_for_jQ(S_I argc,
 #if HAVE_GETOPT_LONG
 			long_options,
 #endif
+			stop_scan,
 			presence);
 
-    it = find(presence.begin(), presence.end(), 'j');
-    if(it != presence.end())
-	j_is_present = true;
-
     it = find(presence.begin(), presence.end(), 'Q');
     if(it != presence.end())
 	Q_is_present = true;
 }
 
+
+vector<string> line_tools_split(const string & val, char sep)
+{
+    vector<string> ret;
+    string::const_iterator be = val.begin();
+    string::const_iterator ne = val.begin();
+
+    while(ne != val.end())
+    {
+	if(*ne != sep)
+	    ++ne;
+	else
+	{
+	    ret.push_back(string(be, ne));
+	    ++ne;
+	    be = ne;
+	}
+    }
+
+    if(be != val.end())
+	ret.push_back(string(be, ne));
+
+    return ret;
+}
+
+void line_tools_4_4_build_compatible_overwriting_policy(bool allow_over,
+							bool detruire,
+							bool more_recent,
+							const infinint & hourshift,
+							bool ea_erase,
+							const crit_action * & overwrite)
+{
+    crit_action *tmp1 = nullptr;
+    crit_action *tmp2 = nullptr; // tmp1 and tmp2 are used for construction of the overwriting policy
+    overwrite = nullptr;
+
+    try
+    {
+	if(allow_over)
+	{
+	    if(ea_erase)
+		overwrite = new crit_constant_action(data_overwrite, EA_overwrite);
+	    else
+		overwrite = new crit_constant_action(data_overwrite, EA_merge_overwrite);
+	    if(overwrite == nullptr)
+		throw Ememory("tools_build_compatible_overwriting_policy");
+
+	    tmp1 = new crit_constant_action(data_preserve, EA_preserve);
+	    if(tmp1 == nullptr)
+		throw Ememory("tools_build_compatible_overwriting_policy");
+
+	    if(more_recent)
+	    {
+		tmp2 = new testing(crit_invert(crit_in_place_data_more_recent(hourshift)), *overwrite, *tmp1);
+		if(tmp2 == nullptr)
+		    throw Ememory("tools_build_compatible_overwriting_policy");
+
+		delete overwrite;
+		overwrite = tmp2;
+		tmp2 = nullptr;
+	    }
+
+	    if(!detruire)
+	    {
+		tmp2 = new testing(crit_invert(crit_in_place_is_inode()), *overwrite, *tmp1);
+		if(tmp2 == nullptr)
+		    throw Ememory("tools_build_compatible_overwriting_policy");
+		delete overwrite;
+		overwrite = tmp2;
+		tmp2 = nullptr;
+	    }
+
+	    delete tmp1;
+	    tmp1 = nullptr;
+	}
+	else
+	{
+	    overwrite = new crit_constant_action(data_preserve, EA_preserve);
+	    if(overwrite == nullptr)
+		throw Ememory("tools_build_compatible_overwriting_policy");
+	}
+
+	if(overwrite == nullptr)
+	    throw SRC_BUG;
+	if(tmp1 != nullptr)
+	    throw SRC_BUG;
+	if(tmp2 != nullptr)
+	    throw SRC_BUG;
+    }
+    catch(...)
+    {
+	if(tmp1 != nullptr)
+	    delete tmp1;
+	if(tmp2 != nullptr)
+	    delete tmp2;
+	if(overwrite != nullptr)
+	{
+	    delete overwrite;
+	    overwrite = nullptr;
+	}
+	throw;
+    }
+}
+
+void line_tools_crypto_split_algo_pass(const secu_string & all,
+				       crypto_algo & algo,
+				       secu_string & pass,
+				       bool & no_cipher_given,
+				       vector<string> & recipients)
+{
+	// split from "algo:pass" "algo" "pass" "algo:" ":pass" syntaxes
+
+    const char *it = all.c_str();
+    const char *fin = all.c_str() + all.get_size(); // points past the last byte of the secu_string "all"
+    secu_string tmp;
+    recipients.clear();
+
+    if(all.get_size() == 0)
+    {
+	algo = crypto_none;
+	pass.clear();
+    }
+    else
+    {
+	while(it != fin && *it != ':')
+	    ++it;
+
+	if(it != fin) // a ':' is present in the given string
+	{
+		// tmp holds the string before ':'
+	    tmp = secu_string(all.c_str(), it - all.c_str());
+	    ++it;
+
+		// pass holds the string after ':'
+	    pass = secu_string(it, fin - it);
+
+	    no_cipher_given = (tmp == "");
+
+	    if(tmp == "scrambling" || tmp == "scram")
+		algo = crypto_scrambling;
+	    else
+		if(tmp == "none")
+		    algo = crypto_none;
+		else
+		    if(tmp == "blowfish" || tmp == "bf" || tmp == "")
+			algo = crypto_blowfish; // blowfish is the default cypher ("")
+		    else
+			if(tmp == "aes" || tmp == "aes256")
+			    algo = crypto_aes256;
+			else
+			    if(tmp == "twofish" || tmp == "twofish256")
+				algo = crypto_twofish256;
+			    else
+				if(tmp == "serpent" || tmp == "serpent256")
+				    algo = crypto_serpent256;
+				else
+				    if(tmp == "camellia" || tmp == "camellia256")
+					algo = crypto_camellia256;
+				    else
+					if(tmp == "gnupg")
+					{
+					    secu_string emails;
+					    line_tools_crypto_split_algo_pass(pass, algo, emails, no_cipher_given, recipients);
+					    recipients = line_tools_split(emails.c_str(), ',');
+					    pass.clear();
+					}
+					else
+					    throw Erange("crypto_split_algo_pass", string(gettext("unknown cryptographic algorithm: ")) + tmp.c_str());
+	}
+	else // no ':' using blowfish as default cypher
+	{
+	    no_cipher_given = true;
+	    algo = crypto_blowfish;
+	    pass = all;
+	}
+    }
+}
+
+void line_tools_display_signatories(user_interaction & ui, const list<signator> & gnupg_signed)
+{
+    list<signator>::const_iterator it = gnupg_signed.begin();
+    string tmp;
+
+    if(gnupg_signed.empty())
+	return;
+
+    ui.printf(        "+-----------------+----------------+----------------------------------------+-------------------------+");
+    ui.printf(gettext("| Signature Status|  Key Status    |  Finger Print                          | Signature Date          |"));
+    ui.printf(        "+-----------------+----------------+----------------------------------------+-------------------------+");
+    while(it != gnupg_signed.end())
+    {
+	tmp = "";
+
+	switch(it->result)
+	{
+	case signator::good:
+	    tmp += "|      Good       |";
+	    break;
+	case signator::bad:
+	    tmp += "|    BAD !!!      |";
+	    break;
+	case signator::unknown_key:
+	    tmp += "|   Unknown Key   |";
+	    break;
+	case signator::error:
+	    tmp += "|  System Error   |";
+	    break;
+	default:
+	    throw SRC_BUG;
+	}
+
+	switch(it->key_validity)
+	{
+	case signator::valid:
+	    tmp += "    Valid       |";
+	    break;
+	case signator::expired:
+	    tmp += "   EXPIRED      |";
+	    break;
+	case signator::revoked:
+	    tmp += "   REVOKED      |";
+	    break;
+	default:
+	    throw SRC_BUG;
+	}
+	tmp += it->fingerprint + "|";
+	tmp += tools_display_date(it->signing_date) + " |";
+	ui.warning(tmp);
+	if(it->key_validity == signator::expired)
+	{
+	    tmp = "                  |" + tools_display_date(it->signature_expiration_date);
+	    ui.warning(tmp);
+	}
+
+	++it;
+    }
+    ui.printf("------------------+----------------+----------------------------------------+-------------------------+");
+    ui.printf(" For more information about a key, use the command: gpg --list-key <fingeprint>");
+}
+
+///////////////////
+
 static string build(string::iterator a, string::iterator b)
 {
     string ret = "";
