@@ -29,9 +29,11 @@
 #include "../my_config.h"
 
 #include <string>
+#include <vector>
 #include "infinint.hpp"
 #include "tlv_list.hpp"
 #include "integers.hpp"
+#include "criterium.hpp"
 
 using namespace libdar;
 
@@ -51,7 +53,7 @@ public:
     void set_arg(generic_file & f, U_I size, S_I index);
 
     S_I argc() const { return x_argc; };
-    char* const * argv() const { return x_argv; }; // well the const method is a bit silly, as the call has the possibility to modify what is pointed to by the returned value...
+    char* const * argv() const { return x_argv; }; // well, the const method is a bit silly, as the caller has the possibility to modify what is pointed to by the returned value...
 
 private:
     S_I x_argc;
@@ -60,7 +62,7 @@ private:
 
 extern void line_tools_slice_ownership(const std::string & cmd, std::string & slice_permission, std::string & slice_user_ownership, std::string & slice_group_ownership);
 extern void line_tools_repeat_param(const std::string & cmd, infinint & repeat_count, infinint & repeat_byte);
-extern void line_tools_tlv_list2argv(user_interaction & dialog, const tlv_list & list, argc_argv & arg);
+extern void line_tools_tlv_list2argv(user_interaction & dialog, tlv_list & list, argc_argv & arg);
 
     /// returns the old position of parsing (next argument to parse)
 extern S_I line_tools_reset_getopt();
@@ -89,8 +91,9 @@ void line_tools_get_min_digits(std::string arg, infinint & num, infinint & ref_n
     /// \param[in] argv is the list of arguments on the command line
     /// \param[in] getopt_string is the parsing string to pass to getopt
 #if HAVE_GETOPT_LONG
-    /// \param[in] long_options is the optional list of long options  (an NULL pointer is acceptable for no long option)
+    /// \param[in] long_options is the optional list of long options  (an nullptr pointer is acceptable for no long option)
 #endif
+    /// \param[in] stop_scan if this (char) option is met, stop scanning for wanted options
     /// \param[out] presence is a subset of arguments containing the option found on command-line
 extern void line_tools_look_for(const std::vector<char> & arguments,
 				S_I argc,
@@ -99,6 +102,7 @@ extern void line_tools_look_for(const std::vector<char> & arguments,
 #if HAVE_GETOPT_LONG
 				const struct option *long_options,
 #endif
+				char stop_scan,
 				std::vector<char> & presence);
 
 
@@ -108,20 +112,45 @@ extern void line_tools_look_for(const std::vector<char> & arguments,
     /// \param[in] argv is the list of arguments on the command line
     /// \param[in] getopt_string is the parsing string to pass to getopt
 #if HAVE_GETOPT_LONG
-    /// \param[in] long_options is the optional list of long options (an NULL pointer is acceptable for no long option)
+    /// \param[in] long_options is the optional list of long options (an nullptr pointer is acceptable for no long option)
 #endif
-    /// \param[out] j_is_present is set to true if -j option or its equivalent long option has been found on command-line
+    /// \param[in] stop_scan if this (char) option is met, stop scanning for -j and -Q options
     /// \param[out] Q_is_present is set to true if -Q option or its equivalent long option has been found on command-line
-extern void line_tools_look_for_jQ(S_I argc,
+extern void line_tools_look_for_Q(S_I argc,
 				   char *const argv[],
 				   const char *getopt_string,
 #if HAVE_GETOPT_LONG
 				   const struct option *long_options,
 #endif
-				   bool & j_is_present,
+				   char stop_scan,
 				   bool & Q_is_present);
 
 
+    /// split a line in words given the separator character (sep)
+
+extern std::vector<std::string> line_tools_split(const std::string & val, char sep);
+
+extern void line_tools_4_4_build_compatible_overwriting_policy(bool allow_over,
+							       bool detruire,
+							       bool more_recent,
+							       const libdar::infinint & hourshift,
+							       bool ea_erase,
+							       const libdar::crit_action * & overwrite);
+
+    /// split the argument to -K, -J and -$ in their different parts
+    /// \param[in] all is what the user provided on command-line
+    /// \param[out] algo is the symmetrical algorithm to use
+    /// \param[out] pass is either the passphrase
+    /// \param[out] no_cipher_given is true if the use did not specified the cipher (which defaults to blowfish)
+    /// \param[out] recipients emails recipients to use (empty list if gnupg has not to be used)
+extern void line_tools_crypto_split_algo_pass(const secu_string & all,
+					      crypto_algo & algo,
+					      secu_string & pass,
+					      bool & no_cipher_given,
+					      std::vector<std::string> & recipients);
+
+    /// display information about the signatories
+extern void line_tools_display_signatories(user_interaction & ui, const std::list<signator> & gnupg_signed);
 
     /// @}
 
