@@ -39,7 +39,7 @@ extern "C"
 using namespace libdar;
 using namespace std;
 
-int little_main(user_interaction & ui, S_I argc, char * const argv[], const char **env);
+int little_main(shell_interaction & ui, S_I argc, char * const argv[], const char **env);
 
 int main(S_I argc, char * const argv[], const char **env)
 {
@@ -47,11 +47,12 @@ int main(S_I argc, char * const argv[], const char **env)
 			    argv,
 			    env,
 			    "",
-			    NULL,
+			    nullptr,
+			    '\0',
 			    &little_main);
 }
 
-int little_main(user_interaction & ui, S_I argc, char * const argv[], const char **env)
+int little_main(shell_interaction & ui, S_I argc, char * const argv[], const char **env)
 {
     if(argc != 2)
     {
