@@ -1,4 +1,4 @@
-//*********************************************************************/
+/*********************************************************************/
 // dar - disk archive - a backup/restoration program
 // Copyright (C) 2002-2052 Denis Corbin
 //
@@ -29,6 +29,7 @@
 
 #include "../my_config.h"
 #include <vector>
+#include <string>
 
 #include "erreurs.hpp"
 #include "path.hpp"
@@ -39,6 +40,9 @@
 #include "escape_catalogue.hpp"
 #include "pile.hpp"
 #include "list_entry.hpp"
+#include "on_pool.hpp"
+#include "crypto.hpp"
+#include "slice_layout.hpp"
 
 namespace libdar
 {
@@ -49,7 +53,7 @@ namespace libdar
 	/// are the same abstraction level as the operation realized by the DAR
 	/// command line tool.
 	/// \ingroup API
-    class archive
+    class archive : public on_pool
     {
     public:
 
@@ -76,7 +80,7 @@ namespace libdar
 	    /// \param[in] filename base name of the slices. If "-" is given the archive will be produced in standard output
 	    /// \param[in] extension slices extension ("dar")
 	    /// \param[in] options optional parameters to use for the operation
- 	    /// \param[out] progressive_report statistics about the operation, considering the treated files (NULL can be given if you don't want to use this feature)
+ 	    /// \param[out] progressive_report statistics about the operation, considering the treated files (nullptr can be given if you don't want to use this feature)
 	    /// \note the statistics fields used are:
 	    /// - .treated: the total number of files seen
 	    /// - .hard_link: the number of hard linked inodes
@@ -97,16 +101,10 @@ namespace libdar
 		statistics * progressive_report);
 
 
-	    /// this constructor isolates a catalogue of a given archive [this is the "isolate" constructor]
-
-	    /// \param[in,out] dialog for user interaction
-	    /// \param[in] sauv_path the path where to create slices
-	    /// \param[in] ref_arch the archive to take as reference (NULL for a full backup)
-	    /// \param[in] filename base name of the slices ("-" for standard output)
-	    /// \param[in] extension slices extension ("dar")
-	    /// \param[in] options optional parameters to use for the operation
+	    /// WARNING this is a deprecated constructor, use the op_isolate() method for better performances
+	    /// \note this method will be remove from the API in a future version of libdar
 	archive(user_interaction & dialog,
-		const path &sauv_path,
+		const path & sauv_path,
 		archive *ref_arch,
 		const std::string & filename,
 		const std::string & extension,
@@ -121,7 +119,7 @@ namespace libdar
 	    /// \param[in] filename base name of the slices. If "-" is given the archive will be produced in standard output
 	    /// \param[in] extension slices extension ("dar")
 	    /// \param[in] options optional parameters to be used for the operation
-	    /// \param[out] progressive_report statistics about the operation, considering the treated files (NULL can be given if you don't want to use this feature)
+	    /// \param[out] progressive_report statistics about the operation, considering the treated files (nullptr can be given if you don't want to use this feature)
 	    /// \note the statistics fields used are:
 	    /// - .treated: the total number of files seen
 	    /// - .hard_link: the number of hard linked inodes
@@ -149,7 +147,7 @@ namespace libdar
 	archive & operator = (const archive & ref) { throw Efeature(dar_gettext("Archive assignment operator is not implemented")); };
 
 	    /// the destructor
-	~archive() { free(); };
+	~archive() throw(Ebug) { free_all(); };
 
 
 	    /// extraction of data from an archive
@@ -159,7 +157,7 @@ namespace libdar
 	    /// \param[in] options optional parameter to be used for the operation
 	    /// \param[in,out] progressive_report points to an already existing statistics object that can be consulted at any time
 	    /// during the call (see the returned value to know the useful fields and their meining),
-	    /// NULL can be given in argument if you only need the result at the end of the operation through the returned value of this call
+	    /// nullptr can be given in argument if you only need the result at the end of the operation through the returned value of this call
 	    /// this should speed up the operation by a little amount.
 	    /// \return the statistics about the operation, considering the treated files
 	    /// \note the statistics fields used are:
@@ -203,7 +201,7 @@ namespace libdar
 	    /// \param[in] options optional parameters to be used with the operation
 	    /// \param[in,out] progressive_report points to an already existing statistics object that can be consulted at any time
 	    /// during the call (see the returned value to know the useful fields and their meining),
-	    /// NULL can be given in argument if you only need the result at the end of the operation through the returned value of this call
+	    /// nullptr can be given in argument if you only need the result at the end of the operation through the returned value of this call
 	    /// this should speed up the operation by a little amount.
 	    /// \return the statistics about the operation, considering the treated files
 	    /// \note the statistics fields used are:
@@ -223,7 +221,7 @@ namespace libdar
 	    /// \param[in] options optional parameter to use for the operation
 	    /// \param[in,out] progressive_report points to an already existing statistics object that can be consulted at any time
 	    /// during the call (see the returned value to know the useful fields and their meining),
-	    /// NULL can be given in argument if you only need the result at the end of the operation through the returned value of this call
+	    /// nullptr can be given in argument if you only need the result at the end of the operation through the returned value of this call
 	    /// this should speed up the operation by a little amount.
 	    /// \note op_test will generate an error message if used on an archive
 	    /// that has been created by the isolate or creation constructor
@@ -243,6 +241,20 @@ namespace libdar
 			   statistics * progressive_report);
 
 
+	    /// this methodes isolates the catalogue of a the current archive into a separated archive
+
+	    /// \param[in,out] dialog for user interaction
+	    /// \param[in] sauv_path the path where to create slices
+	    /// \param[in] filename base name of the slices ("-" for standard output)
+	    /// \param[in] extension slices extension ("dar")
+	    /// \param[in] options optional parameters to use for the operation
+	void op_isolate(user_interaction & dialog,
+			const path &sauv_path,
+			const std::string & filename,
+			const std::string & extension,
+			const archive_options_isolate & options);
+
+
 	    /// getting information about a given directory
 
 	    /// \param[in,out] dialog for user interaction
@@ -266,8 +278,14 @@ namespace libdar
 	    /// mandatory
 	const std::vector<list_entry> get_children_in_table(const std::string & dir) const;
 
+	    /// returns true if the pointed directory has one or more subdirectories
+	bool has_subdirectory(const std::string & dir) const;
+
 	    /// retrieving statistics about archive contents
-	const entree_stats get_stats() const { if(cat == NULL) throw SRC_BUG; return cat->get_stats(); };
+	const entree_stats get_stats() const { if(cat == nullptr) throw SRC_BUG; return cat->get_stats(); };
+
+	    /// retrieving signature information about the archive
+	const std::list<signator> & get_signatories() const { return gnupg_signed; };
 
 	    /// necessary to get the catalogue fully loaded in memory in any situation
 	    /// in particular in sequential reading mode
@@ -300,32 +318,51 @@ namespace libdar
 
 	void drop_all_filedescriptors(user_interaction & dialog);
 
+	    /// change all inode as unsaved (equal to differential backup with no change met)
+	void set_to_unsaved_data_and_FSA() { if(cat == nullptr) throw SRC_BUG; cat->set_to_unsaved_data_and_FSA(); };
+
+	    /// check that the internal memory_pool has all its blocks properly freeed
+	    ///
+	    /// \return an empty string in normal situation, else a status report about the
+	    /// still allocated blocks that remain in the internal memory_pool
+	    /// \note this must be the last call done to that object before destruction and it must
+	    /// be done only once
+	std::string free_and_check_memory() const;
+
+
     private:
 	enum operation { oper_create, oper_isolate, oper_merge };
 
-	pile stack;
-	header_version ver;
-	catalogue *cat;
-	infinint local_cat_size;
-	path *local_path;
-	bool exploitable; //< is false if only the catalogue is available (for reference backup or isolation).
-	bool lax_read_mode; //< whether the archive has been openned in lax mode (unused for creation/merging/isolation)
-	bool sequential_read; //< whether the archive is read in sequential mode
+	pile stack;              //< the different layer through which the archive contents is read or wrote
+	header_version ver;      //< information for the archive header
+	memory_pool *pool;       //< points to local_pool or inherited pool or to nullptr if no memory_pool has to be used
+	catalogue *cat;          //< archive contents
+	infinint local_cat_size; //< size of the catalogue on disk
+	bool exploitable;        //< is false if only the catalogue is available (for reference backup or isolation).
+	bool lax_read_mode;      //< whether the archive has been openned in lax mode (unused for creation/merging/isolation)
+	bool sequential_read;    //< whether the archive is read in sequential mode
+	bool freed_and_checked;  //< whether free_and_check has been run
+	std::list<signator> gnupg_signed; //< list of signature found in the archive (reading an existing archive)
+	slice_layout slices;     //< slice layout, archive is not sliced <=> first_size or other_size fields is set to zero (in practice both are set to zero, but one being set is enought to determine the archive is not sliced)
 
-	void free();
-	catalogue & get_cat() const { if(cat == NULL) throw SRC_BUG; else return *cat; };
+	void free_except_memory_pool();
+	void free_all();
+	void init_pool();
+	void check_gnupg_signed(user_interaction & dialog) const;
+
+	const catalogue & get_cat() const { if(cat == nullptr) throw SRC_BUG; else return *cat; };
 	const header_version & get_header() const { return ver; };
-	const path & get_path() { if(local_path == NULL) throw SRC_BUG; else return *local_path; };
 
 	bool get_sar_param(infinint & sub_file_size, infinint & first_file_size, infinint & last_file_size,
 			   infinint & total_file_number);
+	const entrepot *get_entrepot(); //< this method may return nullptr if no entrepot is used (pipes used for archive building, etc.)
 	infinint get_level2_size();
 	infinint get_cat_size() const { return local_cat_size; };
 
 	statistics op_create_in(user_interaction & dialog,
 				operation op,
 				const path & fs_root,
-				const path & sauv_path,
+				const entrepot & sauv_path_t,
 				archive *ref_arch,
 				const mask & selection,
 				const mask & subtree,
@@ -334,6 +371,10 @@ namespace libdar
 				bool allow_over,
 				bool warn_over,
 				bool info_details,
+				bool display_treated,
+				bool display_treated_only_dir,
+				bool display_skipped,
+				bool display_finished,
 				const infinint & pause,
 				bool empty_dir,
 				compression algo,
@@ -345,22 +386,22 @@ namespace libdar
 				crypto_algo crypto,
 				const secu_string & pass,
 				U_32 crypto_size,
+				const std::vector<std::string> & gnupg_recipients,
+				const std::vector<std::string> & gnupg_signatories,
 				const mask & compr_mask,
 				const infinint & min_compr_size,
 				bool nodump,
+				const std::string & exclude_by_ea,
 				const infinint & hourshift,
 				bool empty,
 				bool alter_atime,
 				bool furtive_read_mode,
 				bool same_fs,
-				inode::comparison_fields what_to_check,
+				cat_inode::comparison_fields what_to_check,
 				bool snapshot,
 				bool cache_directory_tagging,
-				bool display_skipped,
 				const infinint & fixed_date,
 				const std::string & slice_permission,
-				const std::string & slice_user_ownership,
-				const std::string & slice_group_ownership,
 				const infinint & repeat_count,
 				const infinint & repeat_byte,
 				bool add_marks_for_sequential_reading,
@@ -372,15 +413,17 @@ namespace libdar
 				const std::string & backup_hook_file_execute,
 				const mask & backup_hook_file_mask,
 				bool ignore_unknown,
+				const fsa_scope & scope,
+				bool multi_threaded,
 				statistics * progressive_report);
 
 	void op_create_in_sub(user_interaction & dialog,        //< interaction with user
 			      operation op,                     //< the filter operation to bind to
 			      const path & fs_root,             //< root of the filesystem to act on
-			      const path & sauv_path_t,         //< where to create the archive
-			      catalogue  * ref_arch1,           //< catalogue of the archive of reference (a catalogue must be provided in any case, a empty one shall fit for no reference)
-			      catalogue  * ref_arch2,           //< secondary catalogue used for merging, can be NULL if not used
-			      const path * ref_path,            //< path of the archive of archive of reference (NULL if there is no archive of reference used, thus ref_arch (previous arg) is probably an empty archive)
+			      const entrepot & sauv_path_t,     //< where to create the archive
+			      const catalogue * ref_cat1,       //< catalogue of the archive of reference, (cannot be nullptr if ref_cat2 is not nullptr)
+			      const catalogue * ref_cat2,       //< secondary catalogue used for merging, can be nullptr if not used
+			      bool initial_pause,               //< whether we shall pause before starting the archive creation
 			      const mask & selection,           //< filter on filenames
 			      const mask & subtree,             //< filter on directory tree and filenames
 			      const std::string & filename,     //< basename of the archive to create
@@ -389,6 +432,10 @@ namespace libdar
 			      const crit_action & overwrite,    //< whether and how to allow overwriting (for files inside the archive)
 			      bool warn_over,                   //< whether to warn before overwriting
 			      bool info_details,                //< whether to display detailed informations
+			      bool display_treated,             //< whether to display treated files
+			      bool display_treated_only_dir,    //< whether to only display current directory of treated files
+			      bool display_skipped,             //< display skipped files for the operation
+			      bool display_finished,            //< display space and compression ratio summary for each completed directory
 			      const infinint & pause,           //< whether to pause between slices
 			      bool empty_dir,                   //< whether to store excluded dir as empty directories
 			      compression algo,                 //< compression algorithm
@@ -400,23 +447,23 @@ namespace libdar
 			      crypto_algo crypto,               //< crypt algorithm
 			      const secu_string & pass,         //< password ("" for onfly request of password)
 			      U_32 crypto_size,                 //< size of crypto blocks
+			      const std::vector<std::string> & gnupg_recipients, //< list of email recipients to encrypted a randomly chosen key inside the archive
+			      const std::vector<std::string> & gnupg_signatories, //< list of email recipients to use for signature
 			      const mask & compr_mask,          //< files to compress
 			      const infinint & min_compr_size,  //< file size under which to not compress files
 			      bool nodump,                      //< whether to consider the "nodump" filesystem flag
+			      const std::string & exclude_by_ea,//< if not empty the ea to use for inode exclusion from backup operation
 			      const infinint & hourshift,       //< hourshift (see man page -H option)
 			      bool empty,                       //< whether to make an "dry-run" execution
 			      bool alter_atime,                 //< whether to alter atime date (by opposition to ctime) when reading files
 			      bool furtive_read_mode,           //< whether to neither alter atime nor ctome (if true alter_atime is ignored)
 			      bool same_fs,                     //< confin the files consideration to a single filesystem
-			      inode::comparison_fields what_to_check,  //< fields to consider wien comparing inodes (see inode::comparison_fields enumeration)
+			      cat_inode::comparison_fields what_to_check,  //< fields to consider wien comparing inodes (see cat_inode::comparison_fields enumeration)
 			      bool snapshot,                    //< make as if all file had not changed
 			      bool cache_directory_tagging,     //< avoid saving directory which follow the cache directory tagging
-			      bool display_skipped,             //< display skipped files for the operation
 			      bool keep_compressed,             //< keep file compressed when merging
 			      const infinint & fixed_date,      //< whether to ignore any archive of reference and only save file which modification is more recent that the given "fixed_date" date
 			      const std::string & slice_permission,      //< permissions of slices that will be created
-			      const std::string & slice_user_ownership,  //< user ownership of slices that will be created
-			      const std::string & slice_group_ownership, //< group ownership of slices that will be created
 			      const infinint & repeat_count,             //< max number of retry to save a file that have changed while it was read for backup
 			      const infinint & repeat_byte,              //< max amount of wasted data used to save a file that have changed while it was read for backup
 			      bool decremental,                          //< in the merging context only, whether to build a decremental backup from the two archives of reference
@@ -429,7 +476,9 @@ namespace libdar
 			      const std::string & backup_hook_file_execute, //< command to execute before and after files to backup
 			      const mask & backup_hook_file_mask,         //< files elected to have a command executed before and after their backup
 			      bool ignore_unknown,                        //< whether to warn when an unknown inode type is met
-			      statistics * st_ptr);             //< statistics must not be NULL !
+			      const fsa_scope & scope,                    //< FSA scope for the operation
+			      bool multi_threaded,              //< whether libdar is allowed to spawn several thread to possibily work faster on multicore CPU
+			      statistics * st_ptr);             //< statistics must not be nullptr !
 
 	void disable_natural_destruction();
 	void enable_natural_destruction();
@@ -437,8 +486,7 @@ namespace libdar
 	const label & get_catalogue_data_name() const;
 	bool only_contains_an_isolated_catalogue() const; //< true if the current archive only contains an isolated catalogue
 	void check_against_isolation(user_interaction & dialog, bool lax) const; //< throw Erange exception if the archive only contains an isolated catalogue
-	void check_header_version() const;
-	const directory *get_dir_object(const std::string & dir) const;
+	const cat_directory *get_dir_object(const std::string & dir) const;
     };
 
 } // end of namespace
