@@ -21,9 +21,8 @@
 
 #include "../my_config.h"
 
-#include <new>
-
 #include "archive_options.hpp"
+#include "entrepot_local.hpp"
 
 using namespace std;
 
@@ -34,14 +33,14 @@ namespace libdar
     static const U_32 default_crypto_size = 10240;
     static const path default_ref_chem = "/";
     static const U_I default_min_compr_size = 100;
-    static const inode::comparison_fields default_comparison_fields = inode::cf_all;
+    static const cat_inode::comparison_fields default_comparison_fields = cat_inode::cf_all;
     static const crit_constant_action default_crit_action = crit_constant_action(data_preserve, EA_preserve);
     static const string default_user_comment = "N/A";
 
 	// some local helper functions
 
     inline void archive_option_destroy_mask(mask * & ptr);
-    inline void archive_option_clean_mask(mask * & ptr, bool all = true);
+    inline void archive_option_clean_mask(mask * & ptr, memory_pool *pool, bool all = true);
     inline void archive_option_destroy_crit_action(crit_action * & ptr);
     inline void archive_option_clean_crit_action(crit_action * & ptr);
 
@@ -51,20 +50,20 @@ namespace libdar
 	/////////////////////////////////////////////////////////
 
 
-    inline void archive_option_clean_mask(mask * & ptr, bool all)
+    inline void archive_option_clean_mask(mask * & ptr, memory_pool *pool, bool all)
     {
 	archive_option_destroy_mask(ptr);
-	ptr = new (nothrow) bool_mask(all);
-	if(ptr == NULL)
-	    throw Ememory("archive_options_clean_mask");
+	ptr = new (pool) bool_mask(all);
+	if(ptr == nullptr)
+	    throw Ememory("archive_option_clean_mask");
     }
 
     inline void archive_option_destroy_mask(mask * & ptr)
     {
-	if(ptr != NULL)
+	if(ptr != nullptr)
 	{
 	    delete ptr;
-	    ptr = NULL;
+	    ptr = nullptr;
 	}
     }
 
@@ -72,16 +71,16 @@ namespace libdar
     {
 	archive_option_destroy_crit_action(ptr);
 	ptr = default_crit_action.clone();
-	if(ptr == NULL)
+	if(ptr == nullptr)
 	    throw Ememory("archive_options::archive_option_clean_crit_action");
     }
 
     inline void archive_option_destroy_crit_action(crit_action * & ptr)
     {
-	if(ptr != NULL)
+	if(ptr != nullptr)
 	{
 	    delete ptr;
-	    ptr = NULL;
+	    ptr = nullptr;
 	}
     }
 
@@ -92,6 +91,8 @@ namespace libdar
 
     archive_options_read::archive_options_read() : x_ref_chem(default_ref_chem)
     {
+	x_entrepot = nullptr;
+	x_ref_entrepot = nullptr;
 	clear();
     }
 
@@ -100,6 +101,8 @@ namespace libdar
 
 	    // setting the default values for all options
 
+	destroy();
+
 	x_crypto = crypto_none;
 	x_pass.clear();
 	x_crypto_size = default_crypto_size;
@@ -110,6 +113,11 @@ namespace libdar
 	x_lax = false;
 	x_sequential_read = false;
 	x_slice_min_digits = 0;
+	x_entrepot = new (get_pool()) entrepot_local("", "", false); // never using furtive_mode to read slices
+	if(x_entrepot == nullptr)
+	    throw Ememory("archive_options_read::clear");
+	x_ignore_signature_check_failure = false;
+	x_multi_threaded = true;
 
 	    //
 	external_cat = false;
@@ -120,6 +128,9 @@ namespace libdar
 	x_ref_crypto_size = default_crypto_size;
 	x_ref_execute = "";
 	x_ref_slice_min_digits = 0;
+	x_ref_entrepot = new (get_pool()) entrepot_local("", "", false); // never using furtive_mode to read slices
+	if(x_ref_entrepot == nullptr)
+	    throw Ememory("archive_options_read::clear");
     }
 
     void archive_options_read::set_default_crypto_size()
@@ -172,11 +183,92 @@ namespace libdar
 
     }
 
+    void archive_options_read::copy_from(const archive_options_read & ref)
+    {
+	x_crypto = ref.x_crypto;
+	x_pass = ref.x_pass;
+	x_crypto_size = ref.x_crypto_size;
+	x_input_pipe = ref.x_input_pipe;
+	x_output_pipe = ref.x_output_pipe;
+	x_execute = ref.x_execute;
+	x_info_details = ref.x_info_details;
+	x_lax = ref.x_lax;
+	x_sequential_read = ref.x_sequential_read;
+	x_slice_min_digits = ref.x_slice_min_digits;
+	if(ref.x_entrepot == nullptr)
+	    throw SRC_BUG;
+	x_entrepot = ref.x_entrepot->clone();
+	if(x_entrepot == nullptr)
+	    throw Ememory("archive_options_read::copy_from");
+	x_ignore_signature_check_failure = ref.x_ignore_signature_check_failure;
+	x_multi_threaded = ref.x_multi_threaded;
+	    //
+
+	external_cat = ref.external_cat;
+	x_ref_chem = ref.x_ref_chem;
+	x_ref_basename = ref.x_ref_basename;
+	x_ref_crypto = ref.x_ref_crypto;
+	x_ref_pass = ref.x_ref_pass;
+	x_ref_crypto_size = ref.x_ref_crypto_size;
+	x_ref_execute = ref.x_ref_execute;
+	x_ref_slice_min_digits = ref.x_ref_slice_min_digits;
+	if(ref.x_ref_entrepot == nullptr)
+	    throw SRC_BUG;
+	x_ref_entrepot = ref.x_ref_entrepot->clone();
+	if(x_ref_entrepot == nullptr)
+	    throw Ememory("archive_options_read::copy_from");
+    }
+
+    void archive_options_read::destroy()
+    {
+	if(x_entrepot != nullptr)
+	{
+	    delete x_entrepot;
+	    x_entrepot = nullptr;
+	}
+	if(x_ref_entrepot != nullptr)
+	{
+	    delete x_ref_entrepot;
+	    x_ref_entrepot = nullptr;
+	}
+    }
+
+
+
 
 	/////////////////////////////////////////////////////////
 	/////////////////////////////////////////////////////////
 	/////////////////////////////////////////////////////////
 
+    archive_options_create::archive_options_create()
+    {
+	x_selection = x_subtree = x_ea_mask = x_compr_mask = x_backup_hook_file_mask = nullptr;
+	x_entrepot = nullptr;
+	try
+	{
+	    clear();
+	}
+	catch(...)
+	{
+	    destroy();
+	    throw;
+	}
+    }
+
+    archive_options_create::archive_options_create(const archive_options_create & ref)
+    {
+	x_selection = x_subtree = x_ea_mask = x_compr_mask = x_backup_hook_file_mask = nullptr;
+	x_entrepot = nullptr;
+	try
+	{
+	    copy_from(ref);
+	}
+	catch(...)
+	{
+	    destroy();
+	    throw;
+	}
+    }
 
     void archive_options_create::clear()
     {
@@ -186,15 +278,19 @@ namespace libdar
 
 	    destroy();
 
-	    archive_option_clean_mask(x_selection);
-	    archive_option_clean_mask(x_subtree);
-	    archive_option_clean_mask(x_ea_mask);
-	    archive_option_clean_mask(x_compr_mask);
-	    archive_option_clean_mask(x_backup_hook_file_mask, false);
-	    x_ref_arch = NULL;
+	    archive_option_clean_mask(x_selection, get_pool());
+	    archive_option_clean_mask(x_subtree, get_pool());
+	    archive_option_clean_mask(x_ea_mask, get_pool());
+	    archive_option_clean_mask(x_compr_mask, get_pool());
+	    archive_option_clean_mask(x_backup_hook_file_mask, get_pool(), false);
+	    x_ref_arch = nullptr;
 	    x_allow_over = true;
 	    x_warn_over = true;
 	    x_info_details = false;
+	    x_display_treated = false;
+	    x_display_treated_only_dir = false;
+	    x_display_skipped = false;
+	    x_display_finished = false;
 	    x_pause = 0;
 	    x_empty_dir = false;
 	    x_compr_algo = none;
@@ -205,8 +301,11 @@ namespace libdar
 	    x_crypto = crypto_none;
 	    x_pass.clear();
 	    x_crypto_size = default_crypto_size;
+	    x_gnupg_recipients.clear();
+	    x_gnupg_signatories.clear();
 	    x_min_compr_size = default_min_compr_size;
 	    x_nodump = false;
+	    exclude_by_ea = "";
 	    x_what_to_check = default_comparison_fields;
 	    x_hourshift = 0;
 	    x_empty = false;
@@ -220,13 +319,12 @@ namespace libdar
 	    x_same_fs = false;
 	    x_snapshot = false;
 	    x_cache_directory_tagging = false;
-	    x_display_skipped = false;
 	    x_fixed_date = 0;
 	    x_slice_permission = "";
 	    x_slice_user_ownership = "";
 	    x_slice_group_ownership = "";
-	    x_repeat_count = 0;
-	    x_repeat_byte = 0;
+	    x_repeat_count = 3;
+	    x_repeat_byte = 1;
 	    x_sequential_marks = true;
 	    x_sparse_file_min_size = 15;  // min value to activate the feature (0 means no detection of sparse_file)
 	    x_security_check = true;
@@ -235,6 +333,11 @@ namespace libdar
 	    x_slice_min_digits = 0;
 	    x_backup_hook_file_execute = "";
 	    x_ignore_unknown = false;
+	    x_entrepot = new (get_pool()) entrepot_local( "", "", false); // never using furtive_mode to read slices
+	    if(x_entrepot == nullptr)
+		throw Ememory("archive_options_create::clear");
+	    x_scope = all_fsa_families();
+	    x_multi_threaded = true;
 	}
 	catch(...)
 	{
@@ -251,7 +354,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_selection);
 	    x_selection = selection.clone();
-	    if(x_selection == NULL)
+	    if(x_selection == nullptr)
 		throw Ememory("archive_options_create::set_selection");
 	}
 	catch(...)
@@ -269,7 +372,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_subtree);
 	    x_subtree = subtree.clone();
-	    if(x_subtree == NULL)
+	    if(x_subtree == nullptr)
 		throw Ememory("archive_options_create::set_subtree");
 	}
 	catch(...)
@@ -287,7 +390,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_ea_mask);
 	    x_ea_mask = ea_mask.clone();
-	    if(x_ea_mask == NULL)
+	    if(x_ea_mask == nullptr)
 		throw Ememory("archive_options_create::set_ea_mask");
 	}
 	catch(...)
@@ -305,7 +408,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_compr_mask);
 	    x_compr_mask = compr_mask.clone();
-	    if(x_compr_mask == NULL)
+	    if(x_compr_mask == nullptr)
 		throw Ememory("archive_options_create::set_compr_mask");
 	}
 	catch(...)
@@ -324,7 +427,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_backup_hook_file_mask);
 	    x_backup_hook_file_mask = which_files.clone();
-	    if(x_backup_hook_file_mask == NULL)
+	    if(x_backup_hook_file_mask == nullptr)
 		throw Ememory("archive_options_create::set_backup_hook");
 
 	    x_backup_hook_file_execute = execute;
@@ -337,6 +440,16 @@ namespace libdar
 	NLS_SWAP_OUT;
     }
 
+    void archive_options_create::set_entrepot(const entrepot & entr)
+    {
+	if(x_entrepot != nullptr)
+	    delete x_entrepot;
+
+	x_entrepot = entr.clone();
+	if(x_entrepot == nullptr)
+	    throw Ememory("archive_options_create::set_entrepot");
+    }
+
     void archive_options_create::destroy()
     {
 	NLS_SWAP_IN;
@@ -347,6 +460,11 @@ namespace libdar
 	    archive_option_destroy_mask(x_ea_mask);
 	    archive_option_destroy_mask(x_compr_mask);
 	    archive_option_destroy_mask(x_backup_hook_file_mask);
+	    if(x_entrepot != nullptr)
+	    {
+		delete x_entrepot;
+		x_entrepot = nullptr;
+	    }
 	}
 	catch(...)
 	{
@@ -358,79 +476,84 @@ namespace libdar
 
     void archive_options_create::copy_from(const archive_options_create & ref)
     {
-	x_selection = NULL;
-	x_subtree = NULL;
-	x_ea_mask = NULL;
-	x_compr_mask = NULL;
-	x_backup_hook_file_mask = NULL;
+	x_selection = nullptr;
+	x_subtree = nullptr;
+	x_ea_mask = nullptr;
+	x_compr_mask = nullptr;
+	x_backup_hook_file_mask = nullptr;
+	x_entrepot = nullptr;
 
-	try
-	{
-	    if(ref.x_selection == NULL)
-		throw SRC_BUG;
-	    if(ref.x_subtree == NULL)
-		throw SRC_BUG;
-	    if(ref.x_ea_mask == NULL)
-		throw SRC_BUG;
-	    if(ref.x_compr_mask == NULL)
-		throw SRC_BUG;
-	    if(ref.x_backup_hook_file_mask == NULL)
-		throw SRC_BUG;
-	    x_selection = ref.x_selection->clone();
-	    x_subtree = ref.x_subtree->clone();
-	    x_ea_mask = ref.x_ea_mask->clone();
-	    x_compr_mask = ref.x_compr_mask->clone();
-	    x_backup_hook_file_mask = ref.x_backup_hook_file_mask->clone();
+	if(ref.x_selection == nullptr)
+	    throw SRC_BUG;
+	if(ref.x_subtree == nullptr)
+	    throw SRC_BUG;
+	if(ref.x_ea_mask == nullptr)
+	    throw SRC_BUG;
+	if(ref.x_compr_mask == nullptr)
+	    throw SRC_BUG;
+	if(ref.x_backup_hook_file_mask == nullptr)
+	    throw SRC_BUG;
+	x_selection = ref.x_selection->clone();
+	x_subtree = ref.x_subtree->clone();
+	x_ea_mask = ref.x_ea_mask->clone();
+	x_compr_mask = ref.x_compr_mask->clone();
+	x_backup_hook_file_mask = ref.x_backup_hook_file_mask->clone();
 
-	    if(x_selection == NULL || x_subtree == NULL || x_ea_mask == NULL || x_compr_mask == NULL || x_backup_hook_file_mask == NULL)
-		throw Ememory("archive_options_create::copy_from");
+	if(x_selection == nullptr || x_subtree == nullptr || x_ea_mask == nullptr || x_compr_mask == nullptr || x_backup_hook_file_mask == nullptr)
+	    throw Ememory("archive_options_create::copy_from");
 
-	    x_ref_arch = ref.x_ref_arch;
-	    x_allow_over = ref.x_allow_over;
-	    x_warn_over = ref.x_warn_over;
-	    x_info_details = ref.x_info_details;
-	    x_pause = ref.x_pause;
-	    x_empty_dir = ref.x_empty_dir;
-	    x_compr_algo = ref.x_compr_algo;
-	    x_compression_level = ref.x_compression_level;
-	    x_file_size = ref.x_file_size;
-	    x_first_file_size = ref.x_first_file_size;
-	    x_execute = ref.x_execute;
-	    x_crypto = ref.x_crypto;
-	    x_pass = ref.x_pass;
-	    x_crypto_size = ref.x_crypto_size;
-	    x_min_compr_size = ref.x_min_compr_size;
-	    x_nodump = ref.x_nodump;
-	    x_what_to_check = ref.x_what_to_check;
-	    x_hourshift = ref.x_hourshift;
-	    x_empty = ref.x_empty;
-	    x_alter_atime = ref.x_alter_atime;
-	    x_old_alter_atime = ref.x_old_alter_atime;
-	    x_furtive_read = ref.x_furtive_read;
-	    x_same_fs = ref.x_same_fs;
-	    x_snapshot = ref.x_snapshot;
-	    x_cache_directory_tagging = ref.x_cache_directory_tagging;
-	    x_display_skipped = ref.x_display_skipped;
-	    x_fixed_date = ref.x_fixed_date;
-	    x_slice_permission = ref.x_slice_permission;
-	    x_slice_user_ownership = ref.x_slice_user_ownership;
-	    x_slice_group_ownership = ref.x_slice_group_ownership;
-	    x_repeat_count = ref.x_repeat_count;
-	    x_repeat_byte = ref.x_repeat_byte;
-	    x_sequential_marks = ref.x_sequential_marks;
-	    x_sparse_file_min_size = ref.x_sparse_file_min_size;
-	    x_security_check = ref.x_security_check;
-	    x_user_comment = ref.x_user_comment;
-	    x_hash = ref.x_hash;
-	    x_slice_min_digits = ref.x_slice_min_digits;
-	    x_backup_hook_file_execute = ref.x_backup_hook_file_execute;
-	    x_ignore_unknown = ref.x_ignore_unknown;
-	}
-	catch(...)
-	{
-	    clear();
-	    throw;
-	}
+	x_ref_arch = ref.x_ref_arch;
+	x_allow_over = ref.x_allow_over;
+	x_warn_over = ref.x_warn_over;
+	x_info_details = ref.x_info_details;
+	x_display_treated = ref.x_display_treated;
+	x_display_treated_only_dir = ref.x_display_treated_only_dir;
+	x_display_skipped = ref.x_display_skipped;
+	x_display_finished = ref.x_display_finished;
+	x_pause = ref.x_pause;
+	x_empty_dir = ref.x_empty_dir;
+	x_compr_algo = ref.x_compr_algo;
+	x_compression_level = ref.x_compression_level;
+	x_file_size = ref.x_file_size;
+	x_first_file_size = ref.x_first_file_size;
+	x_execute = ref.x_execute;
+	x_crypto = ref.x_crypto;
+	x_pass = ref.x_pass;
+	x_crypto_size = ref.x_crypto_size;
+	x_gnupg_recipients = ref.x_gnupg_recipients;
+	x_gnupg_signatories = ref.x_gnupg_signatories;
+	x_min_compr_size = ref.x_min_compr_size;
+	x_nodump = ref.x_nodump;
+	x_what_to_check = ref.x_what_to_check;
+	x_hourshift = ref.x_hourshift;
+	x_empty = ref.x_empty;
+	x_alter_atime = ref.x_alter_atime;
+	x_old_alter_atime = ref.x_old_alter_atime;
+	x_furtive_read = ref.x_furtive_read;
+	x_same_fs = ref.x_same_fs;
+	x_snapshot = ref.x_snapshot;
+	x_cache_directory_tagging = ref.x_cache_directory_tagging;
+	x_fixed_date = ref.x_fixed_date;
+	x_slice_permission = ref.x_slice_permission;
+	x_slice_user_ownership = ref.x_slice_user_ownership;
+	x_slice_group_ownership = ref.x_slice_group_ownership;
+	x_repeat_count = ref.x_repeat_count;
+	x_repeat_byte = ref.x_repeat_byte;
+	x_sequential_marks = ref.x_sequential_marks;
+	x_sparse_file_min_size = ref.x_sparse_file_min_size;
+	x_security_check = ref.x_security_check;
+	x_user_comment = ref.x_user_comment;
+	x_hash = ref.x_hash;
+	x_slice_min_digits = ref.x_slice_min_digits;
+	x_backup_hook_file_execute = ref.x_backup_hook_file_execute;
+	x_ignore_unknown = ref.x_ignore_unknown;
+	if(x_entrepot != nullptr)
+	    throw SRC_BUG;
+	x_entrepot = ref.x_entrepot->clone();
+	if(x_entrepot == nullptr)
+	    throw Ememory("archive_options_create::copy_from");
+	x_scope = ref.x_scope;
+	x_multi_threaded = ref.x_multi_threaded;
     }
 
 
@@ -440,26 +563,95 @@ namespace libdar
 
     void archive_options_isolate::clear()
     {
-	x_allow_over = true;
-	x_warn_over = true;
-	x_info_details = false;
-	x_pause = 0;
-	x_algo = none;
-	x_compression_level = 9;
-	x_file_size = 0;
-	x_first_file_size = 0;
-	x_execute = "";
-	x_crypto = crypto_none;
-	x_pass.clear();
-	x_crypto_size = default_crypto_size;
-	x_empty = false;
-	x_slice_permission = "";
-	x_slice_user_ownership = "";
-	x_slice_group_ownership = "";
-	x_user_comment = default_user_comment;
-	x_hash = hash_none;
-	x_slice_min_digits = 0;
-	x_sequential_marks = true;
+	NLS_SWAP_IN;
+	try
+	{
+	    destroy();
+
+	    x_allow_over = true;
+	    x_warn_over = true;
+	    x_info_details = false;
+	    x_pause = 0;
+	    x_algo = none;
+	    x_compression_level = 9;
+	    x_file_size = 0;
+	    x_first_file_size = 0;
+	    x_execute = "";
+	    x_crypto = crypto_none;
+	    x_pass.clear();
+	    x_crypto_size = default_crypto_size;
+	    x_gnupg_recipients.clear();
+	    x_gnupg_signatories.clear();
+	    x_empty = false;
+	    x_slice_permission = "";
+	    x_slice_user_ownership = "";
+	    x_slice_group_ownership = "";
+	    x_user_comment = default_user_comment;
+	    x_hash = hash_none;
+	    x_slice_min_digits = 0;
+	    x_sequential_marks = true;
+	    x_entrepot = new (get_pool()) entrepot_local("", "", false); // never using furtive_mode to read slices
+	    if(x_entrepot == nullptr)
+		throw Ememory("archive_options_isolate::clear");
+	    x_multi_threaded = true;
+	}
+	catch(...)
+	{
+	    NLS_SWAP_OUT;
+	    throw;
+	}
+	NLS_SWAP_OUT;
+    }
+
+    void archive_options_isolate::set_entrepot(const entrepot & entr)
+    {
+	if(x_entrepot != nullptr)
+	    delete x_entrepot;
+
+	x_entrepot = entr.clone();
+	if(x_entrepot == nullptr)
+	    throw Ememory("archive_options_isolate::set_entrepot");
+    }
+
+    void archive_options_isolate::destroy()
+    {
+	if(x_entrepot != nullptr)
+	{
+	    delete x_entrepot;
+	    x_entrepot = nullptr;
+	}
+    }
+
+    void archive_options_isolate::copy_from(const archive_options_isolate & ref)
+    {
+	x_allow_over = ref.x_allow_over;
+	x_warn_over = ref.x_warn_over;
+	x_info_details = ref.x_info_details;
+	x_pause = ref.x_pause;
+	x_algo = ref.x_algo;
+	x_compression_level = ref.x_compression_level;
+	x_file_size = ref.x_file_size;
+	x_first_file_size = ref.x_first_file_size;
+	x_execute = ref.x_execute;
+	x_crypto = ref.x_crypto;
+	x_pass = ref.x_pass;
+	x_crypto_size = ref.x_crypto_size;
+	x_gnupg_recipients = ref.x_gnupg_recipients;
+	x_gnupg_signatories = ref.x_gnupg_signatories;
+	x_empty = ref.x_empty;
+	x_slice_permission = ref.x_slice_permission;
+	x_slice_user_ownership = ref.x_slice_user_ownership;
+	x_slice_group_ownership = ref.x_slice_group_ownership;
+	x_user_comment = ref.x_user_comment;
+	x_hash = ref.x_hash;
+	x_slice_min_digits = ref.x_slice_min_digits;
+	x_sequential_marks = ref.x_sequential_marks;
+	if(ref.x_entrepot == nullptr)
+	    throw SRC_BUG;
+	x_entrepot = ref.x_entrepot->clone();
+	if(x_entrepot == nullptr)
+	    throw Ememory("archive_options_isolate::copy_from");
+	x_multi_threaded = ref.x_multi_threaded;
     }
 
 
@@ -475,15 +667,18 @@ namespace libdar
 	{
 	    destroy();
 
-	    archive_option_clean_mask(x_selection);
-	    archive_option_clean_mask(x_subtree);
-	    archive_option_clean_mask(x_ea_mask);
-	    archive_option_clean_mask(x_compr_mask);
+	    archive_option_clean_mask(x_selection, get_pool());
+	    archive_option_clean_mask(x_subtree, get_pool());
+	    archive_option_clean_mask(x_ea_mask, get_pool());
+	    archive_option_clean_mask(x_compr_mask, get_pool());
 	    archive_option_clean_crit_action(x_overwrite);
-	    x_ref = NULL;
+	    x_ref = nullptr;
 	    x_allow_over = true;
 	    x_warn_over = true;
 	    x_info_details = false;
+	    x_display_treated = false;
+	    x_display_treated_only_dir = false;
+	    x_display_skipped = false;
 	    x_pause = 0;
 	    x_empty_dir = false;
 	    x_compr_algo = none;
@@ -492,11 +687,12 @@ namespace libdar
 	    x_first_file_size = 0;
 	    x_execute = "";
 	    x_crypto = crypto_none;
-	    x_crypto_size = default_crypto_size;
 	    x_pass.clear();
+	    x_crypto_size = default_crypto_size;
+	    x_gnupg_recipients.clear();
+	    x_gnupg_signatories.clear();
 	    x_min_compr_size = default_min_compr_size;
 	    x_empty = false;
-	    x_display_skipped = false;
 	    x_keep_compressed = false;
 	    x_slice_permission = "";
 	    x_slice_user_ownership = "";
@@ -507,6 +703,11 @@ namespace libdar
 	    x_user_comment = default_user_comment;
 	    x_hash = hash_none;
 	    x_slice_min_digits = 0;
+	    x_entrepot = new (get_pool()) entrepot_local("", "", false); // never using furtive_mode to read slices
+	    if(x_entrepot == nullptr)
+		throw Ememory("archive_options_merge::clear");
+	    x_scope = all_fsa_families();
+	    x_multi_threaded = true;
 	}
 	catch(...)
 	{
@@ -523,7 +724,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_selection);
 	    x_selection = selection.clone();
-	    if(x_selection == NULL)
+	    if(x_selection == nullptr)
 		throw Ememory("archive_options_merge::set_selection");
 	}
 	catch(...)
@@ -541,7 +742,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_subtree);
 	    x_subtree = subtree.clone();
-	    if(x_subtree == NULL)
+	    if(x_subtree == nullptr)
 		throw Ememory("archive_options_merge::set_subtree");
 	}
         catch(...)
@@ -559,7 +760,7 @@ namespace libdar
 	{
 	    archive_option_destroy_crit_action(x_overwrite);
 	    x_overwrite = overwrite.clone();
-	    if(x_overwrite == NULL)
+	    if(x_overwrite == nullptr)
 		throw Ememory("archive_options_merge::set_overwriting_rules");
 	}
         catch(...)
@@ -577,7 +778,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_ea_mask);
 	    x_ea_mask = ea_mask.clone();
-	    if(x_ea_mask == NULL)
+	    if(x_ea_mask == nullptr)
 		throw Ememory("archive_options_merge::set_ea_mask");
 	}
 	catch(...)
@@ -595,7 +796,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_compr_mask);
 	    x_compr_mask = compr_mask.clone();
-	    if(x_compr_mask == NULL)
+	    if(x_compr_mask == nullptr)
 		throw Ememory("archive_options_merge::set_compr_mask");
 	}
 	catch(...)
@@ -607,6 +808,17 @@ namespace libdar
 
     }
 
+    void archive_options_merge::set_entrepot(const entrepot & entr)
+    {
+	if(x_entrepot != nullptr)
+	    delete x_entrepot;
+
+	x_entrepot = entr.clone();
+	if(x_entrepot == nullptr)
+	    throw Ememory("archive_options_merge::set_entrepot");
+    }
+
+
     void archive_options_merge::destroy()
     {
 	NLS_SWAP_IN;
@@ -617,6 +829,11 @@ namespace libdar
 	    archive_option_destroy_mask(x_ea_mask);
 	    archive_option_destroy_mask(x_compr_mask);
 	    archive_option_destroy_crit_action(x_overwrite);
+	    if(x_entrepot != nullptr)
+	    {
+		delete x_entrepot;
+		x_entrepot = nullptr;
+	    }
 	}
 	catch(...)
 	{
@@ -628,37 +845,45 @@ namespace libdar
 
     void archive_options_merge::copy_from(const archive_options_merge & ref)
     {
-	x_selection = NULL;
-	x_subtree = NULL;
-	x_ea_mask = NULL;
-	x_compr_mask = NULL;
-	x_overwrite = NULL;
+	x_selection = nullptr;
+	x_subtree = nullptr;
+	x_ea_mask = nullptr;
+	x_compr_mask = nullptr;
+	x_overwrite = nullptr;
+	x_entrepot = nullptr;
 
 	try
 	{
-	    if(ref.x_selection == NULL)
+	    if(ref.x_selection == nullptr)
 		throw SRC_BUG;
-	    if(ref.x_subtree == NULL)
+	    if(ref.x_subtree == nullptr)
 		throw SRC_BUG;
-	    if(ref.x_ea_mask == NULL)
+	    if(ref.x_ea_mask == nullptr)
 		throw SRC_BUG;
-	    if(ref.x_compr_mask == NULL)
+	    if(ref.x_compr_mask == nullptr)
 		throw SRC_BUG;
-	    if(ref.x_overwrite == NULL)
+	    if(ref.x_overwrite == nullptr)
 		throw SRC_BUG;
+	    if(ref.x_entrepot == nullptr)
+		throw SRC_BUG;
+
 	    x_selection = ref.x_selection->clone();
 	    x_subtree = ref.x_subtree->clone();
 	    x_ea_mask = ref.x_ea_mask->clone();
 	    x_compr_mask = ref.x_compr_mask->clone();
 	    x_overwrite = ref.x_overwrite->clone();
+	    x_entrepot = ref.x_entrepot->clone();
 
-	    if(x_selection == NULL || x_subtree == NULL || x_ea_mask == NULL || x_compr_mask == NULL || x_overwrite == NULL)
+	    if(x_selection == nullptr || x_subtree == nullptr || x_ea_mask == nullptr || x_compr_mask == nullptr || x_overwrite == nullptr || x_entrepot == nullptr)
 		throw Ememory("archive_options_extract::copy_from");
 
 	    x_ref = ref.x_ref;
 	    x_allow_over = ref.x_allow_over;
 	    x_warn_over = ref.x_warn_over;
 	    x_info_details = ref.x_info_details;
+	    x_display_treated = ref.x_display_treated;
+	    x_display_treated_only_dir = ref.x_display_treated_only_dir;
+	    x_display_skipped = ref.x_display_skipped;
 	    x_pause = ref.x_pause;
 	    x_empty_dir = ref.x_empty_dir;
 	    x_compr_algo = ref.x_compr_algo;
@@ -669,9 +894,10 @@ namespace libdar
 	    x_crypto = ref.x_crypto;
 	    x_pass = ref.x_pass;
 	    x_crypto_size = ref.x_crypto_size;
+	    x_gnupg_recipients = ref.x_gnupg_recipients;
+	    x_gnupg_signatories = ref.x_gnupg_signatories;
 	    x_min_compr_size = ref.x_min_compr_size;
 	    x_empty = ref.x_empty;
-	    x_display_skipped = ref.x_display_skipped;
 	    x_keep_compressed = ref.x_keep_compressed;
 	    x_slice_permission = ref.x_slice_permission;
 	    x_slice_user_ownership = ref.x_slice_user_ownership;
@@ -682,6 +908,8 @@ namespace libdar
 	    x_user_comment = ref.x_user_comment;
 	    x_hash = ref.x_hash;
 	    x_slice_min_digits = ref.x_slice_min_digits;
+	    x_scope = ref.x_scope;
+	    x_multi_threaded = ref.x_multi_threaded;
 	}
 	catch(...)
 	{
@@ -700,21 +928,24 @@ namespace libdar
 	NLS_SWAP_IN;
 	try
 	{
-	    archive_option_clean_mask(x_selection);
-	    archive_option_clean_mask(x_subtree);
-	    archive_option_clean_mask(x_ea_mask);
+	    archive_option_clean_mask(x_selection, get_pool());
+	    archive_option_clean_mask(x_subtree, get_pool());
+	    archive_option_clean_mask(x_ea_mask, get_pool());
 	    archive_option_clean_crit_action(x_overwrite);
 	    x_warn_over = true;
 	    x_info_details = false;
+	    x_display_treated = false;
+	    x_display_treated_only_dir = false;
+	    x_display_skipped = false;
 	    x_flat = false;
 	    x_what_to_check = default_comparison_fields;
 	    x_warn_remove_no_match = true;
 	    x_empty = false;
-	    x_display_skipped = false;
 	    x_empty_dir = true;
 	    x_dirty = dirty_warn;
 	    x_only_deleted = false;
 	    x_ignore_deleted = false;
+	    x_scope = all_fsa_families();
 	}
 	catch(...)
 	{
@@ -731,7 +962,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_selection);
 	    x_selection = selection.clone();
-	    if(x_selection == NULL)
+	    if(x_selection == nullptr)
 		throw Ememory("archive_options_extract::set_selection");
 	}
 	catch(...)
@@ -749,7 +980,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_subtree);
 	    x_subtree = subtree.clone();
-	    if(x_subtree == NULL)
+	    if(x_subtree == nullptr)
 		throw Ememory("archive_options_extract::set_subtree");
 	}
 	catch(...)
@@ -767,7 +998,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_ea_mask);
 	    x_ea_mask = ea_mask.clone();
-	    if(x_ea_mask == NULL)
+	    if(x_ea_mask == nullptr)
 		throw Ememory("archive_options_extract::set_ea_mask");
 	}
 	catch(...)
@@ -785,7 +1016,7 @@ namespace libdar
 	{
 	    archive_option_destroy_crit_action(x_overwrite);
 	    x_overwrite = over.clone();
-	    if(x_overwrite == NULL)
+	    if(x_overwrite == nullptr)
 		throw Ememory("archive_options_extract::set_overwriting_rules");
 	}
 	catch(...)
@@ -816,40 +1047,43 @@ namespace libdar
 
     void archive_options_extract::copy_from(const archive_options_extract & ref)
     {
-	x_selection = NULL;
-	x_subtree = NULL;
-	x_ea_mask = NULL;
-	x_overwrite = NULL;
+	x_selection = nullptr;
+	x_subtree = nullptr;
+	x_ea_mask = nullptr;
+	x_overwrite = nullptr;
 
 	try
 	{
-	    if(ref.x_selection == NULL)
+	    if(ref.x_selection == nullptr)
 		throw SRC_BUG;
-	    if(ref.x_subtree == NULL)
+	    if(ref.x_subtree == nullptr)
 		throw SRC_BUG;
-	    if(ref.x_ea_mask == NULL)
+	    if(ref.x_ea_mask == nullptr)
 		throw SRC_BUG;
-	    if(ref.x_overwrite == NULL)
+	    if(ref.x_overwrite == nullptr)
 		throw SRC_BUG;
 	    x_selection = ref.x_selection->clone();
 	    x_subtree = ref.x_subtree->clone();
 	    x_ea_mask = ref.x_ea_mask->clone();
 	    x_overwrite = ref.x_overwrite->clone();
 
-	    if(x_selection == NULL || x_subtree == NULL || x_ea_mask == NULL || x_overwrite == NULL)
+	    if(x_selection == nullptr || x_subtree == nullptr || x_ea_mask == nullptr || x_overwrite == nullptr)
 		throw Ememory("archive_options_extract::copy_from");
 
 	    x_warn_over = ref.x_warn_over;
 	    x_info_details = ref.x_info_details;
+	    x_display_treated = ref.x_display_treated;
+	    x_display_treated_only_dir = ref.x_display_treated_only_dir;
+	    x_display_skipped = ref.x_display_skipped;
 	    x_flat = ref.x_flat;
 	    x_what_to_check = ref.x_what_to_check;
 	    x_warn_remove_no_match = ref.x_warn_remove_no_match;
 	    x_empty = ref.x_empty;
-	    x_display_skipped = ref.x_display_skipped;
 	    x_empty_dir = ref.x_empty_dir;
 	    x_dirty = ref.x_dirty;
 	    x_only_deleted = ref.x_only_deleted;
 	    x_ignore_deleted = ref.x_ignore_deleted;
+	    x_scope = ref.x_scope;
 	}
 	catch(...)
 	{
@@ -871,8 +1105,8 @@ namespace libdar
 
 	    x_info_details = false;
 	    x_list_mode = normal;
-	    archive_option_clean_mask(x_selection);
-	    archive_option_clean_mask(x_subtree);
+	    archive_option_clean_mask(x_selection, get_pool());
+	    archive_option_clean_mask(x_subtree, get_pool());
 	    x_filter_unsaved = false;
 	    x_display_ea = false;
 	}
@@ -892,7 +1126,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_selection);
 	    x_selection = selection.clone();
-	    if(x_selection == NULL)
+	    if(x_selection == nullptr)
 		throw Ememory("archive_options_listing::set_selection");
 	}
 	catch(...)
@@ -910,7 +1144,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_subtree);
 	    x_subtree = subtree.clone();
-	    if(x_subtree == NULL)
+	    if(x_subtree == nullptr)
 		throw Ememory("archive_options_listing::set_subtree");
 	}
 	catch(...)
@@ -921,26 +1155,69 @@ namespace libdar
 	NLS_SWAP_OUT;
     }
 
+    void archive_options_listing::set_user_slicing(const infinint & slicing_first, const infinint & slicing_others)
+    {
+	if(x_slicing_first == nullptr)
+	{
+	    x_slicing_first = new (get_pool()) infinint(slicing_first);
+	    if(x_slicing_first == nullptr)
+		throw Ememory("archive_options_listing::set_user_slicing");
+	}
+	else
+	    *x_slicing_first = slicing_first;
+
+	if(x_slicing_others == nullptr)
+	{
+	    x_slicing_others = new (get_pool()) infinint(slicing_others);
+	    if(x_slicing_others == nullptr)
+		throw Ememory("archive_options_listing::set_user_slicing");
+	}
+	else
+	    *x_slicing_others = slicing_others;
+    }
 
     const mask & archive_options_listing::get_selection() const
     {
-	if(x_selection == NULL)
+	if(x_selection == nullptr)
 	    throw Erange("archive_option_listing", dar_gettext("No mask available"));
 	return *x_selection;
     }
 
     const mask & archive_options_listing::get_subtree() const
     {
-	if(x_subtree == NULL)
+	if(x_subtree == nullptr)
 	    throw Erange("archive_option_listing", dar_gettext("No mask available"));
 	return *x_subtree;
     }
 
+    bool archive_options_listing::get_user_slicing(infinint & slicing_first, infinint & slicing_others) const
+    {
+	if(x_slicing_first != nullptr && x_slicing_others != nullptr)
+	{
+	    slicing_first = *x_slicing_first;
+	    slicing_others = *x_slicing_others;
+	    return true;
+	}
+	else
+	    return false;
+    }
+
+
     void archive_options_listing::destroy()
     {
 	NLS_SWAP_IN;
 	try
 	{
+	    if(x_slicing_first != nullptr)
+	    {
+		delete x_slicing_first;
+		x_slicing_first = nullptr;
+	    }
+	    if(x_slicing_others != nullptr)
+	    {
+		delete x_slicing_others;
+		x_slicing_others = nullptr;
+	    }
 	    archive_option_destroy_mask(x_selection);
 	    archive_option_destroy_mask(x_subtree);
 	}
@@ -954,17 +1231,31 @@ namespace libdar
 
     void archive_options_listing::copy_from(const archive_options_listing & ref)
     {
-	x_selection = NULL;
-	x_subtree = NULL;
+	x_selection = nullptr;
+	x_subtree = nullptr;
+	x_slicing_first = nullptr;
+	x_slicing_others = nullptr;
 
 	try
 	{
-	    if(ref.x_selection == NULL)
+	    if(ref.x_selection == nullptr)
 		throw SRC_BUG;
 	    x_selection = ref.x_selection->clone();
 	    x_subtree = ref.x_subtree->clone();
-	    if(x_selection == NULL || x_subtree == NULL)
+	    if(x_selection == nullptr || x_subtree == nullptr)
 		throw Ememory("archive_options_listing::copy_from");
+	    if(ref.x_slicing_first != nullptr)
+	    {
+		x_slicing_first = new (get_pool()) infinint(*ref.x_slicing_first);
+		if(x_slicing_first == nullptr)
+		    throw Ememory("archive_options_listing::copy_from");
+	    }
+	    if(ref.x_slicing_others != nullptr)
+	    {
+		x_slicing_others = new (get_pool()) infinint(*ref.x_slicing_others);
+		if(x_slicing_others == nullptr)
+		    throw Ememory("archive_options_listing::copy_from");
+	    }
 
 	    x_info_details = ref.x_info_details;
 	    x_list_mode = ref.x_list_mode;
@@ -990,11 +1281,14 @@ namespace libdar
 	{
 	    destroy();
 
-	    archive_option_clean_mask(x_selection);
-	    archive_option_clean_mask(x_subtree);
+	    archive_option_clean_mask(x_selection, get_pool());
+	    archive_option_clean_mask(x_subtree, get_pool());
 	    x_info_details = false;
-	    archive_option_clean_mask(x_ea_mask);
-	    x_what_to_check = inode::cf_all;
+	    x_display_treated = false;
+	    x_display_treated_only_dir = false;
+	    x_display_skipped = false;
+	    archive_option_clean_mask(x_ea_mask, get_pool());
+	    x_what_to_check = cat_inode::cf_all;
 	    x_alter_atime = true;
 	    x_old_alter_atime = true;
 #if FURTIVE_READ_MODE_AVAILABLE
@@ -1002,9 +1296,9 @@ namespace libdar
 #else
 	    x_furtive_read = false;
 #endif
-	    x_display_skipped = false;
 	    x_hourshift = 0;
 	    x_compare_symlink_date = true;
+	    x_scope = all_fsa_families();
 	}
         catch(...)
         {
@@ -1022,7 +1316,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_selection);
 	    x_selection = selection.clone();
-	    if(x_selection == NULL)
+	    if(x_selection == nullptr)
 		throw Ememory("archive_options_diff::set_selection");
 	}
         catch(...)
@@ -1040,7 +1334,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_subtree);
 	    x_subtree = subtree.clone();
-	    if(x_subtree == NULL)
+	    if(x_subtree == nullptr)
 		throw Ememory("archive_options_diff::set_subtree");
 	}
         catch(...)
@@ -1058,7 +1352,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_ea_mask);
 	    x_ea_mask = ea_mask.clone();
-	    if(x_ea_mask == NULL)
+	    if(x_ea_mask == nullptr)
 		throw Ememory("archive_options_dif::set_ea_mask");
 	}
         catch(...)
@@ -1117,34 +1411,37 @@ namespace libdar
 
     void archive_options_diff::copy_from(const archive_options_diff & ref)
     {
-	x_selection = NULL;
-	x_subtree = NULL;
-	x_ea_mask = NULL;
+	x_selection = nullptr;
+	x_subtree = nullptr;
+	x_ea_mask = nullptr;
 
 	try
 	{
-	    if(ref.x_selection == NULL)
+	    if(ref.x_selection == nullptr)
 		throw SRC_BUG;
-	    if(ref.x_subtree == NULL)
+	    if(ref.x_subtree == nullptr)
 		throw SRC_BUG;
-	    if(ref.x_ea_mask == NULL)
+	    if(ref.x_ea_mask == nullptr)
 		throw SRC_BUG;
 
 	    x_selection = ref.x_selection->clone();
 	    x_subtree = ref.x_subtree->clone();
 	    x_ea_mask = ref.x_ea_mask->clone();
 
-	    if(x_selection == NULL || x_subtree == NULL || x_ea_mask == NULL)
+	    if(x_selection == nullptr || x_subtree == nullptr || x_ea_mask == nullptr)
 		throw Ememory("archive_options_extract::copy_from");
 
 	    x_info_details = ref.x_info_details;
+	    x_display_treated = ref.x_display_treated;
+	    x_display_treated_only_dir = ref.x_display_treated_only_dir;
+	    x_display_skipped = ref.x_display_skipped;
 	    x_what_to_check = ref.x_what_to_check;
 	    x_alter_atime = ref.x_alter_atime;
 	    x_old_alter_atime = ref.x_old_alter_atime;
 	    x_furtive_read = ref.x_furtive_read;
-	    x_display_skipped = ref.x_display_skipped;
 	    x_hourshift = ref.x_hourshift;
 	    x_compare_symlink_date = ref.x_compare_symlink_date;
+	    x_scope = ref.x_scope;
 	}
 	catch(...)
 	{
@@ -1166,11 +1463,13 @@ namespace libdar
 	{
 	    destroy();
 
-	    archive_option_clean_mask(x_selection);
-	    archive_option_clean_mask(x_subtree);
+	    archive_option_clean_mask(x_selection, get_pool());
+	    archive_option_clean_mask(x_subtree, get_pool());
 	    x_info_details = false;
-	    x_empty = false;
+	    x_display_treated = false;
+	    x_display_treated_only_dir = false;
 	    x_display_skipped = false;
+	    x_empty = false;
 	}
         catch(...)
         {
@@ -1188,7 +1487,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_selection);
 	    x_selection = selection.clone();
-	    if(x_selection == NULL)
+	    if(x_selection == nullptr)
 		throw Ememory("archive_options_test::set_selection");
 	}
         catch(...)
@@ -1206,7 +1505,7 @@ namespace libdar
 	{
 	    archive_option_destroy_mask(x_subtree);
 	    x_subtree = subtree.clone();
-	    if(x_subtree == NULL)
+	    if(x_subtree == nullptr)
 		throw Ememory("archive_option_test::set_subtree");
 	}
         catch(...)
@@ -1237,25 +1536,27 @@ namespace libdar
 
     void archive_options_test::copy_from(const archive_options_test & ref)
     {
-	x_selection = NULL;
-	x_subtree = NULL;
+	x_selection = nullptr;
+	x_subtree = nullptr;
 
 	try
 	{
-	    if(ref.x_selection == NULL)
+	    if(ref.x_selection == nullptr)
 		throw SRC_BUG;
-	    if(ref.x_subtree == NULL)
+	    if(ref.x_subtree == nullptr)
 		throw SRC_BUG;
 
 	    x_selection = ref.x_selection->clone();
 	    x_subtree = ref.x_subtree->clone();
 
-	    if(x_selection == NULL || x_subtree == NULL)
+	    if(x_selection == nullptr || x_subtree == nullptr)
 		throw Ememory("archive_options_extract::copy_from");
 
 	    x_info_details = ref.x_info_details;
-	    x_empty = ref.x_empty;
+	    x_display_treated = ref.x_display_treated;
+	    x_display_treated_only_dir = ref.x_display_treated_only_dir;
 	    x_display_skipped = ref.x_display_skipped;
+	    x_empty = ref.x_empty;
 	}
 	catch(...)
 	{
