@@ -51,7 +51,7 @@ extern "C"
 #  define strchr index
 #  define strrchr rindex
 # endif
-char *strchr (), *strrchr ();
+    char *strchr (), *strrchr ();
 # if !HAVE_MEMCPY
 #  define memcpy(d, s, n) bcopy ((s), (d), (n))
 #  define memmove(d, s, n) bcopy ((s), (d), (n))
@@ -60,7 +60,6 @@ char *strchr (), *strrchr ();
 
 } // end extern "C"
 
-#include <new>
 #include "tools.hpp"
 #include "compressor.hpp"
 
@@ -113,17 +112,18 @@ namespace libdar
             // these are eventually overwritten below
         wrapperlib_mode wr_mode = zlib_mode;
         current_algo = algo;
+	suspended = false;
 	current_level = compression_level;
 
-        if(compressed_side == NULL)
+        if(compressed_side == nullptr)
             throw SRC_BUG;
         if(compression_level > 9)
             throw SRC_BUG;
 
-        compr = decompr = NULL;
-	lzo_read_buffer = lzo_write_buffer = NULL;
-	lzo_compressed = NULL;
-	lzo_wrkmem = NULL;
+        compr = decompr = nullptr;
+	lzo_read_buffer = lzo_write_buffer = nullptr;
+	lzo_compressed = nullptr;
+	lzo_wrkmem = nullptr;
 
         switch(algo)
         {
@@ -132,19 +132,24 @@ namespace libdar
             write_ptr = &compressor::none_write;
             break;
         case bzip2:
-            wr_mode = bzlib_mode;
+	case xz:
+	    if(algo == bzip2)
+		wr_mode = bzlib_mode;
+	    if(algo == xz)
+		wr_mode = xz_mode;
+
                 // NO BREAK !
         case gzip:
             read_ptr = &compressor::gzip_read;
             write_ptr = &compressor::gzip_write;
-            compr = new (nothrow) xfer(BUFFER_SIZE, wr_mode);
-            if(compr == NULL)
+            compr = new (get_pool()) xfer(BUFFER_SIZE, wr_mode);
+            if(compr == nullptr)
                 throw Ememory("compressor::compressor");
-            decompr = new (nothrow) xfer(BUFFER_SIZE, wr_mode);
-            if(decompr == NULL)
+            decompr = new (get_pool()) xfer(BUFFER_SIZE, wr_mode);
+            if(decompr == nullptr)
             {
                 delete compr;
-		compr = NULL;
+		compr = nullptr;
                 throw Ememory("compressor::compressor");
             }
 
@@ -154,22 +159,22 @@ namespace libdar
                 break;
             case WR_MEM_ERROR:
                 delete compr;
-		compr = NULL;
+		compr = nullptr;
                 delete decompr;
-		decompr = NULL;
+		decompr = nullptr;
                 throw Ememory("compressor::compressor");
             case WR_VERSION_ERROR:
                 delete compr;
-		compr = NULL;
+		compr = nullptr;
                 delete decompr;
-		decompr = NULL;
-                throw Erange("compressor::compressor", gettext("incompatible Zlib version"));
+		decompr = nullptr;
+                throw Erange("compressor::compressor", gettext("incompatible compression library version or unsupported feature required from compression library"));
             case WR_STREAM_ERROR:
             default:
                 delete compr;
-		compr = NULL;
+		compr = nullptr;
                 delete decompr;
-		decompr = NULL;
+		decompr = nullptr;
                 throw SRC_BUG;
             }
 
@@ -181,24 +186,24 @@ namespace libdar
             case WR_MEM_ERROR:
                 compr->wrap.compressEnd();
                 delete compr;
-		compr = NULL;
+		compr = nullptr;
                 delete decompr;
-		decompr = NULL;
+		decompr = nullptr;
                 throw Ememory("compressor::compressor");
             case WR_VERSION_ERROR:
                 compr->wrap.compressEnd();
                 delete compr;
-		compr = NULL;
+		compr = nullptr;
                 delete decompr;
-		decompr = NULL;
-                throw Erange("compressor::compressor", gettext("incompatible Zlib version"));
+		decompr = nullptr;
+                throw Erange("compressor::compressor", gettext("incompatible compression library version or unsupported feature required from compression library"));
             case WR_STREAM_ERROR:
             default:
                 compr->wrap.compressEnd();
                 delete compr;
-		compr = NULL;
+		compr = nullptr;
                 delete decompr;
-		decompr = NULL;
+		decompr = nullptr;
                 throw SRC_BUG;
             }
             break;
@@ -212,34 +217,34 @@ namespace libdar
 	    lzo_read_reached_eof = false;
 	    try
 	    {
-		lzo_read_buffer = new (nothrow) char[LZO_CLEAR_BUFFER_SIZE];
-		lzo_write_buffer = new (nothrow) char[LZO_CLEAR_BUFFER_SIZE];
-		lzo_compressed = new (nothrow) char[LZO_COMPRESSED_BUFFER_SIZE];
-		lzo_wrkmem = new (nothrow) char[LZO1X_999_MEM_COMPRESS];
-		if(lzo_read_buffer == NULL || lzo_write_buffer == NULL || lzo_compressed == NULL || lzo_wrkmem == NULL)
+		meta_new(lzo_read_buffer, LZO_CLEAR_BUFFER_SIZE);
+		meta_new(lzo_write_buffer, LZO_CLEAR_BUFFER_SIZE);
+		meta_new(lzo_compressed, LZO_COMPRESSED_BUFFER_SIZE);
+		meta_new(lzo_wrkmem, LZO1X_999_MEM_COMPRESS);
+		if(lzo_read_buffer == nullptr || lzo_write_buffer == nullptr || lzo_compressed == nullptr || lzo_wrkmem == nullptr)
 		    throw Ememory("compressor::init");
 	    }
 	    catch(...)
 	    {
-		if(lzo_read_buffer != NULL)
+		if(lzo_read_buffer != nullptr)
 		{
-		    delete [] lzo_read_buffer;
-		    lzo_read_buffer = NULL;
+		    meta_delete(lzo_read_buffer);
+		    lzo_read_buffer = nullptr;
 		}
-		if(lzo_write_buffer != NULL)
+		if(lzo_write_buffer != nullptr)
 		{
-		    delete [] lzo_write_buffer;
-		    lzo_write_buffer = NULL;
+		    meta_delete(lzo_write_buffer);
+		    lzo_write_buffer = nullptr;
 		}
-		if(lzo_compressed != NULL)
+		if(lzo_compressed != nullptr)
 		{
-		    delete [] lzo_compressed;
-		    lzo_compressed = NULL;
+		    meta_delete(lzo_compressed);
+		    lzo_compressed = nullptr;
 		}
-		if(lzo_wrkmem != NULL)
+		if(lzo_wrkmem != nullptr)
 		{
-		    delete [] lzo_wrkmem;
-		    lzo_wrkmem = NULL;
+		    meta_delete(lzo_wrkmem);
+		    lzo_wrkmem = nullptr;
 		}
 		throw;
 	    }
@@ -264,36 +269,55 @@ namespace libdar
 	{
 		// ignore all exceptions
 	}
-	if(compr != NULL)
+	if(compr != nullptr)
 	    delete compr;
-	if(decompr != NULL)
+	if(decompr != nullptr)
 	    delete decompr;
-	if(lzo_read_buffer != NULL)
-	    delete [] lzo_read_buffer;
-	if(lzo_write_buffer != NULL)
-	    delete [] lzo_write_buffer;
-	if(lzo_compressed != NULL)
-	    delete [] lzo_compressed;
-	if(lzo_wrkmem != NULL)
-	    delete [] lzo_wrkmem;
+	if(lzo_read_buffer != nullptr)
+	    meta_delete(lzo_read_buffer);
+	if(lzo_write_buffer != nullptr)
+	    meta_delete(lzo_write_buffer);
+	if(lzo_compressed != nullptr)
+	    meta_delete(lzo_compressed);
+	if(lzo_wrkmem != nullptr)
+	    meta_delete(lzo_wrkmem);
 	if(compressed_owner)
-	    if(compressed != NULL)
+	    if(compressed != nullptr)
 		delete compressed;
     }
 
+    void compressor::suspend_compression()
+    {
+	if(!suspended)
+	{
+	    suspended_compr = current_algo;
+	    change_algo(none);
+	    suspended = true;
+	}
+    }
+
+    void compressor::resume_compression()
+    {
+	if(suspended)
+	{
+	    change_algo(suspended_compr);
+	    suspended = false;
+	}
+    }
+
     void compressor::local_terminate()
     {
-        if(compr != NULL)
+        if(compr != nullptr)
         {
             S_I ret;
 
                 // flushing the pending data
-	    flush_write();
+	    compr_flush_write();
             clean_write();
 
             ret = compr->wrap.compressEnd();
             delete compr;
-	    compr = NULL;
+	    compr = nullptr;
 
             switch(ret)
             {
@@ -308,15 +332,15 @@ namespace libdar
             }
         }
 
-        if(decompr != NULL)
+        if(decompr != nullptr)
         {
                 // flushing data
-            flush_read();
+            compr_flush_read();
             clean_read();
 
             S_I ret = decompr->wrap.decompressEnd();
             delete decompr;
-	    decompr = NULL;
+	    decompr = nullptr;
 
             switch(ret)
             {
@@ -327,32 +351,32 @@ namespace libdar
             }
         }
 
-	if(lzo_read_buffer != NULL)
+	if(lzo_read_buffer != nullptr)
 	{
-	    flush_read();
+	    compr_flush_read();
 	    clean_read();
-	    delete [] lzo_read_buffer;
-	    lzo_read_buffer = NULL;
+	    meta_delete(lzo_read_buffer);
+	    lzo_read_buffer = nullptr;
 	}
 
-	if(lzo_write_buffer != NULL)
+	if(lzo_write_buffer != nullptr)
 	{
-	    flush_write();
+	    compr_flush_write();
 	    clean_write();
-	    delete [] lzo_write_buffer;
-	    lzo_write_buffer = NULL;
+	    meta_delete(lzo_write_buffer);
+	    lzo_write_buffer = nullptr;
 	}
 
-	if(lzo_compressed != NULL)
+	if(lzo_compressed != nullptr)
 	{
-	    delete [] lzo_compressed;
-	    lzo_compressed = NULL;
+	    meta_delete(lzo_compressed);
+	    lzo_compressed = nullptr;
 	}
 
-	if(lzo_wrkmem != NULL)
+	if(lzo_wrkmem != nullptr)
 	{
-	    delete [] lzo_wrkmem;
-	    lzo_wrkmem = NULL;
+	    meta_delete(lzo_wrkmem);
+	    lzo_wrkmem = nullptr;
 	}
     }
 
@@ -371,18 +395,17 @@ namespace libdar
         init(new_algo, compressed, new_compression_level);
     }
 
-
     compressor::xfer::xfer(U_I sz, wrapperlib_mode mode) : wrap(mode)
     {
-        buffer = new (nothrow) char[sz];
-        if(buffer == NULL)
+        meta_new(buffer, sz);
+        if(buffer == nullptr)
             throw Ememory("compressor::xfer::xfer");
         size = sz;
     }
 
     compressor::xfer::~xfer()
     {
-        delete [] buffer;
+        meta_delete(buffer);
     }
 
     U_I compressor::none_read(char *a, U_I size)
@@ -466,7 +489,7 @@ namespace libdar
         compr->wrap.set_next_in(a);
         compr->wrap.set_avail_in(size);
 
-        if(a == NULL)
+        if(a == nullptr)
             throw SRC_BUG;
 
         while(compr->wrap.get_avail_in() > 0)
@@ -560,14 +583,14 @@ namespace libdar
 #endif
     }
 
-    void compressor::flush_write()
+    void compressor::compr_flush_write()
     {
         S_I ret;
 
 	if(is_terminated())
 	    throw SRC_BUG;
 
-        if(compr != NULL && compr->wrap.get_total_in() != 0)  // (z/bz)lib
+        if(compr != nullptr && compr->wrap.get_total_in() != 0)  // (z/bz)lib
         {
                 // no more input
             compr->wrap.set_avail_in(0);
@@ -600,26 +623,26 @@ namespace libdar
                 throw SRC_BUG;
         }
 
-	if(lzo_write_buffer != NULL && ! lzo_write_flushed) // lzo
+	if(lzo_write_buffer != nullptr && ! lzo_write_flushed) // lzo
 	{
 	    lzo_block_header lzo_bh;
 
 	    lzo_compress_buffer_and_write();
 	    lzo_bh.type = BLOCK_HEADER_EOF;
 	    lzo_bh.size = 0;
-	    if(compressed == NULL)
+	    if(compressed == nullptr)
 		throw SRC_BUG;
 	    lzo_bh.dump(*compressed);
 	    lzo_write_flushed = true;
 	}
     }
 
-    void compressor::flush_read()
+    void compressor::compr_flush_read()
     {
 	if(is_terminated())
 	    throw SRC_BUG;
 
-        if(decompr != NULL) // zlib
+        if(decompr != nullptr) // zlib
             if(decompr->wrap.decompressReset() != WR_OK)
                 throw SRC_BUG;
             // keep in the buffer the bytes already read, these are discarded in case of a call to skip
@@ -631,10 +654,10 @@ namespace libdar
 	if(is_terminated())
 	    throw SRC_BUG;
 
-        if(decompr != NULL)
+        if(decompr != nullptr)
             decompr->wrap.set_avail_in(0);
 
-	if(lzo_read_buffer != NULL) // lzo
+	if(lzo_read_buffer != nullptr) // lzo
 	{
 	    lzo_read_start = 0;
 	    lzo_read_size = 0;
@@ -646,7 +669,7 @@ namespace libdar
 	if(is_terminated())
 	    throw SRC_BUG;
 
-        if(compr != NULL)
+        if(compr != nullptr)
         {
             S_I ret;
 
@@ -661,7 +684,7 @@ namespace libdar
             while(ret == WR_OK);
         }
 
-	if(lzo_write_buffer != NULL) // lzo
+	if(lzo_write_buffer != nullptr) // lzo
 	    lzo_write_size = 0;
     }
 
@@ -675,7 +698,7 @@ namespace libdar
 
 	    //compressing data to lzo_compress buffer
 
-	status = lzo1x_999_compress_level((lzo_bytep)lzo_write_buffer, lzo_write_size, (lzo_bytep)lzo_compressed, &compr_size, lzo_wrkmem, NULL, 0, 0, current_level);
+	status = lzo1x_999_compress_level((lzo_bytep)lzo_write_buffer, lzo_write_size, (lzo_bytep)lzo_compressed, &compr_size, lzo_wrkmem, nullptr, 0, 0, current_level);
 
 	switch(status)
 	{
@@ -688,7 +711,7 @@ namespace libdar
 	    // writing down the TL(V) before the compressed data
 	lzo_bh.type = BLOCK_HEADER_LZO;
 	lzo_bh.size = compr_size;
-	if(compressed == NULL)
+	if(compressed == nullptr)
 	    throw SRC_BUG;
 
 	lzo_bh.dump(*compressed);
@@ -709,10 +732,10 @@ namespace libdar
 #if LZO1X_MEM_DECOMPRESS > 0
 	char wrkmem[LZO1X_MEM_DECOMPRESS];
 #else
-	char *wrkmem = NULL;
+	char *wrkmem = nullptr;
 #endif
 
-	if(compressed == NULL)
+	if(compressed == nullptr)
 	    throw SRC_BUG;
 
 	lzo_bh.set_from(*compressed);
@@ -789,6 +812,8 @@ namespace libdar
             return bzip2;
 	case 'l':
 	    return lzo;
+	case 'x':
+	    return xz;
         default :
             throw Erange("char2compression", gettext("unknown compression"));
         }
@@ -806,6 +831,8 @@ namespace libdar
             return 'y';
 	case lzo:
 	    return 'l';
+	case xz:
+	    return 'x';
         default:
             throw Erange("compression2char", gettext("unknown compression"));
         }
@@ -823,6 +850,8 @@ namespace libdar
             return "bzip2";
 	case lzo:
 	    return "lzo";
+	case xz:
+	    return "xz";
         default:
             throw Erange("compresion2string", gettext("unknown compression"));
         }
@@ -839,6 +868,9 @@ namespace libdar
 	if(a == "lzo" || a == "lz" || a == "l")
 	    return lzo;
 
+	if(a == "xz" || a == "lzma")
+	    return xz;
+
 	throw Erange("string2compression", tools_printf(gettext("unknown compression algorithm: %S"), &a));
     }
 
