@@ -45,7 +45,8 @@ namespace libdar
 	none = 'n',  ///< no compression
 	gzip = 'z',  ///< gzip compression
 	bzip2 = 'y', ///< bzip2 compression
-	lzo = 'l'    ///< lzo compression
+	lzo = 'l',   ///< lzo compression
+	xz = 'x'     ///< lzma compression
     };
 
 	/// \ingroup Private
@@ -68,44 +69,30 @@ namespace libdar
             // deleted a destructor time
         ~compressor();
 
-        void flush_write(); // flush all data to compressed_side, and reset the compressor
-            // for that additional write can be uncompresssed starting at this point.
-        void flush_read(); // reset decompression engine to be able to read the next block of compressed data
-            // if not called, furthur read return EOF
-        void clean_read(); // discard any byte buffered and not yet returned by read()
-        void clean_write(); // discard any byte buffered and not yet wrote to compressed_side;
-
         compression get_algo() const { return current_algo; };
 
-	    /// changes compression algorithm used by the compressor
+	void suspend_compression();
+	void resume_compression();
+	bool is_compression_suspended() const { return suspended; };
 
-	    /// \param[in] new_algo defines the new algorithm to use
-	    /// \param[in] new_compression_level defines the new compression level to use.
-            /// \note valid value for new_compression_level range from 0 (no compression) to
-	    /// 9 (maximum compression).
-        void change_algo(compression new_algo, U_I new_compression_level);
-
-
-	    /// changes the compression algorithm keeping the same compression level
-
-        void change_algo(compression new_algo)
-	{
-	    change_algo(new_algo, current_level);
-	};
 
             // inherited from generic file
-        bool skip(const infinint & pos) { flush_write(); flush_read(); clean_read(); return compressed->skip(pos); };
-        bool skip_to_eof()  { flush_write(); flush_read(); clean_read(); return compressed->skip_to_eof(); };
-        bool skip_relative(S_I x) { flush_write(); flush_read(); clean_read(); return compressed->skip_relative(x); };
-        infinint get_position() { return compressed->get_position(); };
+	bool skippable(skippability direction, const infinint & amount) { return compressed->skippable(direction, amount); };
+        bool skip(const infinint & pos) { compr_flush_write(); compr_flush_read(); clean_read(); return compressed->skip(pos); };
+        bool skip_to_eof()  { compr_flush_write(); compr_flush_read(); clean_read(); return compressed->skip_to_eof(); };
+        bool skip_relative(S_I x) { compr_flush_write(); compr_flush_read(); clean_read(); return compressed->skip_relative(x); };
+        infinint get_position() const { return compressed->get_position(); };
 
     protected :
+	void inherited_read_ahead(const infinint & amount) { compressed->read_ahead(amount); };
         U_I inherited_read(char *a, U_I size) { return (this->*read_ptr)(a, size); };
         void inherited_write(const char *a, U_I size) { (this->*write_ptr)(a, size); };
-	void inherited_sync_write() { flush_write(); };
+	void inherited_sync_write() { compr_flush_write(); };
+	void inherited_flush_read() { compr_flush_read(); clean_read(); };
 	void inherited_terminate() { local_terminate(); };
+
     private :
-        struct xfer
+        struct xfer : public on_pool
         {
             wrapperlib wrap;
             char *buffer;
@@ -140,6 +127,8 @@ namespace libdar
         generic_file *compressed;
         bool compressed_owner;
         compression current_algo;
+	bool suspended;
+	compression suspended_compr;
 	U_I current_level;
 
         void init(compression algo, generic_file *compressed_side, U_I compression_level);
@@ -160,6 +149,28 @@ namespace libdar
 
 	void lzo_compress_buffer_and_write();
 	void lzo_read_and_uncompress_to_buffer();
+
+	    /// changes compression algorithm used by the compressor
+
+	    /// \param[in] new_algo defines the new algorithm to use
+	    /// \param[in] new_compression_level defines the new compression level to use.
+            /// \note valid value for new_compression_level range from 0 (no compression) to
+	    /// 9 (maximum compression).
+        void change_algo(compression new_algo, U_I new_compression_level);
+
+
+	    /// changes the compression algorithm keeping the same compression level
+
+        void change_algo(compression new_algo)
+	{ change_algo(new_algo, current_level);	};
+
+
+        void compr_flush_write(); // flush all data to compressed_side, and reset the compressor
+            // for that additional write can be uncompresssed starting at this point.
+        void compr_flush_read(); // reset decompression engine to be able to read the next block of compressed data
+            // if not called, furthur read return EOF
+        void clean_read(); // discard any byte buffered and not yet returned by read()
+        void clean_write(); // discard any byte buffered and not yet wrote to compressed_side;
     };
 
 	/// @}
