@@ -28,16 +28,16 @@
 
 #include "../my_config.h"
 
-	/// \ingroup Private
-	/// @}
+    /// \ingroup Private
+    /// @}
 
 extern "C"
 {
 #if HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
-    // if fcntl.h does not define O_TEXT nor O_BINARY (which is a Cygwin
-    // speciality), we define them as neutral ORed values : zero
+	// if fcntl.h does not define O_TEXT nor O_BINARY (which is a Cygwin
+	// speciality), we define them as neutral ORed values : zero
 } // end extern "C"
 
 #ifndef O_TEXT
@@ -48,6 +48,9 @@ extern "C"
 #ifndef O_BINARY
 // zero is neutral in ORed expression where it is expected to be used
 #define O_BINARY 0
+#else
+#define CYGWIN_BUILD 1
+// if O_BINARY is defined we are compiling on or for a cygwin plateform
 #endif
 
     ///    @}
