@@ -39,25 +39,26 @@ extern "C"
 } // end extern "C"
 
 #include <iomanip>
-#include <new>
 
 #include "data_tree.hpp"
 #include "tools.hpp"
 #include "user_interaction.hpp"
 #include "deci.hpp"
 #include "path.hpp"
+#include "datetime.hpp"
+#include "cat_all_entrees.hpp"
 
 using namespace std;
 using namespace libdar;
 
-static data_tree *read_from_file(generic_file & f, unsigned char db_version);
+static data_tree *read_from_file(generic_file & f, unsigned char db_version, memory_pool *pool);
 static void read_from_file(generic_file &f, archive_num &a);
 static void write_to_file(generic_file &f, archive_num a);
 static void display_line(user_interaction & dialog,
 			 archive_num num,
-			 const infinint *data,
+			 const datetime *data,
 			 data_tree::etat data_presence,
-			 const infinint *ea,
+			 const datetime *ea,
 			 data_tree::etat ea_presence);
 
 #define ETAT_SAVED 'S'
@@ -89,11 +90,11 @@ namespace libdar
 	}
     }
 
-    void data_tree::status::read(generic_file & f)
+    void data_tree::status::read(generic_file & f, unsigned char db_version)
     {
 	char tmp;
 
-	date.read(f);
+	date.read(f, db2archive_version(db_version));
 	if(f.read(&tmp, 1) != 1)
 	    throw Erange("data_tree::status::read", gettext("reached End of File before all expected data could be read"));
 	switch(tmp)
@@ -128,7 +129,7 @@ namespace libdar
 	    // signature has already been read
 	tools_read_string(f, filename);
 	infinint tmp = infinint(f); // number of entry in last_mod map
-	while(tmp > 0)
+	while(!tmp.is_zero())
 	{
 	    read_from_file(f, k);
 	    switch(db_version)
@@ -140,7 +141,8 @@ namespace libdar
 		break;
 	    case 2:
 	    case 3:
-		sta.read(f);
+	    case 4:
+		sta.read(f, db_version);
 		last_mod[k] = sta;
 		break;
 	    default: // unsupported database version
@@ -150,7 +152,7 @@ namespace libdar
 	}
 
 	tmp = infinint(f); // number of entry in last_change map
-	while(tmp > 0)
+	while(!tmp.is_zero())
 	{
 	    read_from_file(f, k);
 	    switch(db_version)
@@ -162,7 +164,8 @@ namespace libdar
 		break;
 	    case 2:
 	    case 3:
-		sta.read(f);
+	    case 4:
+		sta.read(f, db_version);
 		last_change[k] = sta;
 		break;
 	    default:
@@ -202,10 +205,10 @@ namespace libdar
     }
 
 
-    data_tree::lookup data_tree::get_data(archive_num & archive, const infinint & date, bool even_when_removed) const
+    data_tree::lookup data_tree::get_data(archive_num & archive, const datetime & date, bool even_when_removed) const
     {
 	map<archive_num, status>::const_iterator it = last_mod.begin();
-	infinint max_seen = 0, max_real = 0;
+	datetime max_seen = datetime(0), max_real = datetime(0);
 	    //archive (first argument) carries the last archive number (in the order of the database) in which a valid entry has been
 	    //found, but which is not just a record "et_present" meaning that the file existed but has not been saved (differential backup context) or "et_absent" (no entry in the corresponding archive).
 	archive_num archive_seen = 0; //< last archive number (in the order of the database) in which a valid entry has been found (any state)
@@ -219,7 +222,7 @@ namespace libdar
 	{
 	    if(it->second.date >= max_seen  // > and = because there should never be twice the same value
 		   // and we must be able to see a value of 0 (initially max = 0) which is valid.
-	       && (date == 0 || it->second.date <= date))
+	       && (date.is_null() || it->second.date <= date))
 	    {
 		max_seen = it->second.date;
 		archive_seen = it->first;
@@ -240,7 +243,7 @@ namespace libdar
 
 	    if(it->second.date >= max_real  // > and = because there should never be twice the same value
 		   // and we must be able to see a value of 0 (initially max = 0) which is valid.
-	       && (date == 0 || it->second.date <= date))
+	       && (date.is_null() || it->second.date <= date))
 	    {
 		if(it->second.present != et_present)
 		{
@@ -304,10 +307,10 @@ namespace libdar
 	return ret;
     }
 
-    data_tree::lookup data_tree::get_EA(archive_num & archive, const infinint & date, bool even_when_removed) const
+    data_tree::lookup data_tree::get_EA(archive_num & archive, const datetime & date, bool even_when_removed) const
     {
 	map<archive_num, status>::const_iterator it = last_change.begin();
-	infinint max_seen = 0, max_real = 0;
+	datetime max_seen = datetime(0), max_real = datetime(0);
 	bool presence_seen = false, presence_real = false;
 	archive_num archive_seen = 0;
 	archive_num archive_even_when_removed = 0;
@@ -318,7 +321,7 @@ namespace libdar
 	{
 	    if(it->second.date >= max_seen  // > and = because there should never be twice the same value
 		   // and we must be able to see a value of 0 (initially max = 0) which is valid.
-	       && (date == 0 || it->second.date <= date))
+	       && (date.is_null() || it->second.date <= date))
 	    {
 		max_seen = it->second.date;
 		archive_seen = it->first;
@@ -339,7 +342,7 @@ namespace libdar
 
 	    if(it->second.date >= max_real  // > and = because there should never be twice the same value
 		   // and we must be able to see a value of 0 (initially max = 0) which is valid.
-	       && (date == 0 || it->second.date <= date))
+	       && (date.is_null() || it->second.date <= date))
 	    {
 		if(it->second.present != et_present)
 		{
@@ -396,7 +399,7 @@ namespace libdar
 	return ret;
     }
 
-    bool data_tree::read_data(archive_num num, infinint & val, etat & present) const
+    bool data_tree::read_data(archive_num num, datetime & val, etat & present) const
     {
 	map<archive_num, status>::const_iterator it = last_mod.find(num);
 
@@ -410,7 +413,7 @@ namespace libdar
 	    return false;
     }
 
-    bool data_tree::read_EA(archive_num num, infinint & val, etat & present) const
+    bool data_tree::read_EA(archive_num num, datetime & val, etat & present) const
     {
 	map<archive_num, status>::const_iterator it = last_change.find(num);
 
@@ -424,12 +427,14 @@ namespace libdar
 	    return false;
     }
 
-    void data_tree::finalize(const archive_num & archive, const infinint & deleted_date, const archive_num & ignore_archives_greater_or_equal)
+    void data_tree::finalize(const archive_num & archive,
+			     const datetime & deleted_date,
+			     const archive_num & ignore_archives_greater_or_equal)
     {
 	map<archive_num, status>::iterator it = last_mod.begin();
 	bool presence_max = false;
 	archive_num num_max = 0;
-	infinint last_mtime = 0; // used as deleted_date for EA if last mtime is found
+	datetime last_mtime = datetime(0); // used as deleted_date for EA if last mtime is found
 	bool found_in_archive = false;
 
 	    // checking the last_mod map
@@ -475,12 +480,21 @@ namespace libdar
 		    // archive we currently add.
 
 		if(deleted_date > last_mtime)
-		    set_data(archive, deleted_date, et_absent); // add an entry telling that this file does no more exist in the current archive
+		    set_data(archive, deleted_date, et_absent);
+		    // add an entry telling that this file does no more exist in the current archive
 		else
-		    set_data(archive, last_mtime + 1, et_absent);
+		    set_data(archive, last_mtime, et_absent);
+		    // add an entry telling thatthis file does no more exists, using the last known date
+		    // as deleted data. This situation may appear when one makes a first backup
+		    // then a second one but excluding from the backup that particular file. This file
+		    // may reappear later with if is backup included in the backup possibily with the same
+		    // date. In 2.4.x we added 1 second to the last known date to create the deleted date
+		    // which lead out of order warning to show for the database. Since 2.5.x date resolution
+		    // may be one microsecond (no more 1 second) thus we now keep the last known date as
+		    // delete date
 	    }
 	    else // the entry has been seen previously but as removed in the latest state,
-		// if we already have an et_absent entry (which is possible during a reordering archive operation within a database), we can (and must) suppress it.
+		    // if we already have an et_absent entry (which is possible during a reordering archive operation within a database), we can (and must) suppress it.
 	    {
 		map<archive_num, status>::iterator it = last_mod.find(archive);
 		if(it != last_mod.end()) // we have an entry associated to this archive
@@ -562,19 +576,19 @@ namespace libdar
 	    //   - this entry does not only exist in the archive about to be removed
 	if(archive_to_remove < last_archive)
 	{
-	    infinint del_date;
+	    datetime del_date;
 	    etat status;
 	    if(last_mod.size() > 1 && read_data(archive_to_remove, del_date, status))
 		if(status == et_removed)
 		{
-		    infinint tmp;
+		    datetime tmp;
 		    if(!read_data(archive_to_remove + 1, tmp, status))
 			set_data(archive_to_remove + 1, del_date, et_removed);
 		}
 	    if(last_change.size() > 1 && read_EA(archive_to_remove, del_date, status))
 		if(status == et_removed)
 		{
-		    infinint tmp;
+		    datetime tmp;
 		    if(!read_EA(archive_to_remove + 1, tmp, status))
 			set_EA(archive_to_remove + 1, del_date, et_removed);
 		}
@@ -627,22 +641,22 @@ namespace libdar
 		    else // not in the same archive
 			if(it->first < ut->first) // it only
 			{
-			    display_line(dialog, it->first, &(it->second.date), it->second.present, NULL, data_tree::et_removed);
+			    display_line(dialog, it->first, &(it->second.date), it->second.present, nullptr, data_tree::et_removed);
 			    ++it;
 			}
 			else // ut only
 			{
-			    display_line(dialog, ut->first, NULL, data_tree::et_removed, &(ut->second.date), ut->second.present);
+			    display_line(dialog, ut->first, nullptr, data_tree::et_removed, &(ut->second.date), ut->second.present);
 			    ++ut;
 			}
 		else // ut at end of list thus it != last_mod.end() (see while condition)
 		{
-		    display_line(dialog, it->first, &(it->second.date), it->second.present, NULL, data_tree::et_removed);
+		    display_line(dialog, it->first, &(it->second.date), it->second.present, nullptr, data_tree::et_removed);
 		    ++it;
 		}
 	    else // it at end of list, this ut != last_change.end() (see while condition)
 	    {
-		display_line(dialog, ut->first, NULL, data_tree::et_removed, &(ut->second.date), ut->second.present);
+		display_line(dialog, ut->first, nullptr, data_tree::et_removed, &(ut->second.date), ut->second.present);
 		++ut;
 	    }
 	}
@@ -704,7 +718,7 @@ namespace libdar
 					      vector<infinint> & total_data, vector<infinint> & total_ea) const
     {
 	archive_num most_recent = 0;
-	infinint max = 0;
+	datetime max = datetime(0);
 	map<archive_num, status>::const_iterator it = last_mod.begin();
 
 	while(it != last_mod.end())
@@ -724,7 +738,7 @@ namespace libdar
 	    ++data[most_recent];
 
 	most_recent = 0;
-	max = 0;
+	max = datetime(0);
 	it = last_change.begin();
 
 	while(it != last_change.end())
@@ -748,16 +762,16 @@ namespace libdar
 
     struct trecord
     {
-	infinint date;
+	datetime date;
 	bool set;
 
-	trecord() { set = false; date = 0; };
+	trecord() { set = false; date = datetime(0); };
 	trecord(const trecord & ref) { date = ref.date; set = ref.set; };
 	const trecord & operator = (const trecord & ref) { date = ref.date; set = ref.set; return *this; };
     };
 
 
-bool data_tree::fix_corruption()
+    bool data_tree::fix_corruption()
     {
 	bool ret = true;
 	map<archive_num, status>::iterator it = last_mod.begin();
@@ -794,7 +808,7 @@ bool data_tree::fix_corruption()
 	vector<trecord> dates = vector<trecord>(dates_size);
 	map<archive_num, status>::const_iterator it = the_map.begin();
 	vector<trecord>::iterator rec_it;
-	infinint last_date = 0;
+	datetime last_date = datetime(0);
 
 	    // now the algorithm
 
@@ -863,18 +877,18 @@ bool data_tree::fix_corruption()
     data_dir::data_dir(generic_file &f, unsigned char db_version) : data_tree(f, db_version)
     {
 	infinint tmp = infinint(f); // number of children
-	data_tree *entry = NULL;
+	data_tree *entry = nullptr;
 	rejetons.clear();
 
 	try
 	{
-	    while(tmp > 0)
+	    while(!tmp.is_zero())
 	    {
-		entry = read_from_file(f, db_version);
-		if(entry == NULL)
+		entry = read_from_file(f, db_version, get_pool());
+		if(entry == nullptr)
 		    throw Erange("data_dir::data_dir", gettext("Unexpected end of file"));
 		rejetons.push_back(entry);
-		entry = NULL;
+		entry = nullptr;
 		--tmp;
 	    }
 	}
@@ -884,10 +898,10 @@ bool data_tree::fix_corruption()
 	    while(next != rejetons.end())
 	    {
 		delete *next;
-		*next = NULL;
+		*next = nullptr;
 		++next;
 	    }
-	    if(entry != NULL)
+	    if(entry != nullptr)
 		delete entry;
 	    throw;
 	}
@@ -909,7 +923,7 @@ bool data_tree::fix_corruption()
 	while(next != rejetons.end())
 	{
 	    delete *next;
-	    *next = NULL;
+	    *next = nullptr;
 	    ++next;
 	}
     }
@@ -923,7 +937,7 @@ bool data_tree::fix_corruption()
 	tmp.dump(f);
 	while(it != rejetons.end())
 	{
-	    if(*it == NULL)
+	    if(*it == nullptr)
 		throw SRC_BUG;
 	    (*it)->dump(f);
 	    ++it;
@@ -934,15 +948,15 @@ bool data_tree::fix_corruption()
     data_tree *data_dir::find_or_addition(const string & name, bool is_dir, const archive_num & archive)
     {
 	const data_tree *fils = read_child(name);
-	data_tree *ret = NULL;
+	data_tree *ret = nullptr;
 
-	if(fils == NULL) // brand-new data_tree to build
+	if(fils == nullptr) // brand-new data_tree to build
 	{
 	    if(is_dir)
-		ret = new (nothrow) data_dir(name);
+		ret = new (get_pool()) data_dir(name);
 	    else
-		ret = new (nothrow) data_tree(name);
-	    if(ret == NULL)
+		ret = new (get_pool()) data_tree(name);
+	    if(ret == nullptr)
 		throw Ememory("data_dir::find_or_addition");
 	    add_child(ret);
 	}
@@ -950,10 +964,10 @@ bool data_tree::fix_corruption()
 	{
 		// check if dir/file nature has changed
 	    const data_dir *fils_dir = dynamic_cast<const data_dir *>(fils);
-	    if(fils_dir == NULL && is_dir) // need to upgrade data_tree to data_dir
+	    if(fils_dir == nullptr && is_dir) // need to upgrade data_tree to data_dir
 	    {
-		ret = new (nothrow) data_dir(*fils); // upgrade data_tree in an empty data_dir
-		if(ret == NULL)
+		ret = new (get_pool()) data_dir(*fils); // upgrade data_tree in an empty data_dir
+		if(ret == nullptr)
 		    throw Ememory("data_dir::find_or_addition");
 		try
 		{
@@ -973,13 +987,13 @@ bool data_tree::fix_corruption()
 	return ret;
     }
 
-    void data_dir::add(const inode *entry, const archive_num & archive)
+    void data_dir::add(const cat_inode *entry, const archive_num & archive)
     {
-	const directory *entry_dir = dynamic_cast<const directory *>(entry);
-	data_tree * tree = find_or_addition(entry->get_name(), entry_dir != NULL, archive);
+	const cat_directory *entry_dir = dynamic_cast<const cat_directory *>(entry);
+	data_tree * tree = find_or_addition(entry->get_name(), entry_dir != nullptr, archive);
 	archive_num last_archive;
 	lookup result;
-	infinint last_mod = entry->get_last_modif() > entry->get_last_change() ? entry->get_last_modif() : entry->get_last_change();
+	datetime last_mod = entry->get_last_modif() > entry->get_last_change() ? entry->get_last_modif() : entry->get_last_change();
 
 	switch(entry->get_saved_status())
 	{
@@ -996,19 +1010,19 @@ bool data_tree::fix_corruption()
 
 	switch(entry->ea_get_saved_status())
 	{
-	case inode::ea_none:
+	case cat_inode::ea_none:
 	    break;
-	case inode::ea_removed:
-	    result = tree->get_EA(last_archive, 0, false);
+	case cat_inode::ea_removed:
+	    result = tree->get_EA(last_archive, datetime(0), false);
 	    if(result == found_present || result == not_restorable)
 		tree->set_EA(archive, entry->get_last_change(), et_removed);
 		// else no need to add an et_remove entry in the map
 	    break;
-	case inode::ea_partial:
+	case cat_inode::ea_partial:
 	    tree->set_EA(archive, entry->get_last_change(), et_present);
 	    break;
-	case inode::ea_fake:
-	case inode::ea_full:
+	case cat_inode::ea_fake:
+	case cat_inode::ea_full:
 	    tree->set_EA(archive, entry->get_last_change(), et_saved);
 	    break;
 	default:
@@ -1016,16 +1030,16 @@ bool data_tree::fix_corruption()
 	}
     }
 
-    void data_dir::add(const detruit *entry, const archive_num & archive)
+    void data_dir::add(const cat_detruit *entry, const archive_num & archive)
     {
 	data_tree * tree = find_or_addition(entry->get_name(), false, archive);
 	archive_num last_archive;
 	lookup result;
 
-	result = tree->get_data(last_archive, 0, false);
+	result = tree->get_data(last_archive, datetime(0), false);
 	if(result == found_present || result == not_restorable)
 	    tree->set_data(archive, entry->get_date(), et_removed);
-	result = tree->get_EA(last_archive, 0, false);
+	result = tree->get_EA(last_archive, datetime(0), false);
 	if(result == found_present || result == not_restorable)
 	    tree->set_EA(archive, entry->get_date(), et_removed);
     }
@@ -1034,13 +1048,13 @@ bool data_tree::fix_corruption()
     {
 	list<data_tree *>::const_iterator it = rejetons.begin();
 
-	while(it != rejetons.end() && *it != NULL && (*it)->get_name() != name)
+	while(it != rejetons.end() && *it != nullptr && (*it)->get_name() != name)
 	    ++it;
 
 	if(it == rejetons.end())
-	    return NULL;
+	    return nullptr;
 	else
-	    if(*it == NULL)
+	    if(*it == nullptr)
 		throw SRC_BUG;
 	    else
 		return *it;
@@ -1063,7 +1077,7 @@ bool data_tree::fix_corruption()
 
 	while(it != rejetons.end() && ret)
 	{
-	    if(*it == NULL)
+	    if(*it == nullptr)
 		throw SRC_BUG;
 	    ret = (*it)->check_order(dialog, subpath, initial_warn);
 	    ++it;
@@ -1072,15 +1086,15 @@ bool data_tree::fix_corruption()
 	return ret;
     }
 
-    void data_dir::finalize(const archive_num & archive, const infinint & deleted_date, const archive_num & ignore_archives_greater_or_equal)
+    void data_dir::finalize(const archive_num & archive, const datetime & deleted_date, const archive_num & ignore_archives_greater_or_equal)
     {
-	infinint new_deleted_date;
+	datetime new_deleted_date;
 	archive_num tmp_archive;
 	etat tmp_presence;
 
 	data_tree::finalize(archive, deleted_date, ignore_archives_greater_or_equal);
 
-	switch(get_data(tmp_archive, 0, false))
+	switch(get_data(tmp_archive, datetime(0), false))
 	{
 	case found_present:
 	case found_removed:
@@ -1088,7 +1102,7 @@ bool data_tree::fix_corruption()
 	case not_found:
 	    if(fix_corruption())
 		throw Edata("This is to signal the caller of this method that this object has to be removed from database"); // exception caugth in data_dir::finalize_except_self
-		throw Erange("data_dir::finalize", gettext("This database has been corrupted probably due to a bug in release 2.4.0 to 2.4.9, and it has not been possible to cleanup this corruption, please rebuild the database from archives or extracted \"catalogues\", if the database has never been used by one of the previously mentioned released, you are welcome to open a bug report and provide as much as possible details about the circumstances"));
+	    throw Erange("data_dir::finalize", gettext("This database has been corrupted probably due to a bug in release 2.4.0 to 2.4.9, and it has not been possible to cleanup this corruption, please rebuild the database from archives or extracted \"catalogues\", if the database has never been used by one of the previously mentioned released, you are welcome to open a bug report and provide as much as possible details about the circumstances"));
 	case not_restorable:
 	    break;  // also an acceptable result;
 	default:
@@ -1101,13 +1115,13 @@ bool data_tree::fix_corruption()
 	finalize_except_self(archive, new_deleted_date, ignore_archives_greater_or_equal);
     }
 
-    void data_dir::finalize_except_self(const archive_num & archive, const infinint & deleted_date, const archive_num & ignore_archives_greater_or_equal)
+    void data_dir::finalize_except_self(const archive_num & archive, const datetime & deleted_date, const archive_num & ignore_archives_greater_or_equal)
     {
 	list<data_tree *>::iterator it = rejetons.begin();
 
 	while(it != rejetons.end())
 	{
-	    if(*it == NULL)
+	    if(*it == nullptr)
 		throw SRC_BUG;
 	    try
 	    {
@@ -1130,12 +1144,12 @@ bool data_tree::fix_corruption()
 
 	while(it != rejetons.end())
 	{
-	    if((*it) == NULL)
+	    if((*it) == nullptr)
 		throw SRC_BUG;
 	    if((*it)->remove_all_from(archive_to_remove, last_archive))
 	    {
 		delete *it; // release the memory used by the object
-		*it = NULL;
+		*it = nullptr;
 		rejetons.erase(it); // remove the entry from the list
 		it = rejetons.begin(); // does not seems "it" points to the next item after erase, so we restart from the beginning
 	    }
@@ -1153,15 +1167,16 @@ bool data_tree::fix_corruption()
 	bool data, ea;
 	string etat, name;
 	lookup lo_data, lo_ea;
+	bool even_when_removed = (num != 0);
 
 	while(it != rejetons.end())
 	{
-	    if(*it == NULL)
+	    if(*it == nullptr)
 		throw SRC_BUG;
 	    data_dir *dir = dynamic_cast<data_dir *>(*it);
 
-	    lo_data = (*it)->get_data(ou_data, 0, false);
-	    lo_ea = (*it)->get_EA(ou_ea, 0, false);
+	    lo_data = (*it)->get_data(ou_data, datetime(0), even_when_removed);
+	    lo_ea = (*it)->get_EA(ou_ea, datetime(0), even_when_removed);
 	    data = lo_data == found_present && (ou_data == num || num == 0);
 	    ea = lo_ea == found_present && (ou_ea == num || num == 0);
 	    name = (*it)->get_name();
@@ -1183,7 +1198,7 @@ bool data_tree::fix_corruption()
 		else
 		    dialog.printf("%S  %S%S\n", &etat, &marge, &name);
 	    }
-	    if(dir != NULL)
+	    if(dir != nullptr)
 		dir->show(dialog, num, marge+name+"/");
 	    ++it;
 	}
@@ -1229,7 +1244,7 @@ bool data_tree::fix_corruption()
 
     bool data_dir::fix_corruption()
     {
-	while(rejetons.begin() != rejetons.end() && *(rejetons.begin()) != NULL && (*(rejetons.begin()))->fix_corruption())
+	while(rejetons.begin() != rejetons.end() && *(rejetons.begin()) != nullptr && (*(rejetons.begin()))->fix_corruption())
 	{
 	    delete *(rejetons.begin());
 	    rejetons.erase(rejetons.begin());
@@ -1244,7 +1259,7 @@ bool data_tree::fix_corruption()
 
     void data_dir::add_child(data_tree *fils)
     {
-	if(fils == NULL)
+	if(fils == nullptr)
 	    throw SRC_BUG;
 	rejetons.push_back(fils);
     }
@@ -1253,12 +1268,12 @@ bool data_tree::fix_corruption()
     {
 	list<data_tree *>::iterator it = rejetons.begin();
 
-	while(it != rejetons.end() && *it != NULL && (*it)->get_name() != name)
+	while(it != rejetons.end() && *it != nullptr && (*it)->get_name() != name)
 	    ++it;
 
 	if(it != rejetons.end())
 	{
-	    if(*it == NULL)
+	    if(*it == nullptr)
 		throw SRC_BUG;
 	    else
 		rejetons.erase(it);
@@ -1268,12 +1283,12 @@ bool data_tree::fix_corruption()
 
 ////////////////////////////////////////////////////////////////
 
-    data_dir *data_tree_read(generic_file & f, unsigned char db_version)
+    data_dir *data_tree_read(generic_file & f, unsigned char db_version, memory_pool *pool)
     {
-	data_tree *lu = read_from_file(f, db_version);
+	data_tree *lu = read_from_file(f, db_version, pool);
 	data_dir *ret = dynamic_cast<data_dir *>(lu);
 
-	if(ret == NULL && lu != NULL)
+	if(ret == nullptr && lu != nullptr)
 	    delete lu;
 
 	return ret;
@@ -1296,60 +1311,60 @@ bool data_tree::fix_corruption()
 		loop = false;
 	    }
 	    ptr = current->read_child(filename);
-	    if(ptr == NULL)
+	    if(ptr == nullptr)
 		loop = false;
 	    if(loop)
 	    {
 		current = dynamic_cast<const data_dir *>(ptr);
-		if(current == NULL)
+		if(current == nullptr)
 		{
 		    loop = false;
-		    ptr = NULL;
+		    ptr = nullptr;
 		}
 	    }
 	}
 
-	return ptr != NULL;
+	return ptr != nullptr;
     }
 
-    void data_tree_update_with(const directory *dir, archive_num archive, data_dir *racine)
+    void data_tree_update_with(const cat_directory *dir, archive_num archive, data_dir *racine)
     {
-	const nomme *entry;
+	const cat_nomme *entry;
 
 	dir->reset_read_children();
 	while(dir->read_children(entry))
 	{
-	    const directory *entry_dir = dynamic_cast<const directory *>(entry);
-	    const inode *entry_ino = dynamic_cast<const inode *>(entry);
-	    const mirage *entry_mir = dynamic_cast<const mirage *>(entry);
-	    const detruit *entry_det = dynamic_cast<const detruit *>(entry);
+	    const cat_directory *entry_dir = dynamic_cast<const cat_directory *>(entry);
+	    const cat_inode *entry_ino = dynamic_cast<const cat_inode *>(entry);
+	    const cat_mirage *entry_mir = dynamic_cast<const cat_mirage *>(entry);
+	    const cat_detruit *entry_det = dynamic_cast<const cat_detruit *>(entry);
 
-	    if(entry_mir != NULL)
+	    if(entry_mir != nullptr)
 	    {
 		entry_ino = entry_mir->get_inode();
 		entry_mir->get_inode()->change_name(entry_mir->get_name());
 	    }
 
-	    if(entry_ino == NULL)
-		if(entry_det != NULL)
+	    if(entry_ino == nullptr)
+		if(entry_det != nullptr)
 		{
-		    if(entry_det->get_date() != 0)
+		    if(!entry_det->get_date().is_null())
 			racine->add(entry_det, archive);
-			// else this is an old archive that does not store date with detruit objects
+			// else this is an old archive that does not store date with cat_detruit objects
 		}
 		else
-		    continue; // continue with next loop, we ignore entree objects that are neither inode nor detruit
+		    continue; // continue with next loop, we ignore entree objects that are neither inode nor cat_detruit
 	    else
 		racine->add(entry_ino, archive);
 
-	    if(entry_dir != NULL) // going into recursion
+	    if(entry_dir != nullptr) // going into recursion
 	    {
 		data_tree *new_root = const_cast<data_tree *>(racine->read_child(entry->get_name()));
 		data_dir *new_root_dir = dynamic_cast<data_dir *>(new_root);
 
-		if(new_root == NULL)
+		if(new_root == nullptr)
 		    throw SRC_BUG; // the racine->add method did not add an item for "entry"
-		if(new_root_dir == NULL)
+		if(new_root_dir == nullptr)
 		    throw SRC_BUG; // the racine->add method did not add a data_dir item
 		data_tree_update_with(entry_dir, archive, new_root_dir);
 	    }
@@ -1384,22 +1399,22 @@ bool data_tree::fix_corruption()
 
 ////////////////////////////////////////////////////////////////
 
-static data_tree *read_from_file(generic_file & f, unsigned char db_version)
+static data_tree *read_from_file(generic_file & f, unsigned char db_version, memory_pool *pool)
 {
     char sign;
     data_tree *ret;
 
     if(f.read(&sign, 1) != 1)
-        return NULL; // nothing more to read
+        return nullptr; // nothing more to read
 
     if(sign == data_tree::signature())
-        ret = new (nothrow) data_tree(f, db_version);
+        ret = new (pool) data_tree(f, db_version);
     else if(sign == data_dir::signature())
-        ret = new (nothrow) data_dir(f, db_version);
+        ret = new (pool) data_dir(f, db_version);
     else
         throw Erange("read_from_file", gettext("Unknown record type"));
 
-    if(ret == NULL)
+    if(ret == nullptr)
         throw Ememory("read_from_file");
 
     return ret;
@@ -1425,9 +1440,9 @@ static void write_to_file(generic_file &f, archive_num a)
 
 static void display_line(user_interaction & dialog,
 			 archive_num num,
-			 const infinint *data,
+			 const datetime *data,
 			 data_tree::etat data_presence,
-			 const infinint *ea,
+			 const datetime *ea,
 			 data_tree::etat ea_presence)
 {
 
@@ -1477,7 +1492,7 @@ static void display_line(user_interaction & dialog,
 	throw SRC_BUG;
     }
 
-    if(data == NULL)
+    if(data == nullptr)
     {
 	data_state = ABSENT;
 	data_date = NO_DATE;
@@ -1485,7 +1500,7 @@ static void display_line(user_interaction & dialog,
     else
 	data_date = tools_display_date(*data);
 
-    if(ea == NULL)
+    if(ea == nullptr)
     {
 	ea_state = ABSENT;
 	ea_date = NO_DATE;
@@ -1498,4 +1513,3 @@ static void display_line(user_interaction & dialog,
     else
 	dialog.printf(" \t%u\t%S  %S  %S  %S\n", num, &data_date, &data_state, &ea_date, &ea_state);
 }
-
