@@ -35,7 +35,6 @@ extern "C"
 #include <iomanip>
 #include <iostream>
 #include <deque>
-#include <new>
 #include "database.hpp"
 #include "user_interaction.hpp"
 #include "deci.hpp"
@@ -46,7 +45,7 @@ extern "C"
 using namespace libdar;
 using namespace std;
 
-static storage *file2storage(generic_file &f);
+static storage *file2storage(generic_file &f, memory_pool *pool);
 static void memory2file(storage &s, generic_file &f);
 
 namespace libdar
@@ -62,24 +61,24 @@ namespace libdar
 	coordinate.push_back(dat); // coordinate[0] is never used, but must exist
 	options_to_dar.clear();
 	dar_path = "";
-	files = new (nothrow) data_dir("."); // "." or whaterver else (this name is not used)
-	if(files == NULL)
+	files = new (get_pool()) data_dir("."); // "." or whaterver else (this name is not used)
+	if(files == nullptr)
 	    throw Ememory("database::database");
-	data_files = NULL;
+	data_files = nullptr;
 	check_order_asked = true;
+	cur_db_version = database_header_get_supported_version();
     }
 
     database::database(user_interaction & dialog, const string & base, const database_open_options & opt)
     {
-	unsigned char db_version;
-	generic_file *f = database_header_open(dialog, base, db_version);
+	generic_file *f = database_header_open(dialog, get_pool(), base, cur_db_version);
 
-	if(f == NULL)
+	if(f == nullptr)
 	    throw Ememory("database::database");
 	try
 	{
 	    check_order_asked = opt.get_warn_order();
-	    build(dialog, *f, opt.get_partial(), opt.get_partial_read_only(), db_version);
+	    build(dialog, *f, opt.get_partial(), opt.get_partial_read_only(), cur_db_version);
 	}
 	catch(...)
 	{
@@ -100,14 +99,14 @@ namespace libdar
 		throw SRC_BUG; // we should not get there if the database is more recent than what that software can handle. this is necessary if we do not want to destroy the database or loose data.
 	    coordinate.clear();
 	    infinint tmp = infinint(f); // number of archive to read
-	    while(tmp > 0)
+	    while(!tmp.is_zero())
 	    {
 		tools_read_string(f, dat.chemin);
 		tools_read_string(f, dat.basename);
 		if(db_version >= 3)
-		    dat.root_last_mod.read(f);
+		    dat.root_last_mod.read(f, db2archive_version(db_version));
 		else
-		    dat.root_last_mod = 0;
+		    dat.root_last_mod = datetime(0);
 		coordinate.push_back(dat);
 		--tmp;
 	    }
@@ -120,24 +119,24 @@ namespace libdar
 
 	    if(!partial)
 	    {
-		files = data_tree_read(f, db_version);
-		if(files == NULL)
+		files = data_tree_read(f, db_version, get_pool());
+		if(files == nullptr)
 		    throw Ememory("database::database");
 		if(files->get_name() != ".")
 		    files->set_name(".");
-		data_files = NULL;
+		data_files = nullptr;
 	    }
 	    else
 	    {
 		if(!read_only)
 		{
-		    files = NULL;
-		    data_files = file2storage(f);
+		    files = nullptr;
+		    data_files = file2storage(f, get_pool());
 		}
 		else
 		{
-		    files = NULL;
-		    data_files = NULL;
+		    files = nullptr;
+		    data_files = nullptr;
 		}
 	    }
 	}
@@ -151,19 +150,19 @@ namespace libdar
 
     database::~database()
     {
-	if(files != NULL)
+	if(files != nullptr)
 	    delete files;
-	if(data_files != NULL)
+	if(data_files != nullptr)
 	    delete data_files;
     }
 
     void database::dump(user_interaction & dialog, const std::string & filename, const database_dump_options & opt) const
     {
-	if(files == NULL && data_files == NULL)
+	if(files == nullptr && data_files == nullptr)
 	    throw Erange("database::dump", gettext("Cannot write down a read-only database"));
 
-	generic_file *f = database_header_create(dialog, filename, opt.get_overwrite());
-	if(f == NULL)
+	generic_file *f = database_header_create(dialog, get_pool(), filename, opt.get_overwrite());
+	if(f == nullptr)
 	    throw Ememory("database::dump");
 
 	try
@@ -179,21 +178,21 @@ namespace libdar
 	    }
 	    tools_write_vector(*f, options_to_dar);
 	    tools_write_string(*f, dar_path);
-	    if(files != NULL)
+	    if(files != nullptr)
 		files->dump(*f);
 	    else
-		if(data_files != NULL)
+		if(data_files != nullptr)
 		    memory2file(*data_files, *f);
 		else
 		    throw SRC_BUG;
 	}
 	catch(...)
 	{
-	    if(f != NULL)
+	    if(f != nullptr)
 		delete f;
 	    throw;
 	}
-	if(f != NULL)
+	if(f != nullptr)
 	    delete f;
     }
 
@@ -205,7 +204,7 @@ namespace libdar
 	    struct archive_data dat;
 	    archive_num number = coordinate.size();
 
-	    if(files == NULL)
+	    if(files == nullptr)
 		throw SRC_BUG;
 	    if(basename == "")
 		throw Erange("database::add_archive", gettext("Empty string is an invalid archive basename"));
@@ -241,7 +240,7 @@ namespace libdar
 		throw Erange("database::remove_archive", gettext("Incorrect archive range in database"));
 	    for(U_I i = max ; i >= min ; --i)
 	    {
-		if(files == NULL)
+		if(files == nullptr)
 		    throw SRC_BUG;
 		files->remove_all_from(i, coordinate.size() - 1);
 		files->skip_out(i);
@@ -301,7 +300,7 @@ namespace libdar
 	{
 	    struct archive_data moved;
 
-	    if(files == NULL)
+	    if(files == nullptr)
 		throw SRC_BUG;
 	    if(src >= coordinate.size() || src <= 0)
 		throw Erange("database::set_permutation", string(gettext("Invalid archive number: ")) + tools_int2str(src));
@@ -360,9 +359,11 @@ namespace libdar
 
 	    if(!dialog.get_use_dar_manager_contents())
 	    {
-		dialog.printf(gettext("\ndar path    : %S\n"), &dar_path);
-		dialog.printf(gettext("dar options : %S\n\n"), &opt);
-
+		dialog.warning("\n");
+		dialog.printf(gettext("dar path        : %S\n"), &dar_path);
+		dialog.printf(gettext("dar options     : %S\n"), &opt);
+		dialog.printf(gettext("database version: %d\n"), cur_db_version);
+		dialog.warning("\n");
 		dialog.printf(gettext("archive #   |    path      |    basename\n"));
 		dialog.printf("------------+--------------+---------------\n");
 	    }
@@ -393,7 +394,7 @@ namespace libdar
 	{
 	    if(num != 0)
 		num = get_real_archive_num(num, opt.get_revert_archive_numbering());
-	    if(files == NULL)
+	    if(files == nullptr)
 		throw SRC_BUG;
 
 	    if(num < coordinate.size())
@@ -415,29 +416,29 @@ namespace libdar
 	NLS_SWAP_IN;
 	try
 	{
-	    const data_tree *ptr = NULL;
+	    const data_tree *ptr = nullptr;
 	    const data_dir *ptr_dir = files;
 	    string tmp;
 
-	    if(files == NULL)
+	    if(files == nullptr)
 		throw SRC_BUG;
 
 	    if(!chemin.is_relative())
 		throw Erange("database::show_version", gettext("Invalid path, path must be relative"));
 
-	    while(chemin.pop_front(tmp) && ptr_dir != NULL)
+	    while(chemin.pop_front(tmp) && ptr_dir != nullptr)
 	    {
 		ptr = ptr_dir->read_child(tmp);
-		if(ptr == NULL)
+		if(ptr == nullptr)
 		    throw Erange("database::show_version", gettext("Non existent file in database"));
 		ptr_dir = dynamic_cast<const data_dir *>(ptr);
 	    }
 
-	    if(ptr_dir == NULL)
+	    if(ptr_dir == nullptr)
 		throw Erange("database::show_version", gettext("Non existent file in database"));
 
 	    ptr = ptr_dir->read_child(chemin.display());
-	    if(ptr == NULL)
+	    if(ptr == nullptr)
 		throw Erange("database::show_version", gettext("Non existent file in database"));
 	    else
 		ptr->listing(dialog);
@@ -459,7 +460,7 @@ namespace libdar
 	    vector<infinint> stats_ea(coordinate.size(), 0);
 	    vector<infinint> total_data(coordinate.size(), 0);
 	    vector<infinint> total_ea(coordinate.size(), 0);
-	    if(files == NULL)
+	    if(files == nullptr)
 		throw SRC_BUG;
 	    files->compute_most_recent_stats(stats_data, stats_ea, total_data, total_ea);
 
@@ -495,14 +496,14 @@ namespace libdar
 	    const data_tree *ptr;
 
 	    anneau.assign(filename.begin(), filename.end());
-	    if(files == NULL)
+	    if(files == nullptr)
 		throw SRC_BUG;
 
 	    if(opt.get_info_details())
 		dialog.warning(gettext("Checking chronological ordering of files between the archives..."));
 	    check_order(dialog);
 
-		// determination of the archive to restore and files to restore for each selected archive
+		// determination of the archive to restore and files to restore for each selected file
 	    while(!anneau.empty())
 	    {
 		if(data_tree_find(anneau.front(), *files, ptr))
@@ -570,7 +571,7 @@ namespace libdar
 				command_line[num_data].push_back(anneau.front());
 			    }
 			    else // archive number is zero (not a valid archive number)
-				if(opt.get_date() != 0) // a date was specified
+				if(!opt.get_date().is_zero()) // a date was specified
 				{
 				    string fic = anneau.front();
 				    if(opt.get_info_details())
@@ -601,7 +602,7 @@ namespace libdar
 			}
 		    }
 
-		    if(ptr_dir != NULL)
+		    if(ptr_dir != nullptr)
 		    {  // adding current directory children in the list of files
 			vector<string> fils;
 			vector<string>::iterator fit;
@@ -625,10 +626,10 @@ namespace libdar
 
 	    if(opt.get_early_release())
 	    {
-		if(files != NULL)
+		if(files != nullptr)
 		{
 		    delete files;
-		    files = NULL;
+		    files = nullptr;
 		}
 	    }
 
@@ -668,7 +669,7 @@ namespace libdar
 			    dialog.printf("Arguments sent through anonymous pipe are:");
 			    dialog.warning(tools_concat_vector(" ", argvpipe));
 			}
-			tools_system_with_pipe(dialog, dar_cmd, argvpipe);
+			tools_system_with_pipe(dialog, dar_cmd, argvpipe, get_pool());
 		    }
 		    catch(Erange & e)
 		    {
@@ -708,7 +709,7 @@ namespace libdar
 	    return num;
     }
 
-    const infinint & database::get_root_last_mod(const archive_num & num) const
+    const datetime & database::get_root_last_mod(const archive_num & num) const
     {
 	if(num >= coordinate.size())
 	    throw SRC_BUG;
@@ -718,14 +719,14 @@ namespace libdar
 
 } // end of namespace
 
-static storage *file2storage(generic_file &f)
+static storage *file2storage(generic_file &f, memory_pool *pool)
 {
-    storage *st = new (nothrow) storage(0);
+    storage *st = new (pool) storage(0);
     const U_I taille = 102400;
     unsigned char buffer[taille];
     S_I lu;
 
-    if(st == NULL)
+    if(st == nullptr)
         throw Ememory("dar_manager:file2storage");
 
     do
