@@ -27,8 +27,9 @@
 #define DEFILE_HPP
 
 #include "../my_config.h"
-#include "catalogue.hpp"
 #include "path.hpp"
+#include "cat_entree.hpp"
+#include "on_pool.hpp"
 
 namespace libdar
 {
@@ -44,19 +45,15 @@ namespace libdar
 	/// this class is used to display the progression of the filtering routing,
 	/// and the file on which the filtering routine operates
 	/// \ingroup Private
-    class defile
+    class defile : public on_pool
     {
     public :
         defile(const path &racine) : chemin(racine) { init = true; };
 
-        void enfile(const entree *e);
+        void enfile(const cat_entree *e);
         const path & get_path() const { return chemin; };
         const std::string & get_string() const { return cache; };
 
-#ifdef LIBDAR_SPECIAL_ALLOC
-        USE_SPECIAL_ALLOC(defile);
-#endif
-
     private :
         path chemin; //< current path
         bool init;   //< true if reached the "root" (all pushed arguments have been poped)
