@@ -44,9 +44,10 @@ namespace libdar
 
 	/// \param[in] chemin is the path to the file to read attributes of
 	/// \param[in] filter is a mask that defines which attributes names have to be considered only
-	/// \return NULL if no EA have been found under the specified mask, or returns a newly allocated object
+	/// \param[in] p the memory pool to use for dynamic allocation of nullptr to not used any memory pool
+	/// \return nullptr if no EA have been found under the specified mask, or returns a newly allocated object
 	/// that the caller has the responsibility to delete when no more needed
-    extern ea_attributs * ea_filesystem_read_ea(const std::string & chemin, const mask & filter);
+    extern ea_attributs * ea_filesystem_read_ea(const std::string & chemin, const mask & filter, memory_pool *p);
 
 	/// overwrite some attribute to a given file's attribute list
 
@@ -62,22 +63,25 @@ namespace libdar
 
 	/// \param[in] name is the filename which EA must be altered
 	/// \param[in] filter is a mask that defines which EA names have to be removed
+	/// \param[in] p points to the memory pool to use or is to be set to nullptr for no pool utilisation
 	/// \note unless the given mask is logically equivalent to bool_mask(true) some
 	/// EA may remain associated to the file after the operation.
-    extern void ea_filesystem_clear_ea(const std::string & name, const mask & filter);
+    extern void ea_filesystem_clear_ea(const std::string & name, const mask & filter, memory_pool *p);
 
 	/// test the presence of EA for a given file
 
 	/// \param[in] name is the filename which EA presence must be check against
+	/// \param[in] p points to the memory pool to use or is to be set to nullptr for no pool utilisation
 	/// \return true if at least one EA has been found
-    extern bool ea_filesystem_has_ea(const std::string & name);
+    extern bool ea_filesystem_has_ea(const std::string & name, memory_pool *p);
 
 	/// test the presence of EA for a given file
 
 	/// \param[in] name is the filename which EA presence must be check against
 	/// \param[in] filter is a mask that defines which attributes names to only consider
+	/// \param[in] p points to the memory pool to use or is to be set to nullptr for no pool utilisation
 	/// \return true if at least one EA has been found
-    extern bool ea_filesystem_has_ea(const std::string & name, const mask & filter);
+    extern bool ea_filesystem_has_ea(const std::string & name, const mask & filter, memory_pool *p);
 
 	/// @}
 
