@@ -55,7 +55,7 @@ namespace libdar
 
     const char *dar_gettext(const char *arg)
     {
-	const char *ret = NULL;
+	const char *ret = nullptr;
 
 	NLS_SWAP_IN;
 	try
@@ -104,26 +104,34 @@ namespace libdar
 
     void Egeneric::dump() const
     {
+	cerr << dump_str();
+    }
+
+    string Egeneric::dump_str() const
+    {
+	string ret;
         list<niveau> & tmp = const_cast< list<niveau> & >(pile);
         list<niveau>::iterator it;
 
         it = tmp.begin();
 
-        cerr << "---- exception type = ["  << exceptionID() << "] ----------" << endl;
-        cerr << "[source]" << endl;
+        ret +=  "---- exception type = [" + exceptionID() + "] ----------\n";
+        ret +=  "[source]\n";
         while(it != tmp.end())
         {
-            cerr << '\t' << it->lieu << " : " << it->objet << endl;
+            ret += "\t" + it->lieu + " : " + it->objet + "\n";
             it++;
         }
-        cerr << "[most outside call]" << endl;
-        cerr << "-----------------------------------" << endl << endl;
+        ret += "[most outside call]\n";
+        ret += "-----------------------------------\n\n";
+
+	return ret;
     }
 
     Ebug::Ebug(const string & file, S_I line) : Egeneric(tools_printf(gettext("File %S line %d"), &file, line), gettext("it seems to be a bug here"))
     {
 	    // adding the current stack if possible
-#if HAVE_EXECINFO_H
+#if BACKTRACE_AVAILABLE
 	const int buf_size = 20;
 	void *buffer[buf_size];
 	int size = backtrace(buffer, buf_size);
@@ -136,14 +144,14 @@ namespace libdar
 	}
 	catch(...)
 	{
-	    if(symbols != NULL)
+	    if(symbols != nullptr)
 		free(symbols);
 	    throw;
 	}
-	if(symbols != NULL)
+	if(symbols != nullptr)
 	    free(symbols);
 #else
-	 Egeneric::stack("stack dump", "execinfo absent, cannot dump the stack information at the time the exception was thrown");
+	Egeneric::stack("stack dump", "backtrace() call absent, cannot dump the stack information at the time the exception was thrown");
 #endif
     }
 
@@ -152,6 +160,12 @@ namespace libdar
         Egeneric::stack(passage, tools_printf(gettext("in file %S line %S"), &file, &line));
     }
 
+    Esystem::Esystem(const string & source, const string & message, io_error code):
+	Egeneric(source, message)
+    {
+	x_code = code;
+    }
+
     static void init()
     {
         set_unexpected(inattendue);
