@@ -31,6 +31,7 @@
 #include <string>
 #include <list>
 #include "integers.hpp"
+#include "erreurs.hpp"
 
 namespace libdar
 {
@@ -80,7 +81,12 @@ namespace libdar
 	void prepend_message(const std::string & context);
 
 	    /// dump all information of the exception to the standard error
-        void dump() const;
+	    ///
+	    /// \note deprecated call, replaced by dump_str()
+	void dump() const;
+
+	    /// return a string result of the exception information dump
+	std::string dump_str() const;
 
     protected :
         virtual std::string exceptionID() const = 0;
@@ -304,6 +310,29 @@ namespace libdar
 	U_64 flag;
     };
 
+	/// exception used to carry system error
+
+    class Esystem : public Egeneric
+    {
+    public:
+	enum io_error
+	{
+	    io_exist,  //< file already exists (write mode)
+	    io_absent, //< file does not exist (read mode)
+	    io_access  //< permission denied (any mode)
+	};
+
+	Esystem(const std::string & source, const std::string & message, io_error code);
+
+	io_error get_code() const { return x_code; };
+
+    protected:
+	virtual std::string exceptionID() const { return "SYSTEM ERROR MET"; };
+
+    private:
+	io_error x_code;
+    };
+
 
 	/// @}
 
