@@ -23,6 +23,13 @@
 
 #include "escape.hpp"
 
+extern "C"
+{
+#ifdef HAVE_STRIN_H
+#include <string.h>
+#endif
+} // extern "C"
+
 using namespace std;
 
 extern "C"
@@ -42,7 +49,7 @@ extern "C"
 #  define strchr index
 #  define strrchr rindex
 # endif
-char *strchr (), *strrchr ();
+    char *strchr (), *strrchr ();
 # if !HAVE_MEMCPY
 #  define memcpy(d, s, n) bcopy ((s), (d), (n))
 #  define memmove(d, s, n) bcopy ((s), (d), (n))
@@ -65,6 +72,7 @@ namespace libdar
 	// avoid escaping of escape sequences when using two escape objects, one writing its data to a second one.
 
     const unsigned char escape::usual_fixed_sequence[ESCAPE_SEQUENCE_LENGTH] = { ESCAPE_FIXED_SEQUENCE_NORMAL, 0xFD, 0xEA, 0x77, 0x21, 0x00 };
+    const infinint escape::READ_BUFFER_SIZE_INFININT = MAX_BUFFER_SIZE;
 
 
 	//-- class routines
@@ -72,7 +80,7 @@ namespace libdar
     escape::escape(generic_file *below, const set<sequence_type> & x_unjumpable) : generic_file(below->get_mode())
     {
 	x_below = below;
-	if(below == NULL)
+	if(below == nullptr)
 	    throw SRC_BUG;
 	write_buffer_size = 0;
 	read_buffer_size = 0;
@@ -80,11 +88,11 @@ namespace libdar
 	already_read = 0;
 	escape_seq_offset_in_buffer = 0;
 	escaped_data_count_since_last_skip = 0;
+	below_position = x_below->get_position();
 	unjumpable = x_unjumpable;
-	if(get_mode() == gf_read_write)
-	    throw SRC_BUG; // escape implementation does not support this mode
 	for(U_I i = 0 ; i < ESCAPE_SEQUENCE_LENGTH; ++i)
 	    fixed_sequence[i] = usual_fixed_sequence[i];
+
     }
 
     escape::~escape()
@@ -132,6 +140,7 @@ namespace libdar
 	escaped_data_count_since_last_skip = 0;
 	set_fixed_sequence_for(t);
 	x_below->write((const char*)fixed_sequence, ESCAPE_SEQUENCE_LENGTH);
+	below_position += ESCAPE_SEQUENCE_LENGTH;
     }
 
     bool escape::skip_to_next_mark(sequence_type t, bool jump)
@@ -142,7 +151,7 @@ namespace libdar
 	    throw SRC_BUG;
 
 	    // check whether we are not in write mode !!!
-	if(get_mode() == gf_read_write)
+	if(get_mode() != gf_read_only)
 	    throw SRC_BUG; // escape implementation does not support this mode
 
 	read_eof = false; // may be have been set because we reached a mark while reading data, so we now need to unset it
@@ -161,7 +170,7 @@ namespace libdar
 		if(!mini_read_buffer())
 		{
 		    read_eof = true; // not enough data available, thus
-		    clean_data();
+		    clean_read();
 		}
 		else // we could get more data to determine whether we have a mark in the buffer or not
 		{
@@ -199,6 +208,7 @@ namespace libdar
 	    {
 		    // dropping all data in read_buffer, and filling it again with some new data
 		read_buffer_size = x_below->read(read_buffer, READ_BUFFER_SIZE);
+		below_position += read_buffer_size;
 		if(read_buffer_size == 0)
 		    read_eof = true;
 		already_read = 0;
@@ -241,7 +251,7 @@ namespace libdar
 
 	check_below();
 
-	if(x_below->get_mode() != gf_read_only)
+	if(get_mode() != gf_read_only)
 	    throw SRC_BUG;
 
 	if(escape_seq_offset_in_buffer > already_read) //no next to read mark
@@ -269,9 +279,27 @@ namespace libdar
 	    return false;
     }
 
+    bool escape::skippable(skippability direction, const infinint & amount)
+    {
+	switch(get_mode())
+	{
+	case gf_read_only:
+	    return x_below->skippable(direction, amount);
+	case gf_write_only:
+	case gf_read_write:
+	    if(direction == skip_forward)
+		return false;
+	    else
+		return x_below->skippable(direction, amount);
+	default:
+	    throw SRC_BUG;
+	}
+    }
 
     bool escape::skip(const infinint & pos)
     {
+	bool ret = true;
+
 	if(is_terminated())
 	    throw SRC_BUG;
 
@@ -281,25 +309,98 @@ namespace libdar
 	if(get_position() == pos)
 	    return true;
 
-	switch(x_below->get_mode())
+	switch(get_mode())
 	{
-	case gf_write_only:
-	    throw Efeature("Skipping not implemented in write mode for escape class");
-		// if the buffer is neither empty not full, we cannot know what to do with this date
-		// either place it asis in the below file, or escape it in the below file.
 	case gf_read_only:
+	    read_eof = false;
+	    flush_or_clean();
+	    ret = x_below->skip(pos);
+	    if(ret)
+		below_position = pos;
+	    else
+		below_position = x_below->get_position();
+	    break;
+	case gf_write_only:
+	    if(get_position() != pos)
+		throw Efeature("Skipping on write_only escape object");
+	    else
+		ret = true;
+	    break;
+	case gf_read_write:
+		// only backward skipping is allowed in that mode
+	    if(get_position() < pos)
+		throw Efeature("Skipping forward not implemented in write mode for escape class");
+	    else
+	    {
+		char tmp_buffer[WRITE_BUFFER_SIZE];
+		infinint cur_below = below_position;
+		U_I trouve;
+
+		try
+		{
+		    if(pos >= ESCAPE_SEQUENCE_LENGTH)
+		    {
+			U_I lu = 0;
+
+			below_position = pos - ESCAPE_SEQUENCE_LENGTH;
+			ret = x_below->skip(below_position);
+
+			if(ret)
+			{
+			    lu = x_below->read(tmp_buffer, ESCAPE_SEQUENCE_LENGTH);
+			    below_position += lu;
+			    write_buffer_size = lu;
+			}
+			else
+			    below_position = x_below->get_position();
+		    }
+		    else // skipping very close after the start of file, no escape mark can take place there
+		    {
+			U_I width = 0;
+			U_I lu = 0;
+			infinint tmp = pos;
+			tmp.unstack(width);
+			if(tmp != 0)
+			    throw SRC_BUG;
+			width = ESCAPE_SEQUENCE_LENGTH - width;
+			if(!x_below->skip(0))
+			    throw SRC_BUG;  // should succeed or throw an exception in that situation (backward skipping)
+			lu = x_below->read(tmp_buffer, width);
+			write_buffer_size = lu;
+			below_position = lu;
+			ret = true;
+		    }
+		}
+		catch(...)
+		{
+		    x_below->skip(cur_below);
+		    below_position = cur_below;
+		    throw;
+		}
+		(void)memcpy(write_buffer, tmp_buffer, write_buffer_size);
+		trouve = trouve_amorce(write_buffer, write_buffer_size, fixed_sequence);
+		if(trouve == 0) // we read a whole escape sequence
+		    write_buffer_size = 0; // so we know that we can restart the lookup process here from scratch
+		else if(trouve == write_buffer_size) // no start of escape sequence found
+		    write_buffer_size = 0; // so we know that we can restart the lookup process here from scratch
+		else // partial escape sequence found, moving at the beginning of the write_buffer for further lookup
+		{
+		    (void)memmove(write_buffer, write_buffer + trouve, write_buffer_size - trouve);
+		    write_buffer_size -= trouve;
+		}
+	    }
 	    break;
 	default:
 	    throw SRC_BUG; // this mode is not allowed
 	}
 
-	read_eof = false;
-	flush_or_clean();
-	return x_below->skip(pos);
+	return ret;
     }
 
     bool escape::skip_to_eof()
     {
+	bool ret;
+
 	if(is_terminated())
 	    throw SRC_BUG;
 
@@ -313,11 +414,16 @@ namespace libdar
 	read_eof = true;
 	escaped_data_count_since_last_skip = 0;
 
-	return x_below->skip_to_eof();
+	ret = x_below->skip_to_eof();
+	below_position = x_below->get_position();
+
+	return ret;
     }
 
     bool escape::skip_relative(S_I x)
     {
+	bool ret;
+
 	if(is_terminated())
 	    throw SRC_BUG;
 
@@ -332,21 +438,48 @@ namespace libdar
 	    // if the buffer is neither empty not full, we cannot know what to do with this date
 	    // either place it asis in the below file, or escape it in the below file.
 	flush_or_clean();
-	return x_below->skip_relative(x);
+	ret = x_below->skip_relative(x);
+	if(ret) // skipping succeeded
+	{
+	    if(x >= 0)
+		below_position += x;
+	    else  // x is negative
+	    {
+		if(below_position < -x)
+		    below_position = 0;
+		else
+		    below_position -= -x; // trick used, because infinint cannot be negative
+	    }
+	}
+	else // skipping failed, need to consult x_below to know where we are now
+	    below_position = x_below->get_position();
+
+	return ret;
     }
 
-    infinint escape::get_position()
+    infinint escape::get_position() const
     {
 	if(is_terminated())
 	    throw SRC_BUG;
 
 	check_below();
 	if(get_mode() == gf_read_only)
-	    return x_below->get_position() - read_buffer_size + already_read - escaped_data_count_since_last_skip;
+	    return below_position - read_buffer_size + already_read - escaped_data_count_since_last_skip;
 	else
-	    return x_below->get_position() + write_buffer_size - escaped_data_count_since_last_skip;
+	    return below_position + write_buffer_size - escaped_data_count_since_last_skip;
     }
 
+    void escape::inherited_read_ahead(const infinint & amount)
+    {
+	if(is_terminated())
+	    throw SRC_BUG;
+
+	check_below();
+	if(!read_eof)
+	    x_below->read_ahead(amount);
+    }
+
+
     U_I escape::inherited_read(char *a, U_I size)
     {
 	U_I returned = 0;
@@ -442,6 +575,7 @@ namespace libdar
 		    // filling missing data in "a" from x_below
 
 		read = x_below->read(a + returned, needed);
+		below_position += read;
 		if(read < needed)
 		    read_eof = true;
 
@@ -532,6 +666,7 @@ namespace libdar
 	    if(trouve == write_buffer_size) // no escape sequence found
 	    {
 		x_below->write(write_buffer, write_buffer_size);
+		below_position += write_buffer_size;
 		write_buffer_size = 0;
 	    }
 	    else // start of escape sequence found
@@ -539,8 +674,10 @@ namespace libdar
 		if(trouve + ESCAPE_SEQUENCE_LENGTH - 1 <= write_buffer_size) // no doubt, we have a full escape sequence in data, we need to protect this data
 		{
 		    x_below->write(write_buffer, trouve);
+		    below_position += trouve;
 		    set_fixed_sequence_for(seqt_not_a_sequence);
 		    x_below->write((const char *)fixed_sequence, ESCAPE_SEQUENCE_LENGTH);
+		    below_position += ESCAPE_SEQUENCE_LENGTH;
 			// still remains valid data not yet written in write_buffer at offset 'trouve + ESCAPE_SEQUENCE_LENGTH - 1'
 			// however this data is also in the input write_buffer (a, size)
 		    written = (trouve + ESCAPE_SEQUENCE_LENGTH - 1) - initial_buffer_size;
@@ -563,6 +700,7 @@ namespace libdar
 			// first, we can at least write down the data up to offset "trouve - 1" (that's "trouve" bytes).
 
 		    x_below->write(write_buffer, trouve);
+		    below_position += trouve;
 
 		    if(yet_in_a >= missing_for_sequence) // sequence entirely available with remaining data in "a"
 		    {
@@ -603,6 +741,7 @@ namespace libdar
 	    if(trouve == remains)
 	    {
 		x_below->write(a + written, remains);
+		below_position += remains;
 		written = size;
 	    }
 	    else
@@ -610,6 +749,7 @@ namespace libdar
 		if(trouve > 0)
 		{
 		    x_below->write(a + written, trouve);
+		    below_position += trouve;
 		    written += trouve;
 		}
 
@@ -617,6 +757,7 @@ namespace libdar
 		{
 		    set_fixed_sequence_for(seqt_not_a_sequence);
 		    x_below->write((const char *)fixed_sequence, ESCAPE_SEQUENCE_LENGTH);
+		    below_position += ESCAPE_SEQUENCE_LENGTH;
 		    written += ESCAPE_SEQUENCE_LENGTH - 1;
 		    ++escaped_data_count_since_last_skip;
 		}
@@ -657,6 +798,10 @@ namespace libdar
 	    return 'I';
 	case seqt_failed_backup:
 	    return '!';
+	case seqt_fsa:
+	    return 'S';
+	case seqt_fsa_crc:
+	    return 's';
 	default:
 	    throw SRC_BUG;
 	}
@@ -686,11 +831,22 @@ namespace libdar
 	    return seqt_dirty;
 	case '!':
 	    return seqt_failed_backup;
+	case 'S':
+	    return seqt_fsa;
+	case 's':
+	    return seqt_fsa_crc;
 	default:
 	    throw Erange("escape::char2type", gettext("Unknown escape sequence type"));
 	}
     }
 
+    void escape::clean_read()
+    {
+	read_buffer_size = already_read = escape_seq_offset_in_buffer = 0;
+	read_eof = false;
+	escaped_data_count_since_last_skip = 0;
+    }
+
     void escape::flush_write()
     {
 	check_below();
@@ -698,6 +854,7 @@ namespace libdar
 	if(write_buffer_size > 0)
 	{
 	    x_below->write(write_buffer, write_buffer_size);
+	    below_position += write_buffer_size;
 	    write_buffer_size = 0;
 	}
     }
@@ -716,6 +873,7 @@ namespace libdar
 	already_read = ref.already_read;
 	read_eof = ref.read_eof;
 	escaped_data_count_since_last_skip = ref.escaped_data_count_since_last_skip;
+	below_position = ref.below_position;
 	unjumpable = ref.unjumpable;
 	(void)memcpy(fixed_sequence, ref.fixed_sequence, ESCAPE_SEQUENCE_LENGTH);
     }
@@ -754,10 +912,13 @@ namespace libdar
 		U_I delta; // will receive the amount of byte to reduce the buffer (one byte for each data mark found)
 		U_I delta_size; // will holds the size of the data to unescape
 		U_I offset_in_buffer;
+		U_I short_read;
 
 		    // adding some data at the end of the buffer
 
-		read_buffer_size += x_below->read(read_buffer + read_buffer_size, ESCAPE_SEQUENCE_LENGTH - avail);
+		short_read = x_below->read(read_buffer + read_buffer_size, ESCAPE_SEQUENCE_LENGTH - avail);
+		read_buffer_size += short_read;
+		below_position += short_read;
 		avail = read_buffer_size - already_read;
 
 		    // we can continue unescaping the new data
