@@ -70,15 +70,13 @@ extern "C"
 #endif
 } // end extern "C"
 
-#include <new>
-
 #include "etage.hpp"
 #include "tools.hpp"
 #include "infinint.hpp"
 #include "generic_file.hpp"
 #include "cygwin_adapt.hpp"
 #include "user_interaction.hpp"
-#include "fichier.hpp"
+#include "fichier_local.hpp"
 
 #define CACHE_DIR_TAG_FILENAME "CACHEDIR.TAG"
 #define CACHE_DIR_TAG_FILENAME_CONTENTS "Signature: 8a477f597d28d172789f06886806bc55"
@@ -88,18 +86,18 @@ using namespace std;
 namespace libdar
 {
 	// check if the given file is a tag tellig if the current directory is a cache directory
-    static bool cache_directory_tagging_check(user_interaction & dialog, const char *cpath, const char *filename);
+    static bool cache_directory_tagging_check(const char *cpath, const char *filename);
 
 
     etage::etage(user_interaction &ui,
 		 const char *dirname,
-		 const infinint & x_last_acc,
-		 const infinint & x_last_mod,
+		 const datetime & x_last_acc,
+		 const datetime & x_last_mod,
 		 bool cache_directory_tagging,
 		 bool furtive_read_mode)
     {
         struct dirent *ret;
-	DIR *tmp = NULL;
+	DIR *tmp = nullptr;
 #if FURTIVE_READ_MODE_AVAILABLE
 	int fddir = -1;
 
@@ -111,9 +109,12 @@ namespace libdar
 	    {
 		if(errno != EPERM)
 		    throw Erange("etage::etage",
-				 string(gettext("Error opening directory in furtive read mode: ")) + dirname + " : " + strerror(errno));
+				 string(gettext("Error opening directory in furtive read mode: ")) + dirname + " : " + tools_strerror_r(errno));
 		else // using back normal access mode
-		    ui.warning(tools_printf(gettext("Could not open directory %s in furtive read mode (%s), using normal mode"), dirname, strerror(errno)));
+		{
+		    string tmp = tools_strerror_r(errno);
+		    ui.warning(tools_printf(gettext("Could not open directory %s in furtive read mode (%s), using normal mode"), dirname, tmp.c_str()));
+		}
 	    }
 	}
 #endif
@@ -123,9 +124,9 @@ namespace libdar
 	    if(furtive_read_mode && fddir >= 0)
 	    {
 		tmp = fdopendir(fddir);
-		if(tmp == NULL)
+		if(tmp == nullptr)
 		    close(fddir);
-		    // else, tmp != NULL:
+		    // else, tmp != nullptr:
 		    // fddir is now under control of the system
 		    // we must not close it.
 	    }
@@ -136,19 +137,43 @@ namespace libdar
 #endif
 	    bool is_cache_dir = false;
 
-	    if(tmp == NULL)
-		throw Erange("etage::etage" , string(gettext("Error opening directory: ")) + dirname + " : " + strerror(errno));
+	    if(tmp == nullptr)
+		throw Erange("etage::etage" , string(gettext("Error opening directory: ")) + dirname + " : " + tools_strerror_r(errno));
 
 	    fichier.clear();
-	    while(!is_cache_dir && (ret = readdir(tmp)) != NULL)
-		if(strcmp(ret->d_name, ".") != 0 && strcmp(ret->d_name, "..") != 0)
-		{
-		    if(cache_directory_tagging)
-			is_cache_dir = cache_directory_tagging_check(ui, dirname, ret->d_name);
-		    fichier.push_back(string(ret->d_name));
-		}
+
+#if HAVE_READDIR_R
+	    ret = tools_allocate_struct_dirent(dirname);
+	    struct dirent *dbldrt = nullptr;
+	    if(ret == nullptr)
+		throw SRC_BUG;
+	    try
+	    {
+		while(!is_cache_dir && (readdir_r(tmp, ret, &dbldrt) == 0) && dbldrt != nullptr)
+#else
+		while(!is_cache_dir && (ret = readdir(tmp)) != nullptr)
+#endif
+
+		    if(strcmp(ret->d_name, ".") != 0 && strcmp(ret->d_name, "..") != 0)
+		    {
+			if(cache_directory_tagging)
+			    is_cache_dir = cache_directory_tagging_check(dirname, ret->d_name);
+			fichier.push_back(string(ret->d_name));
+		    }
+
+#if HAVE_READDIR_R
+	    }
+	    catch(...)
+	    {
+		if(ret != nullptr)
+		    tools_release_struct_dirent(ret);
+		throw;
+	    }
+	    tools_release_struct_dirent(ret);
+	    ret = nullptr;
+#endif
 	    closedir(tmp);
-	    tmp = NULL;
+	    tmp = nullptr;
 
 	    if(is_cache_dir)
 	    {
@@ -162,7 +187,7 @@ namespace libdar
 	}
 	catch(...)
 	{
-	    if(tmp != NULL)
+	    if(tmp != nullptr)
 		closedir(tmp);
 	    throw;
 	}
@@ -185,7 +210,7 @@ namespace libdar
 	///////////////////////////////////////////
 
 
-    static bool cache_directory_tagging_check(user_interaction & dialog, const char *cpath, const char *filename)
+    static bool cache_directory_tagging_check(const char *cpath, const char *filename)
     {
 	bool ret = false;
 
@@ -193,28 +218,43 @@ namespace libdar
 	    ret = false;
 	else // we need to inspect the few first bytes of the file
 	{
-	    path chem = path(cpath)+string(filename);
-	    fichier fic = fichier(dialog, chem.display(), gf_read_only, tools_octal2int("0777"), false);
-	    U_I len = strlen(CACHE_DIR_TAG_FILENAME_CONTENTS);
-	    char *buffer = new (nothrow) char[len+1];
-	    S_I lu;
-
-	    if(buffer == NULL)
-		throw Ememory("etage:cache_directory_tagging_check");
 	    try
 	    {
-		lu = fic.read(buffer, len);
-		if(lu < 0 || (U_I)(lu) < len)
-		    ret = false;
-		else
-		    ret = strncmp(buffer, CACHE_DIR_TAG_FILENAME_CONTENTS, len) == 0;
+		path chem = path(cpath)+string(filename);
+		fichier_local fic = fichier_local(chem.display(), false);
+		U_I len = strlen(CACHE_DIR_TAG_FILENAME_CONTENTS);
+		char *buffer = new (nothrow) char[len+1];
+		S_I lu;
+
+		if(buffer == nullptr)
+		    throw Ememory("etage:cache_directory_tagging_check");
+		try
+		{
+		    lu = fic.read(buffer, len);
+		    if(lu < 0 || (U_I)(lu) < len)
+			ret = false;
+		    else
+			ret = strncmp(buffer, CACHE_DIR_TAG_FILENAME_CONTENTS, len) == 0;
+		}
+		catch(...)
+		{
+		    delete [] buffer;
+		    throw;
+		}
+		delete [] buffer;
+	    }
+	    catch(Ememory & e)
+	    {
+		throw;
+	    }
+	    catch(Ebug & e)
+	    {
+		throw;
 	    }
 	    catch(...)
 	    {
-		delete [] buffer;
-		throw;
+		ret = false;
 	    }
-	    delete [] buffer;
 	}
 
 	return ret;
