@@ -43,33 +43,42 @@ namespace libdar
 	/// @}
 
     extern void filtre_restore(user_interaction & dialog, //< for user interaction
+			       memory_pool *pool,         //< set to nullptr or point to the memory pool to use for memory allocation
 			       const mask &filtre,        //< which filename to restore
                                const mask & subtree,      //< which directory and paths to restore
-                               catalogue & cat,           //< table of content to extract information from
+                               const catalogue & cat,     //< table of content to extract information from
                                const path & fs_racine,    //< root path under which to restore directiry tree and files
                                bool fs_warn_overwrite,    //< whether to warn before overwriting (to be replaced by overwriting policy)
-                               bool info_details,         //< whether to be verbose
+                               bool info_details,         //< whether to display processing messages
+			       bool display_treated,      //< whether to display treated files
+			       bool display_treated_only_dir, //< whether to only display current directory of treated file
+			       bool display_skipped,      //< whether to display skipped files
                                statistics & st,           //< statistics result about the operation
                                const mask & ea_mask,      //< defines EA to restore/not restore
                                bool flat,                 //< if true, directories are not restores, all files are placed directly at in fs_racine directory
-			       inode::comparison_fields what_to_check, //< which file properties to restore
+			       cat_inode::comparison_fields what_to_check, //< which file properties to restore
 			       bool warn_remove_no_match, //< wether to warn for file to remove not matching the expected type
 			       bool empty,                //< dry-run execution
-			       bool display_skipped,      //< whether to display skipped files
 			       bool empty_dir,            //< whether to restore directories that do contain any file to restore
 			       const crit_action & x_overwrite, //< how and whether to overwrite files
  			       archive_options_extract::t_dirty dirty, //< whether to restore dirty files
 			       bool only_deleted,         //< whether to only consider deleted files
-			       bool not_deleted);         //< <wether to consider deleted files
+			       bool not_deleted,          //< wether to consider deleted files
+			       const fsa_scope & scope);  //< scope of FSA to take into account
 
     extern void filtre_sauvegarde(user_interaction & dialog,
+				  memory_pool *pool,
 				  const mask &filtre,
                                   const mask &subtree,
-                                  pile & stack,
+                                  const pile_descriptor & pdesc,
                                   catalogue & cat,
-                                  catalogue &ref,
+                                  const catalogue & ref,
                                   const path & fs_racine,
                                   bool info_details,
+				  bool display_treated,
+				  bool display_treated_only_dir,
+				  bool display_skipped,
+				  bool display_finished,
                                   statistics & st,
                                   bool make_empty_dir,
 				  const mask & ea_mask,
@@ -80,10 +89,9 @@ namespace libdar
 				  bool alter_time,
 				  bool furtive_read_mode,
 				  bool same_fs,
-				  inode::comparison_fields what_to_check,
+				  cat_inode::comparison_fields what_to_check,
 				  bool snapshot,
 				  bool cache_directory_tagging,
-				  bool display_skipped,
 				  bool security_check,
 				  const infinint & repeat_count,
 				  const infinint & repeat_byte,
@@ -91,59 +99,69 @@ namespace libdar
 				  const infinint & sparse_file_min_size,
 				  const std::string & backup_hook_file_execute,
 				  const mask & backup_hook_file_mask,
-				  bool ignore_unknown);
+				  bool ignore_unknown,
+				  const fsa_scope & scope,
+				  const std::string & exclude_by_ea);
 
     extern void filtre_difference(user_interaction & dialog,
+				  memory_pool *pool,
 				  const mask &filtre,
                                   const mask &subtree,
-                                  catalogue & cat,
+                                  const catalogue & cat,
                                   const path & fs_racine,
                                   bool info_details,
+				  bool display_treated,
+				  bool display_treated_only_dir,
+				  bool display_skipped,
 				  statistics & st,
 				  const mask & ea_mask,
 				  bool alter_time,
 				  bool furtive_read_mode,
-				  inode::comparison_fields what_to_check,
-				  bool display_skipped,
+				  cat_inode::comparison_fields what_to_check,
 				  const infinint & hourshift,
-				  bool compare_symlink_date);
+				  bool compare_symlink_date,
+				  const fsa_scope & scope,
+				  bool isolated_mode);
 
     extern void filtre_test(user_interaction & dialog,
+			    memory_pool *pool,
 			    const mask &filtre,
                             const mask &subtree,
-                            catalogue & cat,
+                            const catalogue & cat,
                             bool info_details,
+			    bool display_treated,
+			    bool display_treated_only_dir,
+			    bool display_skipped,
 			    bool empty,
-                            statistics & st,
-			    bool display_skipped);
-
-    extern void filtre_isolate(user_interaction & dialog,
-			       catalogue & cat,
-                               catalogue & ref,
-                               bool info_details);
+                            statistics & st);
 
     extern void filtre_merge(user_interaction & dialog,
+			     memory_pool *pool,
 			     const mask & filtre,
 			     const mask & subtree,
-			     pile & stack,
+			     const pile_descriptor & pdesc,
 			     catalogue & cat,
-			     catalogue * ref1,
-			     catalogue * ref2,
+			     const catalogue * ref1,
+			     const catalogue * ref2,
 			     bool info_details,
+			     bool display_treated,
+			     bool display_treated_only_dir,
+			     bool display_skipped,
 			     statistics & st,
 			     bool make_empty_dir,
 			     const mask & ea_mask,
 			     const mask & compr_mask,
 			     const infinint & min_compr_size,
-			     bool display_skipped,
 			     bool keep_compressed,
 			     const crit_action & overwrite,
 			     bool warn_overwrite,
 			     bool decremental_mode,
-			     const infinint & sparse_file_min_size);
+			     const infinint & sparse_file_min_size,
+			     const fsa_scope & scope);
 
     void filtre_sequentially_read_all_catalogue(catalogue & cat,
-						user_interaction & dialog);
+						user_interaction & dialog,
+						bool lax_read_mode);
 
 	/// @}
 
