@@ -49,12 +49,10 @@ extern "C"
 #endif
 } // end extern "C"
 
-#include <new>
-
 #include "header.hpp"
 #include "tlv_list.hpp"
 #include "tools.hpp"
-#include "fichier.hpp"
+#include "fichier_global.hpp"
 
 using namespace std;
 namespace libdar
@@ -87,8 +85,8 @@ namespace libdar
 	internal_name.clear();
 	data_name.clear();
         flag = '\0';
-	first_size = NULL;
-	slice_size = NULL;
+	first_size = nullptr;
+	slice_size = nullptr;
 	old_header = false;
     }
 
@@ -97,7 +95,7 @@ namespace libdar
         magic_number tmp;
 	tlv_list tempo;
 	char extension;
-	fichier *f_fic = dynamic_cast<fichier *>(&f);
+	fichier_global *f_fic = dynamic_cast<fichier_global *>(&f);
 
 	free_pointers();
 	old_header = false;
@@ -120,61 +118,61 @@ namespace libdar
         switch(extension)
         {
         case extension_none:
-	    if(f_fic != NULL)
+	    if(f_fic != nullptr)
 	    {
-		slice_size = new (nothrow) infinint(f_fic->get_size());
-		if(slice_size == NULL)
+		slice_size = new (get_pool()) infinint(f_fic->get_size());
+		if(slice_size == nullptr)
 		{
 		    if(!lax)
 			throw Ememory("header::read");
 		    else
 		    {
 			ui.warning(gettext("LAX MODE: slice size is not possible to read, (lack of virtual memory?), continuing anyway..."));
-			slice_size = new (nothrow) infinint(0);
-			if(slice_size == NULL)
+			slice_size = new (get_pool()) infinint(0);
+			if(slice_size == nullptr)
 			    throw Ememory("header::read");
 		    }
-		    // this extension was used in archives before release 2.4.0
-		    // when the first slice had the same size of the following ones
-		    // the slice size of all slices if thus the one of the first which
-		    // was learnt by getting the size of the file
-		    // this works also for single sliced archives.
+			// this extension was used in archives before release 2.4.0
+			// when the first slice had the same size of the following ones
+			// the slice size of all slices if thus the one of the first which
+			// was learnt by getting the size of the file
+			// this works also for single sliced archives.
 		}
 	    }
 	    old_header = true;
             break;
         case extension_size:
-	    slice_size = new (nothrow) infinint(f);
-	    if(slice_size == NULL)
+	    slice_size = new (get_pool()) infinint(f);
+	    if(slice_size == nullptr)
 	    {
 		if(!lax)
 		    throw Ememory("header::read");
 		else
 		{
 		    ui.warning(gettext("LAX MODE: slice size is not possible to read, (lack of virtual memory?), continuing anyway..."));
-		    slice_size = new (nothrow) infinint(0);
-		    if(slice_size == NULL)
+		    slice_size = new (get_pool()) infinint(0);
+		    if(slice_size == nullptr)
 			throw Ememory("header::read");
 		}
 	    }
-	    if(f_fic != NULL)
+	    if(f_fic != nullptr)
 	    {
-		first_size = new (nothrow) infinint(f_fic->get_size());
-		if(first_size == NULL)
+		first_size = new (get_pool()) infinint(f_fic->get_size());
+		if(first_size == nullptr)
 		{
 		    if(!lax)
 			throw Ememory("header::read");
 		    else
 		    {
 			ui.warning(gettext("LAX MODE: first slice size is not possible to read, (lack of virtual memory?), continuing anyway..."));
-			first_size = new (nothrow) infinint(0);
-			if(first_size == NULL)
+			first_size = new (get_pool()) infinint(0);
+			if(first_size == nullptr)
 			    throw Ememory("header::read");
 		    }
-		    // note: the "extension_size" extension was used in archives before release 2.4.0
-		    // this option was only used in the first slice and contained the size of slices (not of the first slice)
-		    // when the first slice had a different size. This way, reading the size of the current file gives
-		    // the size of the first slice while the header extension gives the size of following slices.
+			// note: the "extension_size" extension was used in archives before release 2.4.0
+			// this option was only used in the first slice and contained the size of slices (not of the first slice)
+			// when the first slice had a different size. This way, reading the size of the current file gives
+			// the size of the first slice while the header extension gives the size of following slices.
 		}
 	    }
 	    else
@@ -187,10 +185,10 @@ namespace libdar
 	case extension_tlv:
 	    tempo.read(f);        // read the list of TLV stored in the header
 	    fill_from(ui, tempo); // from the TLV list, set the different fields of the current header object
-	    if(slice_size == NULL && f_fic != NULL)
+	    if(slice_size == nullptr && f_fic != nullptr)
 	    {
-		slice_size = new (nothrow) infinint(f_fic->get_size());
-		if(slice_size == NULL)
+		slice_size = new (get_pool()) infinint(f_fic->get_size());
+		if(slice_size == nullptr)
 		    throw Ememory("header::read");
 	    }
 	    break;
@@ -200,8 +198,8 @@ namespace libdar
 	    else
 	    {
 		ui.warning(gettext("LAX MODE: Unknown data in slice header, ignoring and continuing"));
-		slice_size = new (nothrow) infinint(0);
-		if(slice_size == NULL)
+		slice_size = new (get_pool()) infinint(0);
+		if(slice_size == nullptr)
 		    throw Ememory("header::read");
 	    }
         }
@@ -220,7 +218,7 @@ namespace libdar
         f.write(&flag, 1);
 	if(old_header)
 	{
-	    if(first_size != NULL && slice_size != NULL && *first_size != *slice_size)
+	    if(first_size != nullptr && slice_size != nullptr && *first_size != *slice_size)
 	    {
 		tmp_ext[0] = extension_size;
 		f.write(tmp_ext, 1);
@@ -239,21 +237,9 @@ namespace libdar
 	}
     }
 
-    void header::read(user_interaction & dialog, S_I fd, bool lax)
-    {
-        fichier fic = fichier(dialog, dup(fd));
-        read(dialog, fic, lax);
-    }
-
-    void header::write(user_interaction & dialog, S_I fd) const
-    {
-        fichier fic = fichier(dialog, dup(fd));
-        write(dialog, fic);
-    }
-
     bool header::get_first_slice_size(infinint & size) const
     {
-	if(first_size != NULL)
+	if(first_size != nullptr)
 	{
 	    size = *first_size;
 	    return true;
@@ -264,10 +250,10 @@ namespace libdar
 
     void header::set_first_slice_size(const infinint & size)
     {
-	if(first_size == NULL)
+	if(first_size == nullptr)
 	{
-	    first_size = new (nothrow) infinint();
-	    if(first_size == NULL)
+	    first_size = new (get_pool()) infinint();
+	    if(first_size == nullptr)
 		throw Ememory("header::set_first_file_size");
 	}
 	*first_size = size;
@@ -275,7 +261,7 @@ namespace libdar
 
     bool header::get_slice_size(infinint & size) const
     {
-	if(slice_size != NULL)
+	if(slice_size != nullptr)
 	{
 	    size = *slice_size;
 	    return true;
@@ -286,10 +272,10 @@ namespace libdar
 
     void header::set_slice_size(const infinint & size)
     {
-	if(slice_size == NULL)
+	if(slice_size == nullptr)
 	{
-	    slice_size = new (nothrow) infinint();
-	    if(slice_size == NULL)
+	    slice_size = new (get_pool()) infinint();
+	    if(slice_size == nullptr)
 		throw Ememory("header::set_slice_size");
 	}
 
@@ -303,23 +289,23 @@ namespace libdar
         internal_name = ref.internal_name;
  	data_name = ref.data_name;
         flag = ref.flag;
-	first_size = NULL;
-	slice_size = NULL;
+	first_size = nullptr;
+	slice_size = nullptr;
 
 	try
 	{
-	    if(ref.first_size != NULL)
+	    if(ref.first_size != nullptr)
 	    {
-		first_size = new (nothrow) infinint();
-		if(first_size == NULL)
+		first_size = new (get_pool()) infinint();
+		if(first_size == nullptr)
 		    throw Ememory("header::copy_from");
 		*first_size = *ref.first_size;
 	    }
 
-	    if(ref.slice_size != NULL)
+	    if(ref.slice_size != nullptr)
 	    {
-		slice_size = new (nothrow) infinint();
-		if(slice_size == NULL)
+		slice_size = new (get_pool()) infinint();
+		if(slice_size == nullptr)
 		    throw Ememory("header::copy_from");
 		*slice_size = *ref.slice_size;
 	    }
@@ -335,46 +321,47 @@ namespace libdar
 
     void header::free_pointers()
     {
-	if(first_size != NULL)
+	if(first_size != nullptr)
 	{
 	    delete first_size;
-	    first_size = NULL;
+	    first_size = nullptr;
 	}
 
-	if(slice_size != NULL)
+	if(slice_size != nullptr)
 	{
 	    delete slice_size;
-	    slice_size = NULL;
+	    slice_size = nullptr;
 	}
     }
 
     void header::fill_from(user_interaction & ui, const tlv_list & extension)
     {
 	U_I taille = extension.size();
-	memory_file tmp = memory_file(gf_read_write);
 
 	free_pointers();
-	for(U_I index = 0; index < taille; index++)
+	for(U_I index = 0; index < taille; ++index)
 	{
-	    extension[index].get_contents(tmp);
 	    switch(extension[index].get_type())
 	    {
 	    case tlv_first_size:
-		first_size = new (nothrow) infinint();
-		if(first_size == NULL)
+		first_size = new (get_pool()) infinint();
+		if(first_size == nullptr)
 		    throw Ememory("header::fill_from");
-		first_size->read(tmp);
+		extension[index].skip(0);
+		first_size->read(extension[index]);
 		break;
 	    case tlv_size:
-		slice_size = new (nothrow) infinint();
-		if(slice_size == NULL)
+		slice_size = new (get_pool()) infinint();
+		if(slice_size == nullptr)
 		    throw Ememory("header::fill_from");
-		slice_size->read(tmp);
+		extension[index].skip(0);
+		slice_size->read(extension[index]);
 		break;
 	    case tlv_data_name:
 		try
 		{
-		    data_name.read(tmp);
+		    extension[index].skip(0);
+		    data_name.read(extension[index]);
 		}
 		catch(Erange & e)
 		{
@@ -391,30 +378,26 @@ namespace libdar
     {
 	tlv_list ret;
 	tlv tmp;
-	memory_file pseudo_fic = memory_file(gf_read_write);
 
-	if(first_size != NULL)
+	if(first_size != nullptr)
 	{
-	    pseudo_fic.reset();
-	    first_size->dump(pseudo_fic);
+	    tmp.reset();
+	    first_size->dump(tmp);
 	    tmp.set_type(tlv_first_size);
-	    tmp.set_contents(pseudo_fic);
 	    ret.add(tmp);
 	}
 
-	if(slice_size != NULL)
+	if(slice_size != nullptr)
 	{
-	    pseudo_fic.reset();
-	    slice_size->dump(pseudo_fic);
+	    tmp.reset();
+	    slice_size->dump(tmp);
 	    tmp.set_type(tlv_size);
-	    tmp.set_contents(pseudo_fic);
 	    ret.add(tmp);
 	}
 
-	pseudo_fic.reset();
-	data_name.dump(pseudo_fic);
+	tmp.reset();
+	data_name.dump(tmp);
 	tmp.set_type(tlv_data_name);
-	tmp.set_contents(pseudo_fic);
 	ret.add(tmp);
 
 	return ret;
