@@ -34,6 +34,7 @@
 #include "user_interaction.hpp"
 #include "tlv_list.hpp"
 #include "label.hpp"
+#include "on_pool.hpp"
 
 #include <vector>
 
@@ -59,14 +60,12 @@ namespace libdar
 
 	/// this class was a struct before release 2.4.0, now promoted
 	/// to a class it hides the fields and uses TLV to store the
-	/// fields in the archive. A new fields are easily identified
-	/// by old implementations, and optional known fields can be
-	/// recognized after those. This makes the header easier to
+	/// fields in the archive. This makes the header easier to
 	/// extend by adding new fields, while letting a chance for the
-	/// old implementation to use more recent archives
+	/// old implementation to be able to use more recent archives
 	/// the main use of TLV is to handle optional fields easily.
 
-    class header
+    class header : public on_pool
     {
     public:
 	    // constructors & Co.
@@ -80,8 +79,6 @@ namespace libdar
 
         void read(user_interaction & ui, generic_file & f, bool lax = false );
         void write(user_interaction &, generic_file & f) const;
-        void read(user_interaction & dialog, S_I fd, bool lax = false);
-        void write(user_interaction & dialog, S_I fd) const;
 
 	    /// minimal size of a header in an archive
 
@@ -104,11 +101,11 @@ namespace libdar
 
 	bool get_first_slice_size(infinint & size) const;
 	void set_first_slice_size(const infinint & size);
-	void unset_first_slice_size() { if(first_size != NULL) { delete first_size; first_size = NULL; } };
+	void unset_first_slice_size() { if(first_size != nullptr) { delete first_size; first_size = nullptr; } };
 
 	bool get_slice_size(infinint & size) const;
 	void set_slice_size(const infinint & size);
-	void unset_slice_size() { if(slice_size != NULL) { delete slice_size; slice_size = NULL; } };
+	void unset_slice_size() { if(slice_size != nullptr) { delete slice_size; slice_size = nullptr; } };
 
 	bool is_old_header() const { return old_header; };
 	void set_format_07_compatibility() { old_header = true; };
