@@ -52,11 +52,14 @@ extern "C"
 #include <time.h>
 #endif
 
+#if HAVE_GPGME_H
+#include <gpgme.h>
+#endif
+
 } // end extern "C"
 
 #include <string>
 #include <iostream>
-#include <new>
 #include "libdar.hpp"
 #include "erreurs.hpp"
 #include "infinint.hpp"
@@ -73,89 +76,89 @@ extern "C"
 using namespace std;
 
 #define WRAPPER_IN try {  //
-#define WRAPPER_OUT(code,msg)                      \
-                       code = LIBDAR_NOEXCEPT;     \
-                    }                              \
-                    catch(Ememory & e)             \
-                    {                              \
-			code = LIBDAR_EMEMORY;     \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Ebug & e)                \
-                    {                              \
-			code = LIBDAR_EBUG;        \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Einfinint & e)           \
-                    {                              \
-			code = LIBDAR_EINFININT;   \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Elimitint & e)           \
-                    {                              \
-			code = LIBDAR_ELIMITINT;   \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Erange & e)              \
-                    {                              \
-			code = LIBDAR_ERANGE;      \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Edeci & e)               \
-                    {                              \
-			code = LIBDAR_EDECI;       \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Efeature & e)            \
-                    {                              \
-			code = LIBDAR_EFEATURE;    \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Ehardware & e)           \
-                    {                              \
-			code = LIBDAR_EHARDWARE;   \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Euser_abort & e)         \
-                    {                              \
-			code = LIBDAR_EUSER_ABORT; \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Edata & e)               \
-                    {                              \
-			code = LIBDAR_EDATA;       \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Escript & e)             \
-                    {                              \
-			code = LIBDAR_ESCRIPT;     \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Elibcall & e)            \
-                    {                              \
-			code = LIBDAR_ELIBCALL;    \
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Ecompilation & e)        \
-                    {                              \
-                        code = LIBDAR_ECOMPILATION;\
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Ethread_cancel & e)      \
-                    {                              \
-                        code = LIBDAR_THREAD_CANCEL;\
-                        msg = e.get_message();     \
-                    }                              \
-                    catch(Egeneric & e)            \
-                    {/*unknown Egeneric exception*/\
-			code = LIBDAR_EBUG;        \
-                        msg = string(gettext("Caught an unknown Egeneric exception: ")) + e.get_message();  \
-                    }                              \
-                    catch(...)                     \
-                    {/* unknown Egeneric exception*/\
-			code = LIBDAR_UNKNOWN;     \
-                        msg = gettext("Caught a none libdar exception");  \
-                    }                              //
+#define WRAPPER_OUT(code,msg)						\
+    code = LIBDAR_NOEXCEPT;						\
+    }									\
+				    catch(Ememory & e)			\
+				    {					\
+					code = LIBDAR_EMEMORY;		\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Ebug & e)			\
+				    {					\
+					code = LIBDAR_EBUG;		\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Einfinint & e)		\
+				    {					\
+					code = LIBDAR_EINFININT;	\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Elimitint & e)		\
+				    {					\
+					code = LIBDAR_ELIMITINT;	\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Erange & e)			\
+				    {					\
+					code = LIBDAR_ERANGE;		\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Edeci & e)			\
+				    {					\
+					code = LIBDAR_EDECI;		\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Efeature & e)			\
+				    {					\
+					code = LIBDAR_EFEATURE;		\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Ehardware & e)		\
+				    {					\
+					code = LIBDAR_EHARDWARE;	\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Euser_abort & e)		\
+				    {					\
+					code = LIBDAR_EUSER_ABORT;	\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Edata & e)			\
+				    {					\
+					code = LIBDAR_EDATA;		\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Escript & e)			\
+				    {					\
+					code = LIBDAR_ESCRIPT;		\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Elibcall & e)			\
+				    {					\
+					code = LIBDAR_ELIBCALL;		\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Ecompilation & e)		\
+				    {					\
+					code = LIBDAR_ECOMPILATION;	\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Ethread_cancel & e)		\
+				    {					\
+					code = LIBDAR_THREAD_CANCEL;	\
+					msg = e.get_message();		\
+				    }					\
+				    catch(Egeneric & e)			\
+				    {/*unknown Egeneric exception*/	\
+					code = LIBDAR_EBUG;		\
+					msg = string(gettext("Caught an unknown Egeneric exception: ")) + e.get_message(); \
+				    }					\
+				    catch(...)				\
+				    {/* unknown Egeneric exception*/	\
+					code = LIBDAR_UNKNOWN;		\
+					msg = gettext("Caught a none libdar exception"); \
+				    }                              //
 
 
 namespace libdar
@@ -183,7 +186,7 @@ namespace libdar
 	WRAPPER_IN
 	    get_version(major, minor, init_libgcrypt);
 	WRAPPER_OUT(exception, except_msg)
-        NLS_SWAP_OUT;
+	    NLS_SWAP_OUT;
     }
 
     void get_version(U_I & major, U_I & medium, U_I & minor, bool init_libgcrypt)
@@ -203,7 +206,7 @@ namespace libdar
 	WRAPPER_IN
 	    get_version(major, medium, minor, init_libgcrypt);
 	WRAPPER_OUT(exception, except_msg)
-        NLS_SWAP_OUT;
+	    NLS_SWAP_OUT;
     }
 
     archive* open_archive_noexcept(user_interaction & dialog,
@@ -214,13 +217,15 @@ namespace libdar
 				   U_16 & exception,
 				   std::string & except_msg)
     {
-	archive *ret = NULL;
+	archive *ret = nullptr;
         NLS_SWAP_IN;
 	WRAPPER_IN
 	    ret = new (nothrow) archive(dialog, chem,  basename,  extension,
 					options);
+  	    if(ret == nullptr)
+		throw Ememory("open_archive_noexcept");
 	WRAPPER_OUT(exception, except_msg)
-        NLS_SWAP_OUT;
+	NLS_SWAP_OUT;
 	return ret;
     }
 
@@ -234,7 +239,7 @@ namespace libdar
 				     U_16 & exception,
 				     std::string & except_msg)
     {
-	archive *arch_ret = NULL;
+	archive *arch_ret = nullptr;
 	NLS_SWAP_IN;
 	WRAPPER_IN
 	    arch_ret = new (nothrow) archive(dialog,
@@ -244,33 +249,34 @@ namespace libdar
 					     extension,
 					     options,
 					     progressive_report);
+  	    if(arch_ret == nullptr)
+		throw Ememory("open_archive_noexcept");
 	WRAPPER_OUT(exception, except_msg)
         NLS_SWAP_OUT;
 	return arch_ret;
     }
 
 
-    archive *isolate_archive_noexcept(user_interaction & dialog,
-				      const path &sauv_path,
-				      archive *ref_arch,
-				      const std::string & filename,
-				      const std::string & extension,
-				      const archive_options_isolate & options,
-				      U_16 & exception,
-				      std::string & except_msg)
+    void op_isolate_noexcept(user_interaction & dialog,
+			     archive *ptr,
+			     const path &sauv_path,
+			     const std::string & filename,
+			     const std::string & extension,
+			     const archive_options_isolate & options,
+			     U_16 & exception,
+			     std::string & except_msg)
     {
-	archive *ret = NULL;
 	NLS_SWAP_IN;
 	WRAPPER_IN
-	    ret = new (nothrow) archive(dialog,
-					sauv_path,
-					ref_arch,
-					filename,
-					extension,
-					options);
+	    if(ptr == nullptr)
+		throw Elibcall("op_isolate_noexcept", gettext("Invald nullptr argument given to 'ptr'"));
+	ptr->op_isolate(dialog,
+			sauv_path,
+			filename,
+			extension,
+			options);
 	WRAPPER_OUT(exception, except_msg)
-        NLS_SWAP_OUT;
-	return ret;
+	    NLS_SWAP_OUT;
     }
 
     archive *merge_archive_noexcept(user_interaction & dialog,
@@ -283,7 +289,7 @@ namespace libdar
 				    U_16 & exception,
 				    std::string & except_msg)
     {
-	archive *ret = NULL;
+	archive *ret = nullptr;
 	NLS_SWAP_IN;
 	WRAPPER_IN
 	    ret = new (nothrow) archive(dialog,
@@ -293,8 +299,10 @@ namespace libdar
 					extension,
 					options,
 					progressive_report);
+  	    if(ret == nullptr)
+		throw Ememory("open_archive_noexcept");
 	WRAPPER_OUT(exception, except_msg)
-	NLS_SWAP_OUT;
+	    NLS_SWAP_OUT;
 	return ret;
     }
 
@@ -307,25 +315,25 @@ namespace libdar
     {
 	NLS_SWAP_IN;
 	WRAPPER_IN
-	    if(ptr == NULL)
-		throw Elibcall("close_archive_noexcept", gettext("Invalid NULL pointer given to close_archive"));
+	    if(ptr == nullptr)
+		throw Elibcall("close_archive_noexcept", gettext("Invalid nullptr pointer given to close_archive"));
 	    else
 	    {
 		delete ptr;
-		ptr = NULL;
+		ptr = nullptr;
 	    }
 	WRAPPER_OUT(exception, except_msg)
-        NLS_SWAP_OUT;
+	    NLS_SWAP_OUT;
     }
 
     char *libdar_str2charptr_noexcept(const std::string & x, U_16 & exception, std::string & except_msg)
     {
-        char *ret = NULL;
+        char *ret = nullptr;
         NLS_SWAP_IN;
         WRAPPER_IN
 	    ret = tools_str2charptr(x);
 	WRAPPER_OUT(exception, except_msg)
-	NLS_SWAP_OUT;
+	    NLS_SWAP_OUT;
 	return ret;
     }
 
@@ -336,28 +344,12 @@ namespace libdar
 		// locale for gettext
 
 	    if(string(DAR_LOCALEDIR) != string(""))
-		if(bindtextdomain(PACKAGE, DAR_LOCALEDIR) == NULL)
+		if(bindtextdomain(PACKAGE, DAR_LOCALEDIR) == nullptr)
 		    throw Erange("", "Cannot open the translated messages directory, native language support will not work");
 
 		// pseudo random generator
 
-	    srand(time(NULL)+getpid()+getppid());
-
-
-		// initializing mutex
-
-#ifdef MUTEX_WORKS
-#ifdef LIBDAR_SPECIAL_ALLOC
-	    special_alloc_init_for_thread_safe();
-#endif
-	    thread_cancellation::init();
-#endif
-
-		// building the (later read only) database of user/UID and group/GID of the system
-
-#ifdef __DYNAMIC__
-	    user_group_bases::class_init();
-#endif
+	    srand(::time(nullptr)+getpid()+getppid());
 
 		// initializing LIBLZO2
 
@@ -405,21 +397,31 @@ namespace libdar
 		    throw Erange("libdar_init_libgcrypt", tools_printf(gettext("Too old version for libgcrypt, minimum required version is %s\n"), MIN_VERSION_GCRYPT));
 #endif
 
+#if GPGME_SUPPORT
+	    if(gpgme_check_version(GPGME_MIN_VERSION) == nullptr)
+	    {
+		string tmp = "GPGME_SUPPORT";
+		throw Erange("libdar_init_gpgme", tools_printf(gettext("GPGME version requirement is not satisfied, requires version > %s"), tmp.c_str()));
+	    }
+
+	    if(gpgme_err_code(gpgme_engine_check_version(GPGME_PROTOCOL_OpenPGP)) != GPG_ERR_NO_ERROR)
+		throw Erange("libdar_init_gpgme", tools_printf(gettext("GPGME engine not available: %s"), gpgme_get_protocol_name(GPGME_PROTOCOL_OpenPGP)));
+#endif
 	    tools_init();
 
-		 // so now libdar is ready for use!
+		// so now libdar is ready for use!
 
-	     libdar_initialized = true;
-	 }
-     }
+	    libdar_initialized = true;
+	}
+    }
 
-     extern void close_and_clean()
-     {
+    extern void close_and_clean()
+    {
 #ifdef CRYPTO_AVAILABLE
-	 if(libdar_initialized_gcrypt)
-	     gcry_control(GCRYCTL_TERM_SECMEM, 0); // by precaution if not already done by libgcrypt itself
+	if(libdar_initialized_gcrypt)
+	    gcry_control(GCRYCTL_TERM_SECMEM, 0); // by precaution if not already done by libgcrypt itself
 #endif
-	 tools_end();
+	tools_end();
     }
 
 
@@ -435,14 +437,14 @@ namespace libdar
 	statistics ret;
 	NLS_SWAP_IN;
 	WRAPPER_IN
-	    if(ptr == NULL)
-		throw Elibcall("op_extract_noexcept", gettext("Invalid NULL argument given to 'ptr'"));
+	    if(ptr == nullptr)
+		throw Elibcall("op_extract_noexcept", gettext("Invalid nullptr argument given to 'ptr'"));
 	ret = ptr->op_extract(dialog,
 			      fs_root,
 			      options,
 			      progressive_report);
 	WRAPPER_OUT(exception, except_msg)
-	NLS_SWAP_OUT;
+	    NLS_SWAP_OUT;
 	return ret;
     }
 
@@ -455,12 +457,12 @@ namespace libdar
     {
 	NLS_SWAP_IN;
 	WRAPPER_IN
-	    if(ptr == NULL)
-		throw Elibcall("op_extract_noexcept", gettext("Invalid NULL argument given to 'ptr'"));
+	    if(ptr == nullptr)
+		throw Elibcall("op_extract_noexcept", gettext("Invalid nullptr argument given to 'ptr'"));
 	ptr->op_listing(dialog,
 			options);
 	WRAPPER_OUT(exception, except_msg)
-        NLS_SWAP_OUT;
+	    NLS_SWAP_OUT;
     }
 
     statistics op_diff_noexcept(user_interaction & dialog,
@@ -474,14 +476,14 @@ namespace libdar
 	statistics ret;
 	NLS_SWAP_IN;
 	WRAPPER_IN
-	    if(ptr == NULL)
-		throw Elibcall("op_extract_noexcept", gettext("Invalid NULL argument given to 'ptr'"));
+	    if(ptr == nullptr)
+		throw Elibcall("op_extract_noexcept", gettext("Invalid nullptr argument given to 'ptr'"));
 	ret = ptr->op_diff(dialog,
 			   fs_root,
 			   options,
 			   progressive_report);
 	WRAPPER_OUT(exception, except_msg)
-        NLS_SWAP_OUT;
+	    NLS_SWAP_OUT;
 	return ret;
     }
 
@@ -496,13 +498,13 @@ namespace libdar
 	statistics ret;
 	NLS_SWAP_IN;
 	WRAPPER_IN
-	    if(ptr == NULL)
-		throw Elibcall("op_extract_noexcept", gettext("Invalid NULL argument given to 'ptr'"));
+	    if(ptr == nullptr)
+		throw Elibcall("op_extract_noexcept", gettext("Invalid nullptr argument given to 'ptr'"));
 	ret = ptr->op_test(dialog,
 			   options,
 			   progressive_report);
 	WRAPPER_OUT(exception, except_msg)
-	NLS_SWAP_OUT;
+	    NLS_SWAP_OUT;
 	return ret;
     }
 
@@ -516,12 +518,12 @@ namespace libdar
 	bool ret = false;
 	NLS_SWAP_IN;
 	WRAPPER_IN
-	    if(ptr == NULL)
-		throw Elibcall("op_extract_noexcept", gettext("Invalid NULL argument given to 'ptr'"));
+	    if(ptr == nullptr)
+		throw Elibcall("op_extract_noexcept", gettext("Invalid nullptr argument given to 'ptr'"));
 	ret = ptr->get_children_of(dialog,
 				   dir);
 	WRAPPER_OUT(exception, except_msg)
-	NLS_SWAP_OUT;
+	    NLS_SWAP_OUT;
 	return ret;
     }
 
