@@ -24,12 +24,11 @@
     /// \mainpage
     /// You will find here the reference documentation for the dar and libdar source code, split in several "modules".
     /// - API module: contains all information for using libdar within your program
-    /// - OLD_API_4_4 module: contains the backward compatible API to version 4.4.x
     /// - Tools module: contains some routines you may like to have a look at (but using them with caution)
     /// - Private module: contains all libdar internal documentation, it is not necessary to read it to be able to use libdar
     /// - CMDLINE module: contains the documentation for command-line tools, you might want to have a look for illustration of library usage.
     /// .
-    /// CMDLINE module is out of any namespace as it is not inteded to be used by external application, OLD_API_4_4 module is in the libdar_4_4 namespace. All other modules, are in the libdar namespace.
+    /// CMDLINE module is out of any namespace as it is not inteded to be used by external application. All other symbols are part of the libdar namespace.
     ///
     /// Please not that an API tutorial is also available for a higher view of this library.
 
@@ -37,7 +36,7 @@
     /// \defgroup API API
     /// \brief APlication Interface
     ///
-    /// This gather all symbols that may be accessed from an external
+    /// This gathers all symbols that may be accessed from an external
     /// program. Other symbols are not as much documented, and
     /// may change or be removed without any warning or backward
     /// compatibility support. So only use the function, macro, types,
@@ -87,6 +86,7 @@ extern "C"
 #include "crypto.hpp"
 #include "thread_cancellation.hpp"
 #include "compile_time_features.hpp"
+#include "capabilities.hpp"
 
     /// \addtogroup API
     /// @{
@@ -131,16 +131,16 @@ extern "C"
     /// libdar namespace encapsulate all libdar symbols
 namespace libdar
 {
-    /// \addtogroup API
-    /// @{
+	/// \addtogroup API
+	/// @{
 
 
 	///  libdar Major version defined at compilation time
     const U_I LIBDAR_COMPILE_TIME_MAJOR = 5;
 	///  libdar Medium version defined at compilation time
-    const U_I LIBDAR_COMPILE_TIME_MEDIUM = 6;
+    const U_I LIBDAR_COMPILE_TIME_MEDIUM = 7;
 	///  libdar Minor version defined at compilation time
-    const U_I LIBDAR_COMPILE_TIME_MINOR = 4;
+    const U_I LIBDAR_COMPILE_TIME_MINOR = 3;
 
 	////////////////////////////////////////////////////////////////////////
 	// LIBDAR INITIALIZATION METHODS                                      //
@@ -245,8 +245,8 @@ namespace libdar
 	/// for an explaination of the two extra arguments exception and except_msg check
 	/// the get_version_noexcept function
     extern archive *isolate_archive_noexcept(user_interaction & dialog,
+					     archive *ptr,
 					     const path &sauv_path,
-					     archive *ref_arch,
 					     const std::string & filename,
 					     const std::string & extension,
 					     const archive_options_isolate & options,
@@ -360,7 +360,7 @@ namespace libdar
         /// \return the address of a newly allocated memory
         /// which must be released calling the "delete []"
         /// operator when no more needed.
-        /// \return NULL in case of error
+        /// \return nullptr in case of error
     extern char *libdar_str2charptr_noexcept(const std::string & x, U_16 & exception, std::string & except_msg);
 
 	///////////////////////////////////////////////
