@@ -56,8 +56,8 @@ extern "C"
 #include <typeinfo>
 #include "integers.hpp"
 #include "erreurs.hpp"
-#include "special_alloc.hpp"
 #include "int_tools.hpp"
+#include "on_pool.hpp"
 
 
 #define ZEROED_SIZE 50
@@ -65,8 +65,8 @@ extern "C"
 namespace libdar
 {
 
-    /// \addtogroup Private
-    /// @{
+	/// \addtogroup Private
+	/// @{
 
 
     class generic_file;
@@ -84,33 +84,34 @@ namespace libdar
 	/// byte of information that this type can handle, and it is also assumed that
 	/// the bytes of information are contiguous.
 
-    template<class B> class limitint
+    template<class B> class limitint : public on_pool
     {
     public :
 
 #if SIZEOF_OFF_T > SIZEOF_TIME_T
 #if SIZEOF_OFF_T > SIZEOF_SIZE_T
         limitint(off_t a = 0)
-            { limitint_from(a); };
+	{ limitint_from(a); };
 #else
         limitint(size_t a = 0)
-            { limitint_from(a); };
+	{ limitint_from(a); };
 #endif
 #else
 #if SIZEOF_TIME_T > SIZEOF_SIZE_T
         limitint(time_t a = 0)
-            { limitint_from(a); };
+	{ limitint_from(a); };
 #else
         limitint(size_t a = 0)
-            { limitint_from(a); };
+	{ limitint_from(a); };
 #endif
 #endif
 
 	    // read an limitint from a file
-        limitint(user_interaction & dialog, S_I fd);
 	limitint(generic_file & x);
 
-        void dump(user_interaction & dialog, S_I fd) const; // write byte sequence to file
+	    // for coherent footprint with real infinint
+	~limitint() throw(Ebug) {};
+
         void dump(generic_file &x) const; // write byte sequence to file
         void read(generic_file &f) { build_from_file(f); };
 
@@ -128,13 +129,13 @@ namespace libdar
         limitint & operator <<= (U_32 bit);
         limitint & operator <<= (limitint bit);
         limitint operator ++(int a)
-            { limitint ret = *this; ++(*this); return ret; };
+	{ limitint ret = *this; ++(*this); return ret; };
         limitint operator --(int a)
-            { limitint ret = *this; --(*this); return ret; };
+	{ limitint ret = *this; --(*this); return ret; };
         limitint & operator ++()
-            { return *this += 1; };
+	{ return *this += 1; };
         limitint & operator --()
-            { return *this -= 1; };
+	{ return *this -= 1; };
 
         U_32 operator % (U_32 arg) const;
 
@@ -148,8 +149,9 @@ namespace libdar
 	    // it returns number of byte of information necessary to store the integer
 
 	unsigned char operator [] (const limitint & position) const;
-	    // return in big endian order the information bytes storing the integer
+	    // return in little endian order the information bytes storing the integer
 
+	bool is_zero() const { return field == 0; };
 
         bool operator < (const limitint &x) const { return field < x.field; };
         bool operator == (const limitint &x) const { return field == x.field; };
@@ -157,15 +159,11 @@ namespace libdar
         bool operator <= (const limitint &x) const { return field <= x.field; };
         bool operator != (const limitint &x) const { return field != x.field; };
         bool operator >= (const limitint &x) const { return field >= x.field; };
-
 	static bool is_system_big_endian();
 
-#ifdef LIBDAR_SPECIAL_ALLOC
-        USE_SPECIAL_ALLOC(limitint);
-#endif
-
         B debug_get_max() const { return max_value; };
         B debug_get_bytesize() const { return bytesize; };
+	B debug_get_field() const { return field; };
 
     private :
         static const int TG = 4;
@@ -235,12 +233,11 @@ namespace libdar
     typedef limitint<INFININT_BASE_TYPE> infinint;
 #endif
 } // end of namespace
-	///////////////////////////////////////////////////////////////////////
-	/////////  template implementation ////////////////////////////////////
-	///////////////////////////////////////////////////////////////////////
+    ///////////////////////////////////////////////////////////////////////
+    /////////  template implementation ////////////////////////////////////
+    ///////////////////////////////////////////////////////////////////////
 
 #include "generic_file.hpp"
-#include "fichier.hpp"
 #include "user_interaction.hpp"
 
 namespace libdar
@@ -249,23 +246,11 @@ namespace libdar
     template <class B> typename limitint<B>::endian limitint<B>::used_endian = not_initialized;
 
 
-
-    template <class B> limitint<B>::limitint(user_interaction & dialog, S_I fd)
-    {
-	fichier f = fichier(dialog, dup(fd));
-	build_from_file(f);
-    }
-
     template <class B> limitint<B>::limitint(generic_file & x)
     {
 	build_from_file(x);
     }
 
-    template <class B> void limitint<B>::dump(user_interaction & dialog, S_I fd) const
-    {
-        fichier f = fichier(dialog, dup(fd));
-        dump(f);
-    }
 
     template <class B> void limitint<B>::build_from_file(generic_file & x)
     {
