@@ -35,11 +35,9 @@ namespace libdar
 	uid = 0;
 	gid = 0;
 	perm = 0;
-	last_access = 0;
-	last_modif = 0;
 	data_status = s_saved;
-	ea_status = inode::ea_none;
-	last_change = 0;
+	ea_status = cat_inode::ea_none;
+	fsa_status = cat_inode::fsa_none;
 	file_size = 0;
 	storage_size = 0;
 	sparse_file = 0;
@@ -50,17 +48,14 @@ namespace libdar
 	minor = 0;
     }
 
-    time_t list_entry::infinint2time_t(infinint val)
+    time_t list_entry::datetime2time_t(const datetime & val)
     {
 	time_t ret = 0;
+	time_t unused;
 
-	val.unstack(ret);
-	if(val != 0)
-	    throw Erange("list_entry::infinint_to_time_t", gettext("system type time_t is too small to store a time/date"));
+	(void) val.get_value(ret, unused, datetime::tu_second);
 
 	return ret;
     }
 
-
-
 } // end of namespace
