@@ -27,22 +27,8 @@
 #ifndef LIST_ENTRY_HPP
 #define LIST_ENTRY_HPP
 
-extern "C"
-{
-#if HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
-#if HAVE_SYS_STAT_H
-#include <sys/stat.h>
-#endif
-
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-}
-
 #include <string>
+#include <set>
 
 #include "../my_config.h"
 #include "infinint.hpp"
@@ -51,6 +37,9 @@ extern "C"
 #include "tools.hpp"
 #include "compressor.hpp"
 #include "integers.hpp"
+#include "on_pool.hpp"
+#include "datetime.hpp"
+#include "range.hpp"
 
 namespace libdar
 {
@@ -63,7 +52,7 @@ namespace libdar
 	/// This has the advantage to let the possiblity to add new fields in the future
 	/// without breaking anything in API, and in consequences in user programs.
 	/// \ingroup API
-    class list_entry
+    class list_entry : public on_pool
     {
     public:
 	list_entry();
@@ -85,26 +74,46 @@ namespace libdar
 	bool is_door_inode() const { return type == 'o'; };
 
 	bool has_data_present_in_the_archive() const { return data_status == s_saved; };
-	bool has_EA() const { return ea_status != inode::ea_none && ea_status != inode::ea_removed; };
-	bool has_EA_saved_in_the_archive() const { return ea_status == inode::ea_full; };
+	bool has_EA() const { return ea_status != cat_inode::ea_none && ea_status != cat_inode::ea_removed; };
+	bool has_EA_saved_in_the_archive() const { return ea_status == cat_inode::ea_full; };
+	bool has_FSA() const { return fsa_status != cat_inode::fsa_none; };
+	bool has_FSA_saved_in_the_archive() const { return fsa_status == cat_inode::fsa_full; };
 
 	std::string get_uid() const { return deci(uid).human(); };
 	std::string get_gid() const { return deci(gid).human(); };
-	std::string get_perm() const { return tools_int2str(perm); };
-	std::string get_last_access() const { return last_access != 0 ? tools_display_date(last_access) : ""; };
-	time_t get_last_access_s() const { return infinint2time_t(last_access); };
-	std::string get_last_modif() const { return last_modif != 0 ? tools_display_date(last_modif) : ""; };
-	time_t get_last_modif_s() const { return infinint2time_t(last_modif); };
-	std::string get_last_change() const { return last_change != 0 ? tools_display_date(last_change) : ""; };
-	time_t get_last_change_s() const { return infinint2time_t(last_change); };
+	std::string get_perm() const { return tools_get_permission_string(type, perm, hard_link); };
+	std::string get_last_access() const { return last_access.is_null() ? "" : tools_display_date(last_access); };
+	std::string get_last_modif() const { return last_modif.is_null() ? "" : tools_display_date(last_modif); };
+	std::string get_last_change() const { return last_change.is_null() ? "" : tools_display_date(last_change); };
+	time_t get_last_access_s() const { return datetime2time_t(last_access); };
+	time_t get_last_modif_s() const { return datetime2time_t(last_modif); };
+	time_t get_last_change_s() const { return datetime2time_t(last_change); };
+
+	    /// yet an alternative method to get last access time
+	    ///
+	    /// \param[in] tu time unit to be used to store fraction (libdar::datetime::tu_microsecond, libdar::datetime::tu_nanosecond,...)
+	    /// \param[out] second integer number of second
+	    /// \param[out] fraction remaining part of the time (expressed as tu unit) to be added to "second" to get the exact time
+	void get_last_access(datetime::time_unit tu, time_t & second, time_t & fraction) const
+	{ last_access.get_value(second, fraction, tu); }
+
+	    /// yet an alternative method to get the last modification date (see get_last_access() for details)
+	void get_last_modif(datetime::time_unit tu, time_t & second, time_t & fraction)	const
+	{ last_modif.get_value(second, fraction, tu); }
+
+	    /// yet an alternative method to get the last change date (see get_last_access() for details)
+	void get_last_change(datetime::time_unit tu, time_t & second, time_t & fraction) const
+	{ last_change.get_value(second, fraction, tu); }
+
 	std::string get_file_size() const { return deci(file_size).human(); };
-	std::string get_compression_ratio() const { return tools_get_compression_ratio(storage_size, file_size); };
+	std::string get_compression_ratio() const { return tools_get_compression_ratio(storage_size, file_size, compression_algo != none); };
 	bool is_sparse() const { return sparse_file; };
 	std::string get_compression_algo() const { return compression2string(compression_algo); };
 	bool is_dirty() const { return dirty; };
 	std::string get_link_target() const { return target; };
 	std::string get_major() const { return tools_int2str(major); };
 	std::string get_minor() const { return tools_int2str(minor); };
+	const range & get_slices() const { return slices; };
 
 
 	    // methods for libdar to setup the object
@@ -115,11 +124,12 @@ namespace libdar
 	void set_uid(const infinint & val) { uid = val; };
 	void set_gid(const infinint & val) { gid = val; };
 	void set_perm(U_16 val) { perm = val; };
-	void set_last_access(const infinint & val) { last_access = val; };
-	void set_last_modif(const infinint & val) { last_modif = val; };
+	void set_last_access(const datetime & val) { last_access = val; };
+	void set_last_modif(const datetime & val) { last_modif = val; };
 	void set_saved_status(saved_status val) { data_status = val; };
-	void set_ea_status(inode::ea_status val) { ea_status = val; };
-	void set_last_change(const infinint & val) { last_change = val; };
+	void set_ea_status(cat_inode::ea_status val) { ea_status = val; };
+	void set_last_change(const datetime & val) { last_change = val; };
+	void set_fsa_status(cat_inode::fsa_status val) { fsa_status = val; };
 	void set_file_size(const infinint & val) { file_size = val; };
 	void set_storage_size(const infinint & val) { storage_size = val; };
 	void set_is_sparse_file(bool val) { sparse_file = val; };
@@ -128,6 +138,7 @@ namespace libdar
 	void set_link_target(const std::string & val) { target = val; };
 	void set_major(int val) { major = val; };
 	void set_minor(int val) { minor = val; };
+	void set_slices(const range & sl) { slices = sl; };
 
     private:
 	std::string my_name;
@@ -136,11 +147,12 @@ namespace libdar
 	infinint uid;
 	infinint gid;
 	U_16 perm;
-	infinint last_access;
-	infinint last_modif;
+	datetime last_access;
+	datetime last_modif;
 	saved_status data_status;
-	inode::ea_status ea_status;
-	infinint last_change;
+	cat_inode::ea_status ea_status;
+	datetime last_change;
+	cat_inode::fsa_status fsa_status;
 	infinint file_size;
 	infinint storage_size;
 	bool sparse_file;
@@ -149,8 +161,9 @@ namespace libdar
 	std::string target;
 	int major;
 	int minor;
+	range slices;
 
-	static time_t infinint2time_t(infinint val);
+	static time_t datetime2time_t(const datetime & val);
     };
 
 } // end of namespace
