@@ -59,7 +59,12 @@ namespace libdar
 	    /// \param[in] dialog the user_interaction object to clone and store
 	    /// If you plan to use mem_ui, you should pass the user_interaction to its constructor
 	    /// for you later be able to call get_ui() at any time from the inherited class
-	mem_ui(user_interaction & dialog) { set_ui(dialog); };
+	mem_ui(const user_interaction & dialog) { set_ui(dialog); };
+
+	    /// \param[in] dialog pointer to a user_interaction object that will be *referred* to
+	    /// and which must stay alive during the whole life of "this" object. This object is not
+	    /// destroyed nor cloned by mem_ui.
+	mem_ui(user_interaction *dialog) { ui = dialog; cloned = false; };
 
 	    /// the copy constructor
 
@@ -70,7 +75,7 @@ namespace libdar
 
 	    /// it is declared as virtual, for precaution, as it may not be very frequent to
 	    /// release an object having just a mem_ui pointer on it.
-	virtual ~mem_ui() { detruire(); };
+	virtual ~mem_ui() throw(Ebug) { detruire(); };
 
 
 	    /// assignement operator
@@ -79,7 +84,7 @@ namespace libdar
 	    /// if the inherited class explicitely defines its own one.
 	const mem_ui & operator = (const mem_ui & ref) { detruire(); copy_from(ref); return *this; };
 
-
+    protected:
 	    /// get access to the user_interaction cloned object
 
 	    /// \return a reference to the clone object. This reference stays valid during all
@@ -88,10 +93,11 @@ namespace libdar
 
     private:
 	user_interaction *ui;
+	bool cloned;
 
 	void detruire();
 	void copy_from(const mem_ui & ref);
-	void set_ui(user_interaction & dialog);
+	void set_ui(const user_interaction & dialog);
     };
 
 	/// @}
