@@ -39,41 +39,31 @@ namespace libdar
     {
     public:
 
-	    // Constructors & Destructor
-	    //
-	    //
+	    /// Constructors & Destructor
+	memory_file() : generic_file(gf_read_write), data(0) { position = 0; };
+
+	    // memory_storage specific methods
+
+	void reset() { if(is_terminated()) throw SRC_BUG; position = 0; data = storage(0); };
+	infinint size() const { return data.size(); };
 
-	memory_file(gf_mode m) : generic_file(m), data(0) { position = 0; };
 
 	    // virtual method inherited from generic_file
-	    //
-	    //
-
+	bool skippable(skippability direction, const infinint & amount) { return true; };
 	bool skip(const infinint & pos);
 	bool skip_to_eof();
 	bool skip_relative(S_I x);
-	infinint get_position() { if(is_terminated()) throw SRC_BUG; return position; };
-	void reset() { if(is_terminated()) throw SRC_BUG; position = 0; data = storage(0); };
+	infinint get_position() const { if(is_terminated()) throw SRC_BUG; return position; };
 
-	    // raw access to stored data
-	    //
-	    //
-
-	    /// returns the size taken by the object's raw data
-	infinint get_data_size() const { if(is_terminated()) throw SRC_BUG; return data.size(); };
-
-	    /// return the raw data
-	const storage & get_raw_data() const { if(is_terminated()) throw SRC_BUG; return data; };
-	void set_raw_data(const storage & val) { if(is_terminated()) throw SRC_BUG; data = val; position = 0; };
-
-#ifdef LIBDAR_SPECIAL_ALLOC
-        USE_SPECIAL_ALLOC(memory_file);
-#endif
 
     protected:
+
+	    // virtual method inherited from generic_file
+	void inherited_read_ahead(const infinint & amount) {}; // no optimization can be done here, we rely on the OS here
 	U_I inherited_read(char *a, U_I size);
 	void inherited_write(const char *a, U_I size);
 	void inherited_sync_write() {};
+	void inherited_flush_read() {};
 	void inherited_terminate() {};
 
     private:
