@@ -51,15 +51,15 @@ namespace libdar
     {
     public :
         null_file(gf_mode m) : generic_file(m) {};
+	bool skippable(skippability direction, const infinint & amount) { return true; };
         bool skip(const infinint &pos) { return true; };
         bool skip_to_eof() { return true; };
         bool skip_relative(signed int x) { return false; };
-        infinint get_position() { return 0; };
+        infinint get_position() const { return 0; };
 
-#ifdef LIBDAR_SPECIAL_ALLOC
-        USE_SPECIAL_ALLOC(null_file);
-#endif
     protected :
+	void inherited_read_ahead(const infinint & amount) {};
+
         U_I inherited_read(char *a, U_I size)
 	{
 #ifdef MUTEX_WORKS
@@ -76,7 +76,7 @@ namespace libdar
 	};
 
 	void inherited_sync_write() {};
-
+	void inherited_flush_read() {};
 	void inherited_terminate() {};
     };
 
