@@ -56,16 +56,17 @@ namespace libdar
 	    ///
 	    /// \param[in] f is the address of the object to add to the stack
 	    /// \param[in] label unique label associated to this object in the current stack, exception thrown if label already used in stack
+	    /// \param[in] extend_mode allow the new object to have more read/write permission than the already placed object, which have the effect to change the read/write permission of the stack itself, future push() will accept wider permission even if extend_mode is not set
 	    /// \note once added, the object memory allocation is managed by the pile object
 	    /// the pile is responsible of destroying this object if its destructor is called
 	    /// however, the pile object releases its responsibility about any object that
 	    /// will be poped (see pop() below) from the stack.
 	    /// \note empty label (empty string) is the only value that can be used for several objects of the stack
-	void push(generic_file *f, const std::string & label = "");
+	void push(generic_file *f, const std::string & label = "", bool extend_mode = false);
 
 	    /// remove the top generic_file from the top
 	    ///
-	    /// \returns the address of the object that has been poped from the stack or NULL if the stack is empty
+	    /// \returns the address of the object that has been poped from the stack or nullptr if the stack is empty
 	    /// \note this is now the duty of the caller to release this object memory when the object is no more needed
 	generic_file *pop();
 
@@ -75,10 +76,10 @@ namespace libdar
 	template <class T> bool pop_and_close_if_type_is(T *ptr);
 
 	    /// returns the address of the top generic_file
-	generic_file *top() { if(stack.empty()) return NULL; else return stack.back().ptr; };
+	generic_file *top() { if(stack.empty()) return nullptr; else return stack.back().ptr; };
 
 	    /// returns the address of teh bottom generic_file
-	generic_file *bottom() { if(stack.empty()) return NULL; else return stack[0].ptr; };
+	generic_file *bottom() { if(stack.empty()) return nullptr; else return stack[0].ptr; };
 
 	    /// returns the number of objects in the stack
 	U_I size() const { return stack.size(); };
@@ -91,17 +92,17 @@ namespace libdar
 
 	    /// this template let the class user find out the higher object on the stack of the given type
 	    /// \param[in,out] ref gives the type of the object to look for, and gets the address of the first object found starting from the top
-	    /// \note if no object of that type could be found in the stack ref is set to NULL
+	    /// \note if no object of that type could be found in the stack ref is set to nullptr
 	template<class T> void find_first_from_top(T * & ref);
 
 	    /// this template is similar to the template "find_first_from_top" except that the search is started from the bottom of the stack
 	template<class T> void find_first_from_bottom(T * & ref);
 
 
-	    /// return the generic_file object just below the given object or NULL if the object is at the bottom of the stack or is not in the stack
+	    /// return the generic_file object just below the given object or nullptr if the object is at the bottom of the stack or is not in the stack
 	generic_file *get_below(const generic_file *ref);
 
-	    /// return the generic_file object just above the given object or NULL if the object is at the bottom of the stack or is not in the stack
+	    /// return the generic_file object just above the given object or nullptr if the object is at the bottom of the stack or is not in the stack
 	generic_file *get_above(const generic_file *ref);
 
 
@@ -128,21 +129,30 @@ namespace libdar
 	void add_label(const std::string & label);
 
 
+	    /// call the generic_file::sync_write() method of all object found above ptr in the stack
+	void sync_write_above(generic_file *ptr);
+
+	    /// call the generic_file::flush_read() method of all objects found above ptr in the stack
+	void flush_read_above(generic_file *ptr);
 
 	    // inherited methods from generic_file
 	    // they all apply to the top generic_file object, they fail by Erange() exception if the stack is empty
 
+	bool skippable(skippability direction, const infinint & amount);
 	bool skip(const infinint & pos);
 	bool skip_to_eof();
 	bool skip_relative(S_I x);
-	infinint get_position();
+	infinint get_position() const;
+
 	void copy_to(generic_file & ref);
 	void copy_to(generic_file & ref, const infinint & crc_size, crc * & value);
 
     protected:
+	void inherited_read_ahead(const infinint & amount);
 	U_I inherited_read(char *a, U_I size);
 	void inherited_write(const char *a, U_I size);
 	void inherited_sync_write();
+	void inherited_flush_read();
 	void inherited_terminate();
 
     private:
@@ -150,7 +160,9 @@ namespace libdar
 	{
 	    generic_file * ptr;
 	    std::list<std::string> labels;
-	};
+	};  // ok, had not much idea to find a name for that struct, "face" was the first idea found to be associated with "pile", which means stack
+	    // in French but also is the name of the face of a coin where its value is written. The opposite face of a coin is called "face" in French
+	    // because often a face is design there and the expression "tirer `a pile ou face" (meaning "to toss up") is very common.
 
 	std::vector<face> stack;
 
@@ -165,13 +177,13 @@ namespace libdar
 
     template <class T> bool pile::pop_and_close_if_type_is(T *ptr)
     {
-	generic_file *top = NULL;
+	generic_file *top = nullptr;
 
 	if(!stack.empty())
 	{
 	    top = stack.back().ptr;
 	    ptr = dynamic_cast<T *>(top);
-	    if(ptr != NULL)
+	    if(ptr != nullptr)
 	    {
 		stack.pop_back();
 		delete top;
@@ -185,17 +197,17 @@ namespace libdar
     }
 
     template <class T> void pile::find_first_from_top(T * & ref)
-	{
-	ref = NULL;
-	for(std::vector<face>::reverse_iterator it = stack.rbegin(); it != stack.rend() && ref == NULL; ++it)
+    {
+	ref = nullptr;
+	for(std::vector<face>::reverse_iterator it = stack.rbegin(); it != stack.rend() && ref == nullptr; ++it)
 	    ref = dynamic_cast<T *>(it->ptr);
     }
 
 
     template <class T> void pile::find_first_from_bottom(T * & ref)
     {
-	ref = NULL;
-	for(std::vector<face>::iterator it = stack.begin(); it != stack.end() && ref == NULL; ++it)
+	ref = nullptr;
+	for(std::vector<face>::iterator it = stack.begin(); it != stack.end() && ref == nullptr; ++it)
 	    ref = dynamic_cast<T *>(it->ptr);
     }
 
