@@ -39,11 +39,11 @@ extern "C"
 } // end extern "C"
 
 #include <typeinfo>
-#include <new>
 
 #include "storage.hpp"
 #include "integers.hpp"
 #include "int_tools.hpp"
+#include "on_pool.hpp"
 
 #define ZEROED_SIZE 50
 
@@ -56,7 +56,7 @@ namespace libdar
 
 	/// can only handle positive integer numbers
 	/// \ingroup Private
-    class infinint
+    class infinint : public on_pool
     {
     public :
 
@@ -82,16 +82,14 @@ namespace libdar
 	{ copy_from(ref); }
 
 	    // read an infinint from a file
-	infinint(user_interaction & dialog, S_I fd);
 	infinint(generic_file & x);
 
-        ~infinint()
+        ~infinint() throw(Ebug)
 	{ detruit(); };
 
         const infinint & operator = (const infinint & ref)
 	{ detruit(); copy_from(ref); return *this; };
 
-        void dump(user_interaction & dialog, int fd) const; // write byte sequence to file
         void dump(generic_file &x) const; // write byte sequence to file
         void read(generic_file &f) { detruit(); build_from_file(f); };
 
@@ -131,7 +129,9 @@ namespace libdar
 	    // it returns number of byte of information necessary to store the integer
 
 	unsigned char operator [] (const infinint & position) const;
-	    // return in big endian order the information byte storing the integer
+	    // return in little endian order the information byte storing the integer
+
+	bool is_zero() const;
 
         friend bool operator < (const infinint &, const infinint &);
         friend bool operator == (const infinint &, const infinint &);
@@ -143,9 +143,6 @@ namespace libdar
 
 	static bool is_system_big_endian();
 
-#ifdef LIBDAR_SPECIAL_ALLOC
-        USE_SPECIAL_ALLOC(infinint);
-#endif
     private :
         static const int TG = 4;
 
@@ -177,7 +174,7 @@ namespace libdar
 
 #define OPERATOR(OP) inline bool operator OP (const infinint &a, const infinint &b) \
     {									\
-	    return a.difference(b) OP 0;				\
+	return a.difference(b) OP 0;					\
     }
 
     OPERATOR(<)
@@ -299,7 +296,7 @@ namespace libdar
         }
 
         field = new (std::nothrow) storage(size);
-        if(field != NULL)
+        if(field != nullptr)
         {
             storage::iterator it = field->begin();
 
