@@ -36,7 +36,7 @@
 
 #include <string>
 #include "integers.hpp"
-#include "special_alloc.hpp"
+#include "on_pool.hpp"
 
 namespace libdar
 {
@@ -54,102 +54,115 @@ namespace libdar
 	/// not yet secured, where from the read() method that fetches data directly from a
 	/// filedescriptor (read() low-level system call) which might be a tty for example
 
-    class secu_string
+    class secu_string : public on_pool
     {
     public:
 	    /// to know if secure memory is available
-
+	    ///
 	    /// it is advised that the user program of class secu_string uses this call before using objects of that class
 	    /// and if returned false, advise the user that the necessary support for secure memory
 	    /// is not present, that any sensitive data may be swapped out under heavy memory load and thus
 	    /// may lead secure password to be wrote to disk in clear.
 	static bool is_string_secured();
 
-	    /// constructor
-
+	    /// constructor 1
+	    ///
 	    /// create the allocated string in secure memory
-	    /// \param[in] size is the amount of secured memory to obtain when creating the object
-	secu_string(U_I size = 0) { init(size); };
-
-	    /// constructor
+	    /// \param[in] storage_size is the amount of secured memory to obtain when creating the object
+	secu_string(U_I storage_size = 0) { init(storage_size); };
 
+	    /// constructor 2
+	    ///
 	    /// create the string from a pointer to a (secure) string or from a portion of it
-	secu_string(const char *ptr, U_I size) { init(size); append(ptr, size); };
+	secu_string(const char *ptr, U_I size) { init(size); append_at(0, ptr, size); };
 
 	    /// the copy constructor
 	secu_string(const secu_string & ref) { copy_from(ref); };
 
-
 	    /// the assignment operator
 	secu_string & operator = (const secu_string & ref) { clean_and_destroy(); copy_from(ref); return *this; };
 
 	bool operator != (const std::string & ref) const { return ! (*this == ref); };
 	bool operator != (const secu_string & ref) const { return ! (*this == ref); };
 	bool operator == (const std::string &ref) const { return compare_with(ref.c_str(),(U_I)(ref.size())); };
-	bool operator == (const secu_string &ref) const { return compare_with(ref.mem, *ref.string_size); };
+	bool operator == (const secu_string &ref) const { return compare_with(ref.mem, *(ref.string_size)); };
 
 	    /// the destructor (set memory to zero before releasing it)
-	~secu_string() { clean_and_destroy(); };
+	~secu_string() throw(Ebug) { clean_and_destroy(); };
 
 	    /// fill the object with data
-
-	    /// reads at most size bytes of data directly from the filedescriptor,
+	    ///
+	    /// set at most size bytes of data directly from the filedescriptor,
 	    /// \param[in] fd the filedescriptor to read data from
 	    /// \param[in] size is the maximum number of byte read
-	    /// \note each read call clears and reset the string, as well as the allocation size
-	void read(int fd, U_I size);
-
-	    /// append some data to the string
+	    /// \note if current storage size is not larg enough to hold size bytes,
+	    /// allocated secure memory is released and larger allocation of secure memory is done.
+	void set(int fd, U_I size);
 
+	    /// append some data to the string at a given offset
+	    ///
+	    /// \param[in] offset defines at which offset in the secu_string will be placed the string to append
 	    /// \param[in] ptr is the address of the string to append
 	    /// \param[in] size is the number of byte to append
 	    /// \note this call does not change the allocation size, (unlike read()), it adds the data pointed by the arguments
 	    /// to the object while there is enough place to do so.
-	    /// clear_and_resize() must be used first to define enough secure memory to append the expected amount of data
+	    /// resize() must be used first to define enough secure memory to append the expected amount of data
 	    /// in one or several call to append.
-	void append(const char *ptr, U_I size);
+	void append_at(U_I offset, const char *ptr, U_I size);
 
 	    /// append some data to the string
-	void append(int fd, U_I size);
+	void append_at(U_I offset, int fd, U_I size);
+
+	    /// append some data at the end of the string
+	void append(const char *ptr, U_I size) { append_at(*string_size, ptr, size); };
+
+	    /// append some data at the end of the string
+	void append(int fd, U_I size) { append_at(*string_size, fd, size); };
 
 	    /// shorten the string (do not change the allocated size)
+	    ///
 	    /// \param[in] pos is the length of the string to set, it must be smaller or equal to the current size
 	void reduce_string_size_to(U_I pos);
 
-	    /// clear the string (ans set its allocated string to zero)
-	void clear() { clean_and_destroy(); init(0); };
+	    /// clear the string (set to an empty string)
+	void clear() { *string_size = 0; };
 
 	    /// clear and resize the string to the defined allocated size
-
+	    ///
 	    /// \param[in] size is the amount of secure memory to allocated
-	void clear_and_resize(U_I size) { clean_and_destroy(); init(size); };
+	void resize(U_I size) { clean_and_destroy(); init(size); };
 
-	void clear_and_not_resize() {  string_size = 0; };
+	    /// set the string to randomize string of given size
+	    ///
+	    /// \note the given size must be less than allocated size
+	void randomize(U_I size);
 
 	    /// get access to the secure string
 
 	    /// \return the address of the first byte of the string
 	    /// \note check the "size" method to know how much bytes can be read
-	    /// \note the string is NULL terminated
-	const char*c_str() const { return mem == NULL ? throw SRC_BUG : mem; };
+	const char*c_str() const { return mem == nullptr ? throw SRC_BUG : mem; };
+
+	    /// get access to the secure string by index
+	    ///
+	    /// \note index must be in the range [ 0 - size() [ to avoid throwing an exception
+	char & operator[] (U_I index);
+	char operator[](U_I index) const { return (const_cast<secu_string *>(this))->operator[](index); };
 
 	    /// get the size of the string
+	U_I get_size() const { if(string_size == nullptr) throw SRC_BUG; return *string_size; }; // returns the size of the string
 
-	    /// this is the amount of data read from the filedescriptor
-	    /// up to the first new-line character.
-	U_I size() const { return *string_size; }; // returns the size of the string
+	    /// get the size of the allocated secure space
+	U_I get_allocated_size() const { return *allocated_size - 1; };
 
-#ifdef LIBDAR_SPECIAL_ALLOC
-        USE_SPECIAL_ALLOC(secu_string);
-#endif
     private:
 	U_I *allocated_size;
 	char *mem;
 	U_I *string_size;
 
-	void init(U_I size);
-	void copy_from(const secu_string & ref);
-	bool compare_with(const char *ptr, U_I size) const;
+	void init(U_I size);   //< to be used at creation time or after clean_and_destroy() only
+	void copy_from(const secu_string & ref); //< to be used at creation time or after clean_and_destroy() only
+	bool compare_with(const char *ptr, U_I size) const; // return true if given sequence is the same as the one stored in "this"
 	void clean_and_destroy();
     };
 
