@@ -31,6 +31,7 @@
 #include "mem_ui.hpp"
 #include "mask.hpp"
 #include "catalogue.hpp"
+#include "on_pool.hpp"
 
 namespace libdar
 {
@@ -62,7 +63,7 @@ namespace libdar
 	/// be saved once the backup is completed, may it be normally or due to an exception being thrown.
 
 
-    class semaphore : public mem_ui
+    class semaphore : public mem_ui, public on_pool
     {
     public:
 
@@ -79,7 +80,7 @@ namespace libdar
 		  const mask & backup_hook_file_mask);
 
 	    /// copy constructor
-	semaphore(const semaphore & ref) : mem_ui(ref.get_ui()) { copy_from(ref); };
+	semaphore(const semaphore & ref) : mem_ui(ref) { copy_from(ref); };
 
 	    /// assignment operator
 	semaphore & operator = (const semaphore & ref) { detruit(); copy_from(ref); return *this; };
@@ -98,21 +99,19 @@ namespace libdar
 	    /// of the matching EOD that will trigger the hook execution in the "end" context.
 	    /// If instead data_to_save if false, no lower() call has to be done.
 	void raise(const std::string & path,
-		   const entree *object,
+		   const cat_entree *object,
 		   bool data_to_save);
 
 	    /// to tell that the backup is completed for the last "raised" entry.
 	void lower();
 
-#ifdef LIBDAR_SPECIAL_ALLOC
-        USE_SPECIAL_ALLOC(semaphore);
-#endif
     private:
 	infinint count;       //< is the number of subdirectories currently saved in the last directory that matched the mask
 	std::string chem;     //< path of the file that has to be call in the "end" context when count will drop to zero
 	std::string filename; //< filename of that same file
 	infinint uid;         //< UID of that same file
 	infinint gid;         //< GID of that same file
+	unsigned char sig;    //< object type
 	std::string execute;  //< command to execute
 	const mask *match;    //< for which file to run the execute command
 
