@@ -35,6 +35,7 @@
 #include "infinint.hpp"
 #include "generic_file.hpp"
 #include "thread_cancellation.hpp"
+#include "mem_ui.hpp"
 
 namespace libdar
 {
@@ -46,15 +47,15 @@ namespace libdar
     class tuyau : public generic_file, public thread_cancellation, protected mem_ui
     {
     public:
-        tuyau(user_interaction & dialog,    //< for user interaction
-	      int fd);                      //< fd is the filedescriptor of a pipe extremity already openned
-        tuyau(user_interaction & dialog,
-	      int fd,                       //< fd is the filedescriptor of a pipe extremity already openned
-	      gf_mode mode);                //< forces the mode if possible
-        tuyau(user_interaction & dialog,    //< for user interaction
-	      const std::string &filename,  //< named pipe to open
-	      gf_mode mode);                //< forces the mode if possible
-	tuyau(user_interaction & dialog);   //< creates a anonymous pipe and bind itself to the writing end. The reading end can be obtained by get_read_side() method
+        tuyau(const user_interaction & dialog, //< for user interaction
+	      int fd);                         //< fd is the filedescriptor of a pipe extremity already openned
+        tuyau(const user_interaction & dialog, //< for user interaction
+	      int fd,                          //< fd is the filedescriptor of a pipe extremity already openned
+	      gf_mode mode);                   //< forces the mode if possible
+        tuyau(const user_interaction & dialog, //< for user interaction
+	      const std::string &filename,     //< named pipe to open
+	      gf_mode mode);                   //< forces the mode if possible
+	tuyau(const user_interaction & dialog);//< creates a anonymous pipe and bind itself to the writing end. The reading end can be obtained by get_read_side() method
         ~tuyau();
 
 	    // provides the reading end of the anonymous pipe when the current object has created it (no filedesc, no path given to constructor).
@@ -72,17 +73,20 @@ namespace libdar
 	void do_not_close_read_fd();
 
             // inherited from generic_file
+	bool skippable(skippability direction, const infinint & amount);
         bool skip(const infinint & pos);
         bool skip_to_eof();
         bool skip_relative(signed int x);
-        infinint get_position() { return position; };
+        infinint get_position() const { return position; };
 
 	bool has_next_to_read();
 
     protected:
+	void inherited_read_ahead(const infinint & amount) {}; // relying on the operating system
         virtual U_I inherited_read(char *a, U_I size);
         virtual void inherited_write(const char *a, U_I size);
 	void inherited_sync_write() {};
+	void inherited_flush_read() {};
 	void inherited_terminate();
 
     private:
@@ -92,7 +96,7 @@ namespace libdar
 	    pipe_path,      //< holds a filename to be openned (named pipe)
 	    pipe_both       //< holds a pair of file descriptors
 	}
-	pipe_mode;          //< defines how the object's status (which possible values defined by the anonymous enum above)
+	    pipe_mode;          //< defines how the object's status (which possible values defined by the anonymous enum above)
 	infinint position;  //< recorded position in the stream
 	int filedesc;       //< file descriptors of the pipe
 	int other_end_fd;   //< in pipe_both mode, this holds the reading side of the anonymous pipe
