@@ -36,6 +36,7 @@
 #include "infinint.hpp"
 #include "generic_file.hpp"
 #include "integers.hpp"
+#include "mem_ui.hpp"
 
 namespace libdar
 {
@@ -60,14 +61,15 @@ namespace libdar
 	    /// \param[in] input is the pipe (see class tuyau) from which is received the information or data
 	    /// \param[in] output is used to send orders to slave_zapette
 	    /// \param[in] by_the_end if true dar will try to open the archive starting from the end else it will try starting from the first bytes
-        zapette(user_interaction & dialog, generic_file *input, generic_file *output, bool by_the_end);
+        zapette(const user_interaction & dialog, generic_file *input, generic_file *output, bool by_the_end);
         ~zapette();
 
             // inherited methods from generic_file
+	bool skippable(skippability direction, const infinint & amount) { return true; };
         bool skip(const infinint &pos);
         bool skip_to_eof() { if(is_terminated()) throw SRC_BUG; position = file_size; return true; };
         bool skip_relative(S_I x);
-        infinint get_position() { if(is_terminated()) throw SRC_BUG; return position; };
+        infinint get_position() const { if(is_terminated()) throw SRC_BUG; return position; };
 
 	    // overwritten inherited methods from contextual
         void set_info_status(const std::string & s);
@@ -75,9 +77,11 @@ namespace libdar
 	const label & get_data_name() const;
 
     protected:
+	void inherited_read_ahead(const infinint & amount) {}; // optimization will be done when zapette will use the messaging_encode/decode exchange format
         U_I inherited_read(char *a, U_I size);
         void inherited_write(const char *a, U_I size);
 	void inherited_sync_write() {};
+	void inherited_flush_read() {};
 	void inherited_terminate();
 
     private:
@@ -100,7 +104,7 @@ namespace libdar
 	    /// and so on (see at the beginning of zapette.cpp file for more). Each of these order may expect a returned value
 	    /// which may be an integer (provided by the "arg" argument of this call)  a boolean value (provided by the "arg"
 	    /// argument where 0 means false and 1 means true) or a char * (first byte to put the answer to is given by 'data' and
-	    /// allocated space for the reply must be given through 'lu' which at return given the effective length of the returned
+	    /// allocated space for the reply must be given through 'lu' which at return gives the effective length of the returned
 	    /// string
 
 	void make_transfert(U_16 size, const infinint &offset, char *data, const std::string & info, S_I & lu, infinint & arg) const;
@@ -111,7 +115,7 @@ namespace libdar
 	/// through a pair of pipes slave_zapette return information about
 	/// a given local archive (single or multi slices).
 	/// \ingroup Private
-    class slave_zapette
+    class slave_zapette : public on_pool
     {
     public:
 
