@@ -44,12 +44,12 @@ extern "C"
 
 #include "libdar.hpp"
 #include "erreurs.hpp"
-#include "crypto.hpp"
+#include "crypto_sym.hpp"
 #include "shell_interaction.hpp"
 #include "deci.hpp"
 #include "cygwin_adapt.hpp"
 #include "macro_tools.hpp"
-#include "fichier.hpp"
+#include "fichier_local.hpp"
 
 using namespace libdar;
 using namespace std;
@@ -59,11 +59,13 @@ void f2(user_interaction *dialog);
 
 int main()
 {
-    user_interaction *dialog = NULL;
+    user_interaction *dialog = new (nothrow) shell_interaction(&cout, &cerr, false);
     U_I maj, med, min;
-
     get_version(maj, med, min);
-    dialog = shell_interaction_init(&cout, &cerr, false);
+
+    if(dialog == nullptr)
+	cout << "ERREUR !" << endl;
+
     try
     {
 	f1(dialog);
@@ -77,17 +79,16 @@ int main()
     {
 	cout << "unknown exception caught" << endl;
     }
-    shell_interaction_close();
-    if(dialog != NULL)
+
+    if(dialog != nullptr)
 	delete dialog;
- }
+}
 
 void f1(user_interaction *dialog)
 {
-    int fd = open("toto", O_WRONLY|O_TRUNC|O_CREAT|O_BINARY, 0644);
-    fichier fic = fichier(*dialog, fd);
+    fichier_local fic = fichier_local(*dialog, "toto", gf_write_only, 0666, false, true, false);
     string pass = "bonjour";
-    crypto_sym bf = crypto_sym(10, secu_string(pass.c_str(), pass.size()), fic, false, macro_tools_supported_version, crypto_blowfish);
+    crypto_sym bf = crypto_sym(10, secu_string(pass.c_str(), pass.size()), fic, false, macro_tools_supported_version, crypto_blowfish, true);
     char buffer[100] = "bonjour les amis il fait chaud il fait beau ! ";
 
     bf.write(buffer, strlen(buffer));
@@ -98,9 +99,9 @@ void f1(user_interaction *dialog)
 
 void f2(user_interaction *dialog)
 {
-    fichier fic = fichier(*dialog, "toto", gf_read_only, tools_octal2int("0777"), false);
+    fichier_local fic = fichier_local(*dialog, "toto", gf_read_only, 0666, false, false, false);
     string pass = "bonjour";
-    crypto_sym bf = crypto_sym(10, secu_string(pass.c_str(), pass.size()), fic, false, macro_tools_supported_version, crypto_blowfish);
+    crypto_sym bf = crypto_sym(10, secu_string(pass.c_str(), pass.size()), fic, false, macro_tools_supported_version, crypto_blowfish, true);
     char buffer[100];
     S_I lu;
     bool ret;
@@ -116,4 +117,7 @@ void f2(user_interaction *dialog)
     cout << bf.get_position() << endl;
     lu = bf.read(buffer, 100);
     cout << bf.get_position() << endl;
+
+    lu = lu+1; // avoid warning of unused variable
+    ret = !ret; // avoid warning of unused variable
 }
