@@ -32,12 +32,12 @@ extern "C"
 #include "escape.hpp"
 #include "cygwin_adapt.hpp"
 #include "shell_interaction.hpp"
-#include "fichier.hpp"
+#include "fichier_local.hpp"
 
 using namespace libdar;
 using namespace std;
 
-static user_interaction *ui = NULL;
+static user_interaction *ui = nullptr;
 
 void f1();
 void f2();
@@ -47,8 +47,8 @@ int main()
     U_I maj, med, min;
 
     get_version(maj, med, min);
-    ui = shell_interaction_init(&cout, &cerr, false);
-    if(ui == NULL)
+    ui = new (nothrow) shell_interaction(&cout, &cerr, false);
+    if(ui == nullptr)
 	cout << "ERREUR !" << endl;
 
     f1();
@@ -58,7 +58,7 @@ int main()
 void f1()
 {
     set<escape::sequence_type> nojump;
-    fichier below = fichier(*ui, "escape_below", gf_write_only, tools_octal2int("0777"), false);
+    fichier_local below = fichier_local(*ui, "escape_below", gf_write_only, 0666, false, true, false);
     escape tested = escape(&below, nojump);
 
     const char *seq1 = "bonjour les amis";
@@ -82,7 +82,7 @@ void f2()
     set<escape::sequence_type> nojump;
     const U_I buf_size = 100;
     unsigned char buffer[buf_size];
-    fichier below = fichier(*ui, "escape_below", gf_read_only, tools_octal2int("0777"), false);
+    fichier_local below = fichier_local(*ui, "escape_below", gf_read_only, 0666, false, false, false);
     escape tested = escape(&below, nojump);
     S_I lu = 0;
 
