@@ -50,7 +50,7 @@ extern "C"
 #include "cygwin_adapt.hpp"
 #include "erreurs.hpp"
 #include "generic_file.hpp"
-#include "fichier.hpp"
+#include "fichier_local.hpp"
 
 
 static void routine_limitint(user_interaction & dialog);
@@ -58,10 +58,12 @@ static void routine_real_infinint(user_interaction & dialog);
 
 using namespace libdar;
 
+user_interaction *ui = nullptr;
+
 int main()
 {
-    user_interaction *ui = shell_interaction_init(&cout, &cerr, false);
-    if(ui == NULL)
+    user_interaction *ui = new (nothrow) shell_interaction(&cout, &cerr, false);
+    if(ui == nullptr)
 	cout << "ERREUR !" << endl;
 
     try
@@ -73,28 +75,21 @@ int main()
     {
         routine_real_infinint(*ui);
     }
-    shell_interaction_close();
-    if(ui != NULL)
+    if(ui != nullptr)
 	delete ui;
 }
 
 static void routine_real_infinint(user_interaction & dialog)
 {
-    int fd = ::open("toto", O_RDWR | O_CREAT | O_TRUNC | O_BINARY, 0644);
+    fichier_local fic = fichier_local(*ui, "toto", gf_read_write, 0666, false, true, false);
+    infinint r1 = 1;
 
-    if(fd >= 0)
-    {
-        infinint r1 = 1;
+    r1 <<= 32;
+    r1--;
 
-        r1 <<= 32;
-        r1--;
-
-        r1.dump(dialog, fd);
-        r1++;
-        r1.dump(dialog, fd);
-
-        close(fd);
-    }
+    r1.dump(fic);
+    r1++;
+    r1.dump(fic);
 }
 
 static void routine_limitint(user_interaction & dialog)
@@ -104,23 +99,12 @@ static void routine_limitint(user_interaction & dialog)
         //
         //
 
-    int fd = ::open("toto", O_RDONLY | O_BINARY);
-    if(fd > 0)
-    {
-        infinint r1 = infinint(dialog, fd);
-        infinint r2;
+    fichier_local fic = fichier_local("toto", false);
+    infinint r1 = infinint(fic);
+    infinint r2;
 
-        try
-        {
-            fichier tmp = fichier(dialog, fd);
-            r2.read(tmp);
-	    r2 += r1; // avoid compiler complaining about r1 not used
-        }
-        catch(Elimitint & e)
-        {
-            dialog.warning(e.get_message());
-        }
-    }
+    r1 = r1+1 ; // avoid warning of unused variable
+    r2.read(fic);
 
     U_32 twopower32_1 = ~0;
     U_32 twopower31 = 1 << 31;
@@ -133,7 +117,7 @@ static void routine_limitint(user_interaction & dialog)
         unsigned long long tmp = twopower32_1;
         tmp++;
         infinint c = tmp;
-	c = c+1; // avoid compiler complaining against unused variable c
+	c = c+1; // avoid warning of unused variable
     }
     catch(Elimitint & e)
     {
@@ -143,7 +127,7 @@ static void routine_limitint(user_interaction & dialog)
     try
     {
         infinint c = (long long)(twopower32_1+1);
-	c = c+1; // avoid compiler complaining against unused variable c
+	c = c+1; // avoid warning of unused variable
     }
     catch(Elimitint & e)
     {
