@@ -47,7 +47,7 @@ extern "C"
 #  define strchr index
 #  define strrchr rindex
 # endif
-char *strchr (), *strrchr ();
+    char *strchr (), *strrchr ();
 # if !HAVE_MEMCPY
 #  define memcpy(d, s, n) bcopy ((s), (d), (n))
 #  define memmove(d, s, n) bcopy ((s), (d), (n))
@@ -62,7 +62,7 @@ char *strchr (), *strrchr ();
 #include "deci.hpp"
 #include "cygwin_adapt.hpp"
 #include "macro_tools.hpp"
-#include "fichier.hpp"
+#include "fichier_local.hpp"
 
 class test : public tronconneuse
 {
@@ -106,10 +106,9 @@ void f3(user_interaction *dialog);
 int main()
 {
     U_I maj, med, min;
-    user_interaction *dialog = NULL;
 
     get_version(maj, med, min);
-    dialog = shell_interaction_init(&cout, &cerr, false);
+    user_interaction *dialog = new (nothrow) shell_interaction(&cout, &cerr, false);
     try
     {
 	f1(dialog);
@@ -124,18 +123,16 @@ int main()
     {
 	cout << "unknown exception caught" << endl;
     }
-    shell_interaction_close();
-    if(dialog != NULL)
+    if(dialog != nullptr)
 	delete dialog;
 }
 
 void f1(user_interaction *dialog)
 {
-    int fd = open("toto", O_WRONLY|O_TRUNC|O_CREAT|O_BINARY, 0644);
-    fichier fic = fichier(*dialog, fd);
+    fichier_local fic = fichier_local(*dialog, "toto", gf_write_only, 0666, false, true, false);
 
     test *toto = new test(*dialog, 10, fic);
-    if(toto == NULL)
+    if(toto == nullptr)
 	throw Ememory("test");
 
 #define TEST_WRITE(x) toto->write(x, strlen(x))
@@ -154,11 +151,10 @@ void f1(user_interaction *dialog)
 
 void f2(user_interaction *dialog)
 {
-    int fd = open("toto", O_RDONLY|O_BINARY);
-    fichier fic = fichier(*dialog, fd);
+    fichier_local fic = fichier_local(*dialog, "toto", gf_read_only, 0666, false, false, false);
 
     test *toto = new test(*dialog, 10, fic);
-    if(toto == NULL)
+    if(toto == nullptr)
 	throw Ememory("test");
 
     const int taille = 100;
@@ -199,11 +195,8 @@ void f2(user_interaction *dialog)
 
 void f3(user_interaction *dialog)
 {
-    int fd = open("toto", O_WRONLY|O_TRUNC|O_CREAT|O_BINARY, 0666);
-    fichier foc = fichier(*dialog, fd);
-
-    fd = open("titi", O_WRONLY|O_TRUNC|O_CREAT|O_BINARY, 0666);
-    fichier fic = fichier(*dialog, fd);
+    fichier_local foc = fichier_local(*dialog, "toto", gf_write_only, 0666, false, false, false);
+    fichier_local fic = fichier_local(*dialog, "titi", gf_write_only, 0666, false, true, false);
 
     WRITE_TO(foc, "Hello les amis");
     WRITE_TO(fic, "Hello les amis");
