@@ -42,7 +42,7 @@ extern "C"
 #  define strchr index
 #  define strrchr rindex
 # endif
-char *strchr (), *strrchr ();
+    char *strchr (), *strrchr ();
 # if !HAVE_MEMCPY
 #  define memcpy(d, s, n) bcopy ((s), (d), (n))
 #  define memmove(d, s, n) bcopy ((s), (d), (n))
@@ -63,7 +63,7 @@ using namespace libdar;
 static const unsigned int buffer_size = 10000;
 static bool xmit = true;
 
-static int little_main(user_interaction & dialog, int argc, char * const argv[], const char **env);
+static int little_main(shell_interaction & dialog, int argc, char * const argv[], const char **env);
 static void action_xmit(user_interaction & dialog, tuyau *in, tuyau *out, U_32 duration);
 static void action_loop(tuyau *in, tuyau *out);
 static void stop_xmit(int l);
@@ -72,18 +72,19 @@ int main(int argc, char * const argv[])
 {
     return dar_suite_global(argc,
 			    argv,
-			    NULL,
+			    nullptr,
 			    "",
-			    NULL,
+			    nullptr,
+			    '\0',
 			    &little_main);
 }
 
-static int little_main(user_interaction & dialog, int argc, char * const argv[], const char **env)
+static int little_main(shell_interaction & dialog, int argc, char * const argv[], const char **env)
 {
-    tuyau *in = NULL, *out = NULL;
+    tuyau *in = nullptr, *out = nullptr;
     U_32 duration;
 
-    shell_interaction_change_non_interactive_output(&cout);
+    dialog.change_non_interactive_output(&cout);
     if(argc != 4)
     {
         dialog.printf("usage : %s <input> <output> <seconds>\n", argv[0]);
